# Autogenerated file. Changes will be overwritten.

try:
    import coriolis
except ImportError:
    import CRL, Hurricane, Viewer, Cfg
    from Hurricane import (
        Technology, DataBase, DbU, Library,
        Layer, BasicLayer,
        Cell, Net, Horizontal, Vertical, Rectilinear, Box, Point,
        Instance, Transformation,
        NetExternalComponents,
    )
    from helpers import u, l
    from helpers.technology import setEnclosures
    from helpers.overlay import CfgCache, UpdateSession
else:
    from coriolis import CRL, Hurricane, Viewer, Cfg
    from coriolis.Hurricane import (
        Technology, DataBase, DbU, Library,
        Layer, BasicLayer,
        Cell, Net, Horizontal, Vertical, Rectilinear, Box, Point,
        Instance, Transformation,
        NetExternalComponents,
    )
    from coriolis.helpers import u, l
    from coriolis.helpers.technology import setEnclosures
    from coriolis.helpers.overlay import CfgCache, UpdateSession

__all__ = ["setup"]

def createRL(tech, net, layer, coords):
    coords = [Point(u(x), u(y)) for x,y in coords]
    Rectilinear.create(net, tech.getLayer(layer), coords)

def _routing():
    af = CRL.AllianceFramework.get()
    db = DataBase.getDB()
    tech = db.getTechnology()

    rg = CRL.RoutingGauge.create('StdCellLib')
    rg.setSymbolic(False)
    metal = tech.getLayer('li')
    via = tech.getLayer('li_mcon_m1')
    setEnclosures(via, metal, (u(0.0), u(0.075)))
    rg.addLayerGauge(CRL.RoutingLayerGauge.create(
        metal, CRL.RoutingLayerGauge.Vertical, CRL.RoutingLayerGauge.PinOnly, 0, 0.0,
        u(0.0), u(0.51), u(0.17), u(0.17), u(0.17), u(0.17),
    ))
    metal = tech.getLayer('m1')
    via = tech.getLayer('li_mcon_m1')
    setEnclosures(via, metal, (u(0.03), u(0.075)))
    via = tech.getLayer('m1_via_m2')
    setEnclosures(via, metal, (u(0.11), u(0.085)))
    rg.addLayerGauge(CRL.RoutingLayerGauge.create(
        metal, CRL.RoutingLayerGauge.Horizontal, CRL.RoutingLayerGauge.Default, 1, 0.0,
        u(0.0), u(0.46), u(0.32), u(0.23), u(0.15), u(0.14),
    ))
    metal = tech.getLayer('m2')
    via = tech.getLayer('m1_via_m2')
    setEnclosures(via, metal, (u(0.11), u(0.085)))
    via = tech.getLayer('m2_via2_m3')
    setEnclosures(via, metal, (u(0.085), u(0.09)))
    rg.addLayerGauge(CRL.RoutingLayerGauge.create(
        metal, CRL.RoutingLayerGauge.Vertical, CRL.RoutingLayerGauge.Default, 2, 0.0,
        u(0.0), u(0.51), u(0.37), u(0.26), u(0.2), u(0.14),
    ))
    metal = tech.getLayer('m3')
    via = tech.getLayer('m2_via2_m3')
    setEnclosures(via, metal, (u(0.085), u(0.09)))
    via = tech.getLayer('m3_via3_m4')
    setEnclosures(via, metal, (u(0.49), u(0.09)))
    rg.addLayerGauge(CRL.RoutingLayerGauge.create(
        metal, CRL.RoutingLayerGauge.Horizontal, CRL.RoutingLayerGauge.Default, 3, 0.0,
        u(0.0), u(0.68), u(0.38), u(0.33), u(0.2), u(0.3),
    ))
    metal = tech.getLayer('m4')
    via = tech.getLayer('m3_via3_m4')
    setEnclosures(via, metal, (u(0.49), u(0.09)))
    via = tech.getLayer('m4_via4_m5')
    setEnclosures(via, metal, (u(0.19), u(0.4)))
    rg.addLayerGauge(CRL.RoutingLayerGauge.create(
        metal, CRL.RoutingLayerGauge.Vertical, CRL.RoutingLayerGauge.Default, 4, 0.0,
        u(0.0), u(1.48), u(1.18), u(0.33), u(0.8), u(0.3),
    ))
    metal = tech.getLayer('m5')
    via = tech.getLayer('m4_via4_m5')
    setEnclosures(via, metal, (u(0.31), u(0.4)))
    rg.addLayerGauge(CRL.RoutingLayerGauge.create(
        metal, CRL.RoutingLayerGauge.Horizontal, CRL.RoutingLayerGauge.Default, 5, 0.0,
        u(0.0), u(3.2), u(1.6), u(1.6), u(0.8), u(1.6),
    ))
    af.addRoutingGauge(rg)
    af.setRoutingGauge('StdCellLib')

    cg = CRL.CellGauge.create(
        'StdCellLib', 'm1',
        u(1.0), u(10.0), u(1.0),
    )
    af.addCellGauge(cg)
    af.setCellGauge('StdCellLib')

    # Place & Route setup
    with CfgCache(priority=Cfg.Parameter.Priority.ConfigurationFile) as cfg:
        cfg.lefImport.minTerminalWidth = 0.0
        cfg.crlcore.groundName = 'vss'
        cfg.crlcore.powerName = 'vdd'
        cfg.etesian.aspectRatio = 1.00
        cfg.etesian.aspectRatio = [10, 1000]
        cfg.etesian.spaceMargin = 0.10
        cfg.etesian.uniformDensity = True
        cfg.etesian.routingDriven = False
        cfg.etesian.latchUpDistance = u(30.0 - 1.0)
        cfg.etesian.diodeName = 'diode_w1'
        cfg.etesian.antennaInsertThreshold = 0.50
        cfg.etesian.antennaMaxWL = u(250.0)
        cfg.etesian.feedNames = 'tie,decap_w0'
        cfg.etesian.cell.zero = 'zero_x1'
        cfg.etesian.cell.one = 'one_x1'
        cfg.etesian.bloat = 'disabled'
        cfg.etesian.effort = 2
        cfg.etesian.effort = (
            ('Fast', 1),
            ('Standard', 2),
            ('High', 3 ),
            ('Extreme', 4 ),
        )
        cfg.etesian.graphics = 2
        cfg.etesian.graphics = (
            ('Show every step', 1),
            ('Show lower bound', 2),
            ('Show result only', 3),
        )
        cfg.anabatic.routingGauge = 'StdCellLib'
        cfg.anabatic.globalLengthThreshold = 1450
        cfg.anabatic.saturateRatio = 0.90
        cfg.anabatic.saturateRp = 10
        cfg.anabatic.topRoutingLayer = 'm5'
        cfg.anabatic.edgeLength = 48
        cfg.anabatic.edgeWidth = 8
        cfg.anabatic.edgeCostH = 9.0
        cfg.anabatic.edgeCostK = -10.0
        cfg.anabatic.edgeHInc = 1.0
        cfg.anabatic.edgeHScaling = 1.0
        cfg.anabatic.globalIterations = 10
        cfg.anabatic.globalIterations = [ 1, 100 ]
        cfg.anabatic.gcell.displayMode = 1
        cfg.anabatic.gcell.displayMode = (("Boundary", 1), ("Density", 2))
        cfg.katana.hTracksReservedLocal = 4
        cfg.katana.hTracksReservedLocal = [0, 20]
        cfg.katana.vTracksReservedLocal = 3
        cfg.katana.vTracksReservedLocal = [0, 20]
        cfg.katana.termSatReservedLocal = 8
        cfg.katana.termSatThreshold = 9
        cfg.katana.eventsLimit = 4000002
        cfg.katana.ripupCost = 3
        cfg.katana.ripupCost = [0, None]
        cfg.katana.strapRipupLimit = 16
        cfg.katana.strapRipupLimit = [1, None]
        cfg.katana.localRipupLimit = 9
        cfg.katana.localRipupLimit = [1, None]
        cfg.katana.globalRipupLimit = 5
        cfg.katana.globalRipupLimit = [1, None]
        cfg.katana.longGlobalRipupLimit = 5
        cfg.chip.padCoreSide = 'South'

    # Plugins setup
    with CfgCache(priority=Cfg.Parameter.Priority.ConfigurationFile) as cfg:
        cfg.viewer.minimumSize = 500
        cfg.viewer.pixelThreshold = 10
        cfg.chip.block.rails.count = 5
        cfg.chip.block.rails.hWidth = u(2.68)
        cfg.chip.block.rails.vWidth = u(2.68)
        cfg.chip.block.rails.hSpacing = u(0.7)
        cfg.chip.block.rails.vSpacing = u(0.7)
        cfg.clockTree.minimumSide = l(600)
        cfg.clockTree.buffer = 'buf_x1'
        cfg.clockTree.placerEngine = 'Etesian'
        cfg.block.spareSide = 10
        cfg.spares.buffer = 'buf_x4'
        cfg.spares.maxSinks = 31


def _load():
    af = CRL.AllianceFramework.get()
    db = DataBase.getDB()
    tech = db.getTechnology()
    rootlib = db.getRootLibrary()

    lib = Library.create(rootlib, 'StdCellLib')
    new_cells = {
        'fill': Cell.create(lib, 'fill'),
        'tie': Cell.create(lib, 'tie'),
        'tie_diff': Cell.create(lib, 'tie_diff'),
        'tie_poly': Cell.create(lib, 'tie_poly'),
        'fill_w2': Cell.create(lib, 'fill_w2'),
        'tie_w2': Cell.create(lib, 'tie_w2'),
        'tie_diff_w2': Cell.create(lib, 'tie_diff_w2'),
        'tie_poly_w2': Cell.create(lib, 'tie_poly_w2'),
        'fill_w4': Cell.create(lib, 'fill_w4'),
        'tie_w4': Cell.create(lib, 'tie_w4'),
        'tie_diff_w4': Cell.create(lib, 'tie_diff_w4'),
        'tie_poly_w4': Cell.create(lib, 'tie_poly_w4'),
        'diode_w1': Cell.create(lib, 'diode_w1'),
        'zero_x1': Cell.create(lib, 'zero_x1'),
        'one_x1': Cell.create(lib, 'one_x1'),
        'zeroone_x1': Cell.create(lib, 'zeroone_x1'),
        'decap_w0': Cell.create(lib, 'decap_w0'),
        'inv_x0': Cell.create(lib, 'inv_x0'),
        'inv_x1': Cell.create(lib, 'inv_x1'),
        'inv_x2': Cell.create(lib, 'inv_x2'),
        'inv_x4': Cell.create(lib, 'inv_x4'),
        'buf_x1': Cell.create(lib, 'buf_x1'),
        'buf_x2': Cell.create(lib, 'buf_x2'),
        'buf_x4': Cell.create(lib, 'buf_x4'),
        'nand2_x0': Cell.create(lib, 'nand2_x0'),
        'nand2_x1': Cell.create(lib, 'nand2_x1'),
        'nand3_x0': Cell.create(lib, 'nand3_x0'),
        'nand3_x1': Cell.create(lib, 'nand3_x1'),
        'nand4_x0': Cell.create(lib, 'nand4_x0'),
        'nand4_x1': Cell.create(lib, 'nand4_x1'),
        'and2_x1': Cell.create(lib, 'and2_x1'),
        'and3_x1': Cell.create(lib, 'and3_x1'),
        'and4_x1': Cell.create(lib, 'and4_x1'),
        'nor2_x0': Cell.create(lib, 'nor2_x0'),
        'nor2_x1': Cell.create(lib, 'nor2_x1'),
        'nor3_x0': Cell.create(lib, 'nor3_x0'),
        'nor3_x1': Cell.create(lib, 'nor3_x1'),
        'nor4_x0': Cell.create(lib, 'nor4_x0'),
        'nor4_x1': Cell.create(lib, 'nor4_x1'),
        'or2_x1': Cell.create(lib, 'or2_x1'),
        'or3_x1': Cell.create(lib, 'or3_x1'),
        'or4_x1': Cell.create(lib, 'or4_x1'),
        'mux2_x1': Cell.create(lib, 'mux2_x1'),
        'and21nor_x0': Cell.create(lib, 'and21nor_x0'),
        'and21nor_x1': Cell.create(lib, 'and21nor_x1'),
        'or21nand_x0': Cell.create(lib, 'or21nand_x0'),
        'or21nand_x1': Cell.create(lib, 'or21nand_x1'),
        'xor2_x0': Cell.create(lib, 'xor2_x0'),
        'nexor2_x0': Cell.create(lib, 'nexor2_x0'),
        'nsnrlatch_x0': Cell.create(lib, 'nsnrlatch_x0'),
        'nsnrlatch_x1': Cell.create(lib, 'nsnrlatch_x1'),
        'dff_x1': Cell.create(lib, 'dff_x1'),
        'dffnr_x1': Cell.create(lib, 'dffnr_x1'),
        'Gallery': Cell.create(lib, 'Gallery'),
    }

    cell = new_cells['fill']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.38),(1.0,0.38),(1.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.62),(0.0,10.0),(1.0,10.0),(1.0,9.62),(0.0,9.62)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_diff']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,5.305),(0.135,9.865),(0.865,9.865),(0.865,5.305),(0.135,5.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,4.295),(0.865,4.295),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(0.01,0.51),(0.01,4.42),(0.99,4.42),(0.99,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.01,5.18),(0.01,9.49),(0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.99,9.49),(0.99,5.18),(0.01,5.18)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_poly']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.67),(0.415,0.84),(0.585,0.84),(0.585,0.67),(0.415,0.67)),
        )
        createRL(
            tech, net, 'poly',
            ((0.105,0.46),(0.105,9.54),(0.895,9.54),(0.895,0.46),(0.105,0.46)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['fill_w2']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.38),(2.0,0.38),(2.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.62),(0.0,10.0),(2.0,10.0),(2.0,9.62),(0.0,9.62)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_w2']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_diff_w2']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,5.305),(0.135,9.865),(1.865,9.865),(1.865,5.305),(0.135,5.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,4.295),(1.865,4.295),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(0.01,0.51),(0.01,4.42),(1.99,4.42),(1.99,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.01,5.18),(0.01,9.49),(0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(1.99,9.49),(1.99,5.18),(0.01,5.18)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_poly_w2']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.915,0.67),(0.915,0.84),(1.085,0.84),(1.085,0.67),(0.915,0.67)),
        )
        createRL(
            tech, net, 'poly',
            ((0.105,0.46),(0.105,9.54),(1.895,9.54),(1.895,0.46),(0.105,0.46)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['fill_w4']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.38),(4.0,0.38),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.62),(0.0,10.0),(4.0,10.0),(4.0,9.62),(0.0,9.62)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_w4']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(3.865,9.865),(3.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,9.655),(0.385,9.825),(0.555,9.825),(0.555,9.655),(0.385,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,9.655),(0.725,9.825),(0.895,9.825),(0.895,9.655),(0.725,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,9.655),(1.065,9.825),(1.235,9.825),(1.235,9.655),(1.065,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,9.655),(1.405,9.825),(1.575,9.825),(1.575,9.655),(1.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,9.655),(1.745,9.825),(1.915,9.825),(1.915,9.655),(1.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,9.655),(2.085,9.825),(2.255,9.825),(2.255,9.655),(2.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,9.655),(2.425,9.825),(2.595,9.825),(2.595,9.655),(2.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,9.655),(2.765,9.825),(2.935,9.825),(2.935,9.655),(2.765,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,9.655),(3.105,9.825),(3.275,9.825),(3.275,9.655),(3.105,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,9.655),(3.445,9.825),(3.615,9.825),(3.615,9.655),(3.445,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(3.865,0.385),(3.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,0.175),(0.385,0.345),(0.555,0.345),(0.555,0.175),(0.385,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,0.175),(0.725,0.345),(0.895,0.345),(0.895,0.175),(0.725,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,0.175),(1.065,0.345),(1.235,0.345),(1.235,0.175),(1.065,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,0.175),(1.405,0.345),(1.575,0.345),(1.575,0.175),(1.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,0.175),(1.745,0.345),(1.915,0.345),(1.915,0.175),(1.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,0.175),(2.085,0.345),(2.255,0.345),(2.255,0.175),(2.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,0.175),(2.425,0.345),(2.595,0.345),(2.595,0.175),(2.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,0.175),(2.765,0.345),(2.935,0.345),(2.935,0.175),(2.765,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,0.175),(3.105,0.345),(3.275,0.345),(3.275,0.175),(3.105,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,0.175),(3.445,0.345),(3.615,0.345),(3.615,0.175),(3.445,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(4.0,0.51),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(4.0,9.215),(4.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(4.0,4.8),(4.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(4.0,10.0),(4.0,9.49),(0.0,9.49)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_diff_w4']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,5.305),(0.135,9.865),(3.865,9.865),(3.865,5.305),(0.135,5.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,9.655),(0.385,9.825),(0.555,9.825),(0.555,9.655),(0.385,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,9.655),(0.725,9.825),(0.895,9.825),(0.895,9.655),(0.725,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,9.655),(1.065,9.825),(1.235,9.825),(1.235,9.655),(1.065,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,9.655),(1.405,9.825),(1.575,9.825),(1.575,9.655),(1.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,9.655),(1.745,9.825),(1.915,9.825),(1.915,9.655),(1.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,9.655),(2.085,9.825),(2.255,9.825),(2.255,9.655),(2.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,9.655),(2.425,9.825),(2.595,9.825),(2.595,9.655),(2.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,9.655),(2.765,9.825),(2.935,9.825),(2.935,9.655),(2.765,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,9.655),(3.105,9.825),(3.275,9.825),(3.275,9.655),(3.105,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,9.655),(3.445,9.825),(3.615,9.825),(3.615,9.655),(3.445,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,4.295),(3.865,4.295),(3.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,0.175),(0.385,0.345),(0.555,0.345),(0.555,0.175),(0.385,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,0.175),(0.725,0.345),(0.895,0.345),(0.895,0.175),(0.725,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,0.175),(1.065,0.345),(1.235,0.345),(1.235,0.175),(1.065,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,0.175),(1.405,0.345),(1.575,0.345),(1.575,0.175),(1.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,0.175),(1.745,0.345),(1.915,0.345),(1.915,0.175),(1.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,0.175),(2.085,0.345),(2.255,0.345),(2.255,0.175),(2.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,0.175),(2.425,0.345),(2.595,0.345),(2.595,0.175),(2.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,0.175),(2.765,0.345),(2.935,0.345),(2.935,0.175),(2.765,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,0.175),(3.105,0.345),(3.275,0.345),(3.275,0.175),(3.105,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,0.175),(3.445,0.345),(3.615,0.345),(3.615,0.175),(3.445,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(0.01,0.51),(0.01,4.42),(3.99,4.42),(3.99,0.51),(4.0,0.51),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.01,5.18),(0.01,9.49),(0.0,9.49),(0.0,10.0),(4.0,10.0),(4.0,9.49),(3.99,9.49),(3.99,5.18),(0.01,5.18)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['tie_poly_w4']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(3.865,9.865),(3.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,9.655),(0.385,9.825),(0.555,9.825),(0.555,9.655),(0.385,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,9.655),(0.725,9.825),(0.895,9.825),(0.895,9.655),(0.725,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,9.655),(1.065,9.825),(1.235,9.825),(1.235,9.655),(1.065,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,9.655),(1.405,9.825),(1.575,9.825),(1.575,9.655),(1.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,9.655),(1.745,9.825),(1.915,9.825),(1.915,9.655),(1.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,9.655),(2.085,9.825),(2.255,9.825),(2.255,9.655),(2.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,9.655),(2.425,9.825),(2.595,9.825),(2.595,9.655),(2.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,9.655),(2.765,9.825),(2.935,9.825),(2.935,9.655),(2.765,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,9.655),(3.105,9.825),(3.275,9.825),(3.275,9.655),(3.105,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,9.655),(3.445,9.825),(3.615,9.825),(3.615,9.655),(3.445,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(3.865,0.385),(3.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,0.175),(0.385,0.345),(0.555,0.345),(0.555,0.175),(0.385,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,0.175),(0.725,0.345),(0.895,0.345),(0.895,0.175),(0.725,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,0.175),(1.065,0.345),(1.235,0.345),(1.235,0.175),(1.065,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,0.175),(1.405,0.345),(1.575,0.345),(1.575,0.175),(1.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,0.175),(1.745,0.345),(1.915,0.345),(1.915,0.175),(1.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,0.175),(2.085,0.345),(2.255,0.345),(2.255,0.175),(2.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,0.175),(2.425,0.345),(2.595,0.345),(2.595,0.175),(2.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,0.175),(2.765,0.345),(2.935,0.345),(2.935,0.175),(2.765,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,0.175),(3.105,0.345),(3.275,0.345),(3.275,0.175),(3.105,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,0.175),(3.445,0.345),(3.615,0.345),(3.615,0.175),(3.445,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.915,0.67),(1.915,0.84),(2.085,0.84),(2.085,0.67),(1.915,0.67)),
        )
        createRL(
            tech, net, 'poly',
            ((0.105,0.46),(0.105,9.54),(3.895,9.54),(3.895,0.46),(0.105,0.46)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(4.0,0.51),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(4.0,9.215),(4.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(4.0,4.8),(4.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(4.0,10.0),(4.0,9.49),(0.0,9.49)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['diode_w1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'i': Net.create(cell, 'i'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vdd']
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        net = nets['vss']
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        net = nets['*']
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        net = nets['i']
        createRL(
            tech, net, 'difftap',
            ((0.375,1.37),(0.375,4.46),(0.625,4.46),(0.625,1.37),(0.375,1.37)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.375,4.98),(0.375,8.63),(0.625,8.63),(0.625,4.98),(0.375,4.98)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,5.19),(0.415,5.36),(0.585,5.36),(0.585,5.19),(0.415,5.19)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,5.53),(0.415,5.7),(0.585,5.7),(0.585,5.53),(0.415,5.53)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,5.87),(0.415,6.04),(0.585,6.04),(0.585,5.87),(0.415,5.87)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,6.21),(0.415,6.38),(0.585,6.38),(0.585,6.21),(0.415,6.21)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,6.55),(0.415,6.72),(0.585,6.72),(0.585,6.55),(0.415,6.55)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,6.89),(0.415,7.06),(0.585,7.06),(0.585,6.89),(0.415,6.89)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,7.23),(0.415,7.4),(0.585,7.4),(0.585,7.23),(0.415,7.23)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,7.57),(0.415,7.74),(0.585,7.74),(0.585,7.57),(0.415,7.57)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,7.91),(0.415,8.08),(0.585,8.08),(0.585,7.91),(0.415,7.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,8.25),(0.415,8.42),(0.585,8.42),(0.585,8.25),(0.415,8.25)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,1.64),(0.415,1.81),(0.585,1.81),(0.585,1.64),(0.415,1.64)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,1.98),(0.415,2.15),(0.585,2.15),(0.585,1.98),(0.415,1.98)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,2.32),(0.415,2.49),(0.585,2.49),(0.585,2.32),(0.415,2.32)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,2.66),(0.415,2.83),(0.585,2.83),(0.585,2.66),(0.415,2.66)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,3.0),(0.415,3.17),(0.585,3.17),(0.585,3.0),(0.415,3.0)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,3.34),(0.415,3.51),(0.585,3.51),(0.585,3.34),(0.415,3.34)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,3.68),(0.415,3.85),(0.585,3.85),(0.585,3.68),(0.415,3.68)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,4.02),(0.415,4.19),(0.585,4.19),(0.585,4.02),(0.415,4.02)),
        )
        createRL(
            tech, net, 'li',
            ((0.415,1.37),(0.415,8.63),(0.585,8.63),(0.585,1.37),(0.415,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)

    cell = new_cells['zero_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'one': Net.create(cell, 'one'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
            'zero': Net.create(cell, 'zero'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.175),(0.55,4.175),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        net = nets['one']
        createRL(
            tech, net, 'difftap',
            ((0.135,5.265),(0.135,9.09),(0.4,9.09),(0.4,5.265),(0.135,5.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.365),(0.175,4.535),(0.345,4.535),(0.345,4.365),(0.175,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.535),(0.175,5.705),(0.345,5.705),(0.345,5.535),(0.175,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.875),(0.175,6.045),(0.345,6.045),(0.345,5.875),(0.175,5.875)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.215),(0.175,6.385),(0.345,6.385),(0.345,6.215),(0.175,6.215)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.555),(0.175,6.725),(0.345,6.725),(0.345,6.555),(0.175,6.555)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.895),(0.175,7.065),(0.345,7.065),(0.345,6.895),(0.175,6.895)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.235),(0.175,7.405),(0.345,7.405),(0.345,7.235),(0.175,7.235)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.575),(0.175,7.745),(0.345,7.745),(0.345,7.575),(0.175,7.575)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.915),(0.175,8.085),(0.345,8.085),(0.345,7.915),(0.175,7.915)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.255),(0.175,8.425),(0.345,8.425),(0.345,8.255),(0.175,8.255)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,4.285),(0.175,8.63),(0.345,8.63),(0.345,4.285),(0.175,4.285)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.285),(0.125,4.285),(0.125,4.615),(0.55,4.615),(0.55,0.78),(0.4,0.78)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,5.265),(0.4,9.09),(0.815,9.09),(0.815,5.265),(0.4,5.265)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['zero']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.175),(0.815,4.175),(0.815,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,4.825),(0.4,9.22),(0.55,9.22),(0.55,5.155),(0.825,5.155),(0.825,4.825),(0.4,4.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,4.905),(0.605,5.075),(0.775,5.075),(0.775,4.905),(0.605,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.465),(0.605,1.635),(0.775,1.635),(0.775,1.465),(0.605,1.465)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.805),(0.605,1.975),(0.775,1.975),(0.775,1.805),(0.605,1.805)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.145),(0.605,2.315),(0.775,2.315),(0.775,2.145),(0.605,2.145)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.485),(0.605,2.655),(0.775,2.655),(0.775,2.485),(0.605,2.485)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.825),(0.605,2.995),(0.775,2.995),(0.775,2.825),(0.605,2.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.165),(0.605,3.335),(0.775,3.335),(0.775,3.165),(0.605,3.165)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.505),(0.605,3.675),(0.775,3.675),(0.775,3.505),(0.605,3.505)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.845),(0.605,4.015),(0.775,4.015),(0.775,3.845),(0.605,3.845)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,8.63),(0.775,8.63),(0.775,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['zero'].setDirection(Net.Direction.OUT)

    cell = new_cells['one_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'one': Net.create(cell, 'one'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
            'zero': Net.create(cell, 'zero'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.175),(0.55,4.175),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        net = nets['one']
        createRL(
            tech, net, 'difftap',
            ((0.135,5.265),(0.135,9.09),(0.4,9.09),(0.4,5.265),(0.135,5.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.365),(0.175,4.535),(0.345,4.535),(0.345,4.365),(0.175,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.535),(0.175,5.705),(0.345,5.705),(0.345,5.535),(0.175,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.875),(0.175,6.045),(0.345,6.045),(0.345,5.875),(0.175,5.875)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.215),(0.175,6.385),(0.345,6.385),(0.345,6.215),(0.175,6.215)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.555),(0.175,6.725),(0.345,6.725),(0.345,6.555),(0.175,6.555)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.895),(0.175,7.065),(0.345,7.065),(0.345,6.895),(0.175,6.895)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.235),(0.175,7.405),(0.345,7.405),(0.345,7.235),(0.175,7.235)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.575),(0.175,7.745),(0.345,7.745),(0.345,7.575),(0.175,7.575)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.915),(0.175,8.085),(0.345,8.085),(0.345,7.915),(0.175,7.915)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.255),(0.175,8.425),(0.345,8.425),(0.345,8.255),(0.175,8.255)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.285),(0.125,4.285),(0.125,4.615),(0.55,4.615),(0.55,0.78),(0.4,0.78)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,5.265),(0.4,9.09),(0.815,9.09),(0.815,5.265),(0.4,5.265)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['zero']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.175),(0.815,4.175),(0.815,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,4.825),(0.4,9.22),(0.55,9.22),(0.55,5.155),(0.825,5.155),(0.825,4.825),(0.4,4.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,4.905),(0.605,5.075),(0.775,5.075),(0.775,4.905),(0.605,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.465),(0.605,1.635),(0.775,1.635),(0.775,1.465),(0.605,1.465)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.805),(0.605,1.975),(0.775,1.975),(0.775,1.805),(0.605,1.805)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.145),(0.605,2.315),(0.775,2.315),(0.775,2.145),(0.605,2.145)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.485),(0.605,2.655),(0.775,2.655),(0.775,2.485),(0.605,2.485)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.825),(0.605,2.995),(0.775,2.995),(0.775,2.825),(0.605,2.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.165),(0.605,3.335),(0.775,3.335),(0.775,3.165),(0.605,3.165)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.505),(0.605,3.675),(0.775,3.675),(0.775,3.505),(0.605,3.505)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.845),(0.605,4.015),(0.775,4.015),(0.775,3.845),(0.605,3.845)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,5.155),(0.775,5.155),(0.775,1.37),(0.605,1.37)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['one'].setDirection(Net.Direction.OUT)

    cell = new_cells['zeroone_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'one': Net.create(cell, 'one'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
            'zero': Net.create(cell, 'zero'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.175),(0.55,4.175),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        net = nets['one']
        createRL(
            tech, net, 'difftap',
            ((0.135,5.265),(0.135,9.09),(0.4,9.09),(0.4,5.265),(0.135,5.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.365),(0.175,4.535),(0.345,4.535),(0.345,4.365),(0.175,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.535),(0.175,5.705),(0.345,5.705),(0.345,5.535),(0.175,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.875),(0.175,6.045),(0.345,6.045),(0.345,5.875),(0.175,5.875)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.215),(0.175,6.385),(0.345,6.385),(0.345,6.215),(0.175,6.215)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.555),(0.175,6.725),(0.345,6.725),(0.345,6.555),(0.175,6.555)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.895),(0.175,7.065),(0.345,7.065),(0.345,6.895),(0.175,6.895)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.235),(0.175,7.405),(0.345,7.405),(0.345,7.235),(0.175,7.235)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.575),(0.175,7.745),(0.345,7.745),(0.345,7.575),(0.175,7.575)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.915),(0.175,8.085),(0.345,8.085),(0.345,7.915),(0.175,7.915)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.255),(0.175,8.425),(0.345,8.425),(0.345,8.255),(0.175,8.255)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.285),(0.125,4.285),(0.125,4.615),(0.55,4.615),(0.55,0.78),(0.4,0.78)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,5.265),(0.4,9.09),(0.815,9.09),(0.815,5.265),(0.4,5.265)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['zero']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.175),(0.815,4.175),(0.815,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,4.825),(0.4,9.22),(0.55,9.22),(0.55,5.155),(0.825,5.155),(0.825,4.825),(0.4,4.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,4.905),(0.605,5.075),(0.775,5.075),(0.775,4.905),(0.605,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.465),(0.605,1.635),(0.775,1.635),(0.775,1.465),(0.605,1.465)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.805),(0.605,1.975),(0.775,1.975),(0.775,1.805),(0.605,1.805)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.145),(0.605,2.315),(0.775,2.315),(0.775,2.145),(0.605,2.145)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.485),(0.605,2.655),(0.775,2.655),(0.775,2.485),(0.605,2.485)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.825),(0.605,2.995),(0.775,2.995),(0.775,2.825),(0.605,2.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.165),(0.605,3.335),(0.775,3.335),(0.775,3.165),(0.605,3.165)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.505),(0.605,3.675),(0.775,3.675),(0.775,3.505),(0.605,3.505)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.845),(0.605,4.015),(0.775,4.015),(0.775,3.845),(0.605,3.845)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,8.63),(0.775,8.63),(0.775,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['one'].setDirection(Net.Direction.OUT)
        nets['zero'].setDirection(Net.Direction.OUT)

    cell = new_cells['decap_w0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'one': Net.create(cell, 'one'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
            'zero': Net.create(cell, 'zero'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.175),(0.55,4.175),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        net = nets['one']
        createRL(
            tech, net, 'difftap',
            ((0.135,5.265),(0.135,9.09),(0.4,9.09),(0.4,5.265),(0.135,5.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.365),(0.175,4.535),(0.345,4.535),(0.345,4.365),(0.175,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.535),(0.175,5.705),(0.345,5.705),(0.345,5.535),(0.175,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.875),(0.175,6.045),(0.345,6.045),(0.345,5.875),(0.175,5.875)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.215),(0.175,6.385),(0.345,6.385),(0.345,6.215),(0.175,6.215)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.555),(0.175,6.725),(0.345,6.725),(0.345,6.555),(0.175,6.555)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.895),(0.175,7.065),(0.345,7.065),(0.345,6.895),(0.175,6.895)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.235),(0.175,7.405),(0.345,7.405),(0.345,7.235),(0.175,7.235)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.575),(0.175,7.745),(0.345,7.745),(0.345,7.575),(0.175,7.575)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.915),(0.175,8.085),(0.345,8.085),(0.345,7.915),(0.175,7.915)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.255),(0.175,8.425),(0.345,8.425),(0.345,8.255),(0.175,8.255)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,4.285),(0.175,8.63),(0.345,8.63),(0.345,4.285),(0.175,4.285)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.285),(0.125,4.285),(0.125,4.615),(0.55,4.615),(0.55,0.78),(0.4,0.78)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,5.265),(0.4,9.09),(0.815,9.09),(0.815,5.265),(0.4,5.265)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['zero']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.175),(0.815,4.175),(0.815,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,4.825),(0.4,9.22),(0.55,9.22),(0.55,5.155),(0.825,5.155),(0.825,4.825),(0.4,4.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,4.905),(0.605,5.075),(0.775,5.075),(0.775,4.905),(0.605,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.465),(0.605,1.635),(0.775,1.635),(0.775,1.465),(0.605,1.465)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.805),(0.605,1.975),(0.775,1.975),(0.775,1.805),(0.605,1.805)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.145),(0.605,2.315),(0.775,2.315),(0.775,2.145),(0.605,2.145)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.485),(0.605,2.655),(0.775,2.655),(0.775,2.485),(0.605,2.485)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.825),(0.605,2.995),(0.775,2.995),(0.775,2.825),(0.605,2.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.165),(0.605,3.335),(0.775,3.335),(0.775,3.165),(0.605,3.165)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.505),(0.605,3.675),(0.775,3.675),(0.775,3.505),(0.605,3.505)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.845),(0.605,4.015),(0.775,4.015),(0.775,3.845),(0.605,3.845)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,5.155),(0.775,5.155),(0.775,1.37),(0.605,1.37)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)

    cell = new_cells['inv_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'i': Net.create(cell, 'i'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.815,9.09),(0.815,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.815,1.91),(0.815,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.535),(0.605,1.705),(0.775,1.705),(0.775,1.535),(0.605,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,8.63),(0.775,8.63),(0.775,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['inv_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(1.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'i': Net.create(cell, 'i'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(0.865,0.385),(0.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,0.175),(0.415,0.345),(0.585,0.345),(0.585,0.175),(0.415,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(1.0,1.2),(1.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(1.0,4.8),(1.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(1.0,10.0),(1.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(1.0,9.215),(1.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(1.0,0.51),(1.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(0.865,9.865),(0.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(1.18,10.18),(1.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.415,9.655),(0.415,9.825),(0.585,9.825),(0.585,9.655),(0.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(1.0,10.0),(1.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.5), u(1.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.815,9.09),(0.815,4.995),(0.55,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.815,4.445),(0.815,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.225),(0.605,5.395),(0.775,5.395),(0.775,5.225),(0.605,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.565),(0.605,5.735),(0.775,5.735),(0.775,5.565),(0.605,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.905),(0.605,6.075),(0.775,6.075),(0.775,5.905),(0.605,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.245),(0.605,6.415),(0.775,6.415),(0.775,6.245),(0.605,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.585),(0.605,6.755),(0.775,6.755),(0.775,6.585),(0.605,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.925),(0.605,7.095),(0.775,7.095),(0.775,6.925),(0.605,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.265),(0.605,7.435),(0.775,7.435),(0.775,7.265),(0.605,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.605),(0.605,7.775),(0.775,7.775),(0.775,7.605),(0.605,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.945),(0.605,8.115),(0.775,8.115),(0.775,7.945),(0.605,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.285),(0.605,8.455),(0.775,8.455),(0.775,8.285),(0.605,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.605),(0.605,1.775),(0.775,1.775),(0.775,1.605),(0.605,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.945),(0.605,2.115),(0.775,2.115),(0.775,1.945),(0.605,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.285),(0.605,2.455),(0.775,2.455),(0.775,2.285),(0.605,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.625),(0.605,2.795),(0.775,2.795),(0.775,2.625),(0.605,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.965),(0.605,3.135),(0.775,3.135),(0.775,2.965),(0.605,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.305),(0.605,3.475),(0.775,3.475),(0.775,3.305),(0.605,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.645),(0.605,3.815),(0.775,3.815),(0.775,3.645),(0.605,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.985),(0.605,4.155),(0.775,4.155),(0.775,3.985),(0.605,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,8.63),(0.775,8.63),(0.775,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['inv_x2']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'i': Net.create(cell, 'i'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(1.245,4.445),(1.245,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(1.245,9.09),(1.245,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.225),(0.605,5.395),(0.775,5.395),(0.775,5.225),(0.605,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.565),(0.605,5.735),(0.775,5.735),(0.775,5.565),(0.605,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.905),(0.605,6.075),(0.775,6.075),(0.775,5.905),(0.605,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.245),(0.605,6.415),(0.775,6.415),(0.775,6.245),(0.605,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.585),(0.605,6.755),(0.775,6.755),(0.775,6.585),(0.605,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.925),(0.605,7.095),(0.775,7.095),(0.775,6.925),(0.605,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.265),(0.605,7.435),(0.775,7.435),(0.775,7.265),(0.605,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.605),(0.605,7.775),(0.775,7.775),(0.775,7.605),(0.605,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.945),(0.605,8.115),(0.775,8.115),(0.775,7.945),(0.605,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.285),(0.605,8.455),(0.775,8.455),(0.775,8.285),(0.605,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.605),(0.605,1.775),(0.775,1.775),(0.775,1.605),(0.605,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.945),(0.605,2.115),(0.775,2.115),(0.775,1.945),(0.605,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.285),(0.605,2.455),(0.775,2.455),(0.775,2.285),(0.605,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.625),(0.605,2.795),(0.775,2.795),(0.775,2.625),(0.605,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.965),(0.605,3.135),(0.775,3.135),(0.775,2.965),(0.605,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.305),(0.605,3.475),(0.775,3.475),(0.775,3.305),(0.605,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.645),(0.605,3.815),(0.775,3.815),(0.775,3.645),(0.605,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.985),(0.605,4.155),(0.775,4.155),(0.775,3.985),(0.605,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,8.63),(0.775,8.63),(0.775,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,0.78),(0.83,0.78),(0.83,4.555),(0.55,4.555),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['inv_x4']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            'i': Net.create(cell, 'i'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(1.41,4.445),(1.41,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.69,0.91),(1.69,4.445),(2.105,4.445),(2.105,0.91),(1.69,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.895,1.03),(1.895,1.2),(2.065,1.2),(2.065,1.03),(1.895,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((1.69,4.995),(1.69,9.09),(2.105,9.09),(2.105,4.995),(1.69,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(1.41,9.09),(1.41,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.895,8.8),(1.895,8.97),(2.065,8.97),(2.065,8.8),(1.895,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,4.445),(1.69,4.445),(1.69,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,4.995),(1.41,9.09),(1.69,9.09),(1.69,4.995),(1.41,4.995)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,1.605),(1.465,1.775),(1.635,1.775),(1.635,1.605),(1.465,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,1.945),(1.465,2.115),(1.635,2.115),(1.635,1.945),(1.465,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,2.285),(1.465,2.455),(1.635,2.455),(1.635,2.285),(1.465,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,2.625),(1.465,2.795),(1.635,2.795),(1.635,2.625),(1.465,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,2.965),(1.465,3.135),(1.635,3.135),(1.635,2.965),(1.465,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,3.305),(1.465,3.475),(1.635,3.475),(1.635,3.305),(1.465,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,3.645),(1.465,3.815),(1.635,3.815),(1.635,3.645),(1.465,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,3.985),(1.465,4.155),(1.635,4.155),(1.635,3.985),(1.465,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,5.225),(1.465,5.395),(1.635,5.395),(1.635,5.225),(1.465,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,5.565),(1.465,5.735),(1.635,5.735),(1.635,5.565),(1.465,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,5.905),(1.465,6.075),(1.635,6.075),(1.635,5.905),(1.465,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,6.245),(1.465,6.415),(1.635,6.415),(1.635,6.245),(1.465,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,6.585),(1.465,6.755),(1.635,6.755),(1.635,6.585),(1.465,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,6.925),(1.465,7.095),(1.635,7.095),(1.635,6.925),(1.465,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.265),(1.465,7.435),(1.635,7.435),(1.635,7.265),(1.465,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.605),(1.465,7.775),(1.635,7.775),(1.635,7.605),(1.465,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.945),(1.465,8.115),(1.635,8.115),(1.635,7.945),(1.465,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,8.285),(1.465,8.455),(1.635,8.455),(1.635,8.285),(1.465,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.225),(0.605,5.395),(0.775,5.395),(0.775,5.225),(0.605,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.565),(0.605,5.735),(0.775,5.735),(0.775,5.565),(0.605,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.905),(0.605,6.075),(0.775,6.075),(0.775,5.905),(0.605,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.245),(0.605,6.415),(0.775,6.415),(0.775,6.245),(0.605,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.585),(0.605,6.755),(0.775,6.755),(0.775,6.585),(0.605,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.925),(0.605,7.095),(0.775,7.095),(0.775,6.925),(0.605,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.265),(0.605,7.435),(0.775,7.435),(0.775,7.265),(0.605,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.605),(0.605,7.775),(0.775,7.775),(0.775,7.605),(0.605,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.945),(0.605,8.115),(0.775,8.115),(0.775,7.945),(0.605,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.285),(0.605,8.455),(0.775,8.455),(0.775,8.285),(0.605,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.605),(0.605,1.775),(0.775,1.775),(0.775,1.605),(0.605,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.945),(0.605,2.115),(0.775,2.115),(0.775,1.945),(0.605,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.285),(0.605,2.455),(0.775,2.455),(0.775,2.285),(0.605,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.625),(0.605,2.795),(0.775,2.795),(0.775,2.625),(0.605,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.965),(0.605,3.135),(0.775,3.135),(0.775,2.965),(0.605,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.305),(0.605,3.475),(0.775,3.475),(0.775,3.305),(0.605,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.645),(0.605,3.815),(0.775,3.815),(0.775,3.645),(0.605,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.985),(0.605,4.155),(0.775,4.155),(0.775,3.985),(0.605,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,8.63),(0.775,8.63),(0.775,4.885),(1.465,4.885),(1.465,8.63),(1.635,8.63),(1.635,1.37),(1.465,1.37),(1.465,4.555),(0.775,4.555),(0.775,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.69), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.69,4.885),(1.69,9.22),(1.84,9.22),(1.84,0.78),(1.69,0.78),(1.69,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78),(1.26,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78),(0.83,4.555),(0.55,4.555),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['buf_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_i_n': Net.create(cell, '_i_n'),
            'i': Net.create(cell, 'i'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_i_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((0.945,0.78),(0.945,4.555),(0.125,4.555),(0.125,4.885),(0.945,4.885),(0.945,9.22),(1.095,9.22),(1.095,0.78),(0.945,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.625,5.535),(0.625,7.09),(0.4,7.09),(0.4,9.09),(1.095,9.09),(1.095,5.535),(0.625,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.665,8.8),(0.665,8.97),(0.835,8.97),(0.835,8.8),(0.665,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.625,1.91),(0.625,3.905),(1.095,3.905),(1.095,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.665,1.03),(0.665,1.2),(0.835,1.2),(0.835,1.03),(0.665,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.345),(0.735,4.345),(0.735,4.015),(0.55,4.015),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,5.095),(0.4,9.22),(0.55,9.22),(0.55,5.425),(0.735,5.425),(0.735,5.095),(0.4,5.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,4.095),(0.515,4.265),(0.685,4.265),(0.685,4.095),(0.515,4.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.175),(0.515,5.345),(0.685,5.345),(0.685,5.175),(0.515,5.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.095,0.91),(1.095,3.905),(1.36,3.905),(1.36,0.91),(1.095,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.095,5.535),(1.095,9.09),(1.36,9.09),(1.36,5.535),(1.095,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.835),(1.15,6.005),(1.32,6.005),(1.32,5.835),(1.15,5.835)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.175),(1.15,6.345),(1.32,6.345),(1.32,6.175),(1.15,6.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.515),(1.15,6.685),(1.32,6.685),(1.32,6.515),(1.15,6.515)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.855),(1.15,7.025),(1.32,7.025),(1.32,6.855),(1.15,6.855)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.195),(1.15,7.365),(1.32,7.365),(1.32,7.195),(1.15,7.195)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.535),(1.15,7.705),(1.32,7.705),(1.32,7.535),(1.15,7.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.875),(1.15,8.045),(1.32,8.045),(1.32,7.875),(1.15,7.875)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.215),(1.15,8.385),(1.32,8.385),(1.32,8.215),(1.15,8.215)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.505),(1.15,1.675),(1.32,1.675),(1.32,1.505),(1.15,1.505)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.845),(1.15,2.015),(1.32,2.015),(1.32,1.845),(1.15,1.845)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.185),(1.15,2.355),(1.32,2.355),(1.32,2.185),(1.15,2.185)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.525),(1.15,2.695),(1.32,2.695),(1.32,2.525),(1.15,2.525)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.865),(1.15,3.035),(1.32,3.035),(1.32,2.865),(1.15,2.865)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.205),(1.15,3.375),(1.32,3.375),(1.32,3.205),(1.15,3.205)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.545),(1.15,3.715),(1.32,3.715),(1.32,3.545),(1.15,3.545)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,8.63),(1.32,8.63),(1.32,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)

    cell = new_cells['buf_x2']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_i_n': Net.create(cell, '_i_n'),
            'i': Net.create(cell, 'i'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_i_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((0.945,0.78),(0.945,4.555),(0.125,4.555),(0.125,4.885),(0.945,4.885),(0.945,9.22),(1.095,9.22),(1.095,4.885),(1.375,4.885),(1.375,9.22),(1.525,9.22),(1.525,0.78),(1.375,0.78),(1.375,4.555),(1.095,4.555),(1.095,0.78),(0.945,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,5.535),(1.375,9.09),(1.79,9.09),(1.79,5.535),(1.375,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.625,5.535),(0.625,7.09),(0.4,7.09),(0.4,9.09),(1.095,9.09),(1.095,5.535),(0.625,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.665,8.8),(0.665,8.97),(0.835,8.97),(0.835,8.8),(0.665,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,8.8),(1.58,8.97),(1.75,8.97),(1.75,8.8),(1.58,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.625,1.91),(0.625,3.905),(1.095,3.905),(1.095,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,0.91),(1.375,3.905),(1.79,3.905),(1.79,0.91),(1.375,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,1.03),(1.58,1.2),(1.75,1.2),(1.75,1.03),(1.58,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.665,1.03),(0.665,1.2),(0.835,1.2),(0.835,1.03),(0.665,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.345),(0.735,4.345),(0.735,4.015),(0.55,4.015),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,5.095),(0.4,9.22),(0.55,9.22),(0.55,5.425),(0.735,5.425),(0.735,5.095),(0.4,5.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,4.095),(0.515,4.265),(0.685,4.265),(0.685,4.095),(0.515,4.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.175),(0.515,5.345),(0.685,5.345),(0.685,5.175),(0.515,5.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.095,0.91),(1.095,3.905),(1.375,3.905),(1.375,0.91),(1.095,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.095,5.535),(1.095,9.09),(1.375,9.09),(1.375,5.535),(1.095,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.835),(1.15,6.005),(1.32,6.005),(1.32,5.835),(1.15,5.835)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.175),(1.15,6.345),(1.32,6.345),(1.32,6.175),(1.15,6.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.515),(1.15,6.685),(1.32,6.685),(1.32,6.515),(1.15,6.515)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.855),(1.15,7.025),(1.32,7.025),(1.32,6.855),(1.15,6.855)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.195),(1.15,7.365),(1.32,7.365),(1.32,7.195),(1.15,7.195)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.535),(1.15,7.705),(1.32,7.705),(1.32,7.535),(1.15,7.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.875),(1.15,8.045),(1.32,8.045),(1.32,7.875),(1.15,7.875)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.215),(1.15,8.385),(1.32,8.385),(1.32,8.215),(1.15,8.215)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.505),(1.15,1.675),(1.32,1.675),(1.32,1.505),(1.15,1.505)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.845),(1.15,2.015),(1.32,2.015),(1.32,1.845),(1.15,1.845)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.185),(1.15,2.355),(1.32,2.355),(1.32,2.185),(1.15,2.185)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.525),(1.15,2.695),(1.32,2.695),(1.32,2.525),(1.15,2.525)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.865),(1.15,3.035),(1.32,3.035),(1.32,2.865),(1.15,2.865)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.205),(1.15,3.375),(1.32,3.375),(1.32,3.205),(1.15,3.205)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.545),(1.15,3.715),(1.32,3.715),(1.32,3.545),(1.15,3.545)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,8.63),(1.32,8.63),(1.32,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)

    cell = new_cells['buf_x4']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_i_n': Net.create(cell, '_i_n'),
            'i': Net.create(cell, 'i'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_i_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,5.535),(0.135,9.09),(0.4,9.09),(0.4,5.535),(0.135,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,3.905),(0.4,3.905),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.835),(0.175,6.005),(0.345,6.005),(0.345,5.835),(0.175,5.835)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.175),(0.175,6.345),(0.345,6.345),(0.345,6.175),(0.175,6.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.515),(0.175,6.685),(0.345,6.685),(0.345,6.515),(0.175,6.515)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.855),(0.175,7.025),(0.345,7.025),(0.345,6.855),(0.175,6.855)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.195),(0.175,7.365),(0.345,7.365),(0.345,7.195),(0.175,7.195)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.535),(0.175,7.705),(0.345,7.705),(0.345,7.535),(0.175,7.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.875),(0.175,8.045),(0.345,8.045),(0.345,7.875),(0.175,7.875)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.215),(0.175,8.385),(0.345,8.385),(0.345,8.215),(0.175,8.215)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.505),(0.175,1.675),(0.345,1.675),(0.345,1.505),(0.175,1.505)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.845),(0.175,2.015),(0.345,2.015),(0.345,1.845),(0.175,1.845)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.185),(0.175,2.355),(0.345,2.355),(0.345,2.185),(0.175,2.185)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.525),(0.175,2.695),(0.345,2.695),(0.345,2.525),(0.175,2.525)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.865),(0.175,3.035),(0.345,3.035),(0.345,2.865),(0.175,2.865)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.205),(0.175,3.375),(0.345,3.375),(0.345,3.205),(0.175,3.205)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.545),(0.175,3.715),(0.345,3.715),(0.345,3.545),(0.175,3.545)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((0.945,0.78),(0.945,4.555),(0.125,4.555),(0.125,4.885),(0.945,4.885),(0.945,9.22),(1.095,9.22),(1.095,4.885),(1.375,4.885),(1.375,9.22),(1.525,9.22),(1.525,4.885),(1.805,4.885),(1.805,9.22),(1.955,9.22),(1.955,4.885),(2.235,4.885),(2.235,9.22),(2.385,9.22),(2.385,0.78),(2.235,0.78),(2.235,4.555),(1.955,4.555),(1.955,0.78),(1.805,0.78),(1.805,4.555),(1.525,4.555),(1.525,0.78),(1.375,0.78),(1.375,4.555),(1.095,4.555),(1.095,0.78),(0.945,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.235,5.535),(2.235,9.09),(2.65,9.09),(2.65,5.535),(2.235,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,5.535),(0.4,9.09),(1.095,9.09),(1.095,5.535),(0.4,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,5.535),(1.375,9.09),(1.955,9.09),(1.955,5.535),(1.375,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,8.8),(1.58,8.97),(1.75,8.97),(1.75,8.8),(1.58,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.44,8.8),(2.44,8.97),(2.61,8.97),(2.61,8.8),(2.44,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,3.905),(1.095,3.905),(1.095,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.235,0.91),(2.235,3.905),(2.65,3.905),(2.65,0.91),(2.235,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,0.91),(1.375,3.905),(1.955,3.905),(1.955,0.91),(1.375,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,1.03),(1.58,1.2),(1.75,1.2),(1.75,1.03),(1.58,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.44,1.03),(2.44,1.2),(2.61,1.2),(2.61,1.03),(2.44,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.345),(0.735,4.345),(0.735,4.015),(0.55,4.015),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,5.095),(0.4,9.22),(0.55,9.22),(0.55,5.425),(0.735,5.425),(0.735,5.095),(0.4,5.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,4.095),(0.515,4.265),(0.685,4.265),(0.685,4.095),(0.515,4.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.175),(0.515,5.345),(0.685,5.345),(0.685,5.175),(0.515,5.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.095,0.91),(1.095,3.905),(1.375,3.905),(1.375,0.91),(1.095,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.955,0.91),(1.955,3.905),(2.235,3.905),(2.235,0.91),(1.955,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.095,5.535),(1.095,9.09),(1.375,9.09),(1.375,5.535),(1.095,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.955,5.535),(1.955,9.09),(2.235,9.09),(2.235,5.535),(1.955,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.835),(1.15,6.005),(1.32,6.005),(1.32,5.835),(1.15,5.835)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.175),(1.15,6.345),(1.32,6.345),(1.32,6.175),(1.15,6.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.515),(1.15,6.685),(1.32,6.685),(1.32,6.515),(1.15,6.515)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.855),(1.15,7.025),(1.32,7.025),(1.32,6.855),(1.15,6.855)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.195),(1.15,7.365),(1.32,7.365),(1.32,7.195),(1.15,7.195)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.535),(1.15,7.705),(1.32,7.705),(1.32,7.535),(1.15,7.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.875),(1.15,8.045),(1.32,8.045),(1.32,7.875),(1.15,7.875)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.215),(1.15,8.385),(1.32,8.385),(1.32,8.215),(1.15,8.215)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,5.835),(2.01,6.005),(2.18,6.005),(2.18,5.835),(2.01,5.835)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,6.175),(2.01,6.345),(2.18,6.345),(2.18,6.175),(2.01,6.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,6.515),(2.01,6.685),(2.18,6.685),(2.18,6.515),(2.01,6.515)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,6.855),(2.01,7.025),(2.18,7.025),(2.18,6.855),(2.01,6.855)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,7.195),(2.01,7.365),(2.18,7.365),(2.18,7.195),(2.01,7.195)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,7.535),(2.01,7.705),(2.18,7.705),(2.18,7.535),(2.01,7.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,7.875),(2.01,8.045),(2.18,8.045),(2.18,7.875),(2.01,7.875)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,8.215),(2.01,8.385),(2.18,8.385),(2.18,8.215),(2.01,8.215)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.505),(1.15,1.675),(1.32,1.675),(1.32,1.505),(1.15,1.505)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.845),(1.15,2.015),(1.32,2.015),(1.32,1.845),(1.15,1.845)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.185),(1.15,2.355),(1.32,2.355),(1.32,2.185),(1.15,2.185)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.525),(1.15,2.695),(1.32,2.695),(1.32,2.525),(1.15,2.525)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.865),(1.15,3.035),(1.32,3.035),(1.32,2.865),(1.15,2.865)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.205),(1.15,3.375),(1.32,3.375),(1.32,3.205),(1.15,3.205)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.545),(1.15,3.715),(1.32,3.715),(1.32,3.545),(1.15,3.545)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,1.505),(2.01,1.675),(2.18,1.675),(2.18,1.505),(2.01,1.505)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,1.845),(2.01,2.015),(2.18,2.015),(2.18,1.845),(2.01,1.845)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,2.185),(2.01,2.355),(2.18,2.355),(2.18,2.185),(2.01,2.185)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,2.525),(2.01,2.695),(2.18,2.695),(2.18,2.525),(2.01,2.525)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,2.865),(2.01,3.035),(2.18,3.035),(2.18,2.865),(2.01,2.865)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,3.205),(2.01,3.375),(2.18,3.375),(2.18,3.205),(2.01,3.205)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,3.545),(2.01,3.715),(2.18,3.715),(2.18,3.545),(2.01,3.545)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,8.63),(1.32,8.63),(1.32,4.885),(2.01,4.885),(2.01,8.63),(2.18,8.63),(2.18,1.37),(2.01,1.37),(2.01,4.555),(1.32,4.555),(1.32,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)

    cell = new_cells['nand2_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(0.98,1.91),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(1.36,9.09),(1.36,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.8),(1.15,8.97),(1.32,8.97),(1.32,8.8),(1.15,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.36,1.91),(1.36,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.535),(1.15,1.705),(1.32,1.705),(1.32,1.535),(1.15,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,7.205),(0.605,7.205),(0.605,8.63),(1.32,8.63),(1.32,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,7.035),(0.98,7.035),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)

    cell = new_cells['nand2_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(0.98,4.445),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(1.36,9.09),(1.36,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.8),(1.15,8.97),(1.32,8.97),(1.32,8.8),(1.15,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,4.445),(1.36,4.445),(1.36,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.605),(1.15,1.775),(1.32,1.775),(1.32,1.605),(1.15,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.945),(1.15,2.115),(1.32,2.115),(1.32,1.945),(1.15,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.285),(1.15,2.455),(1.32,2.455),(1.32,2.285),(1.15,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.625),(1.15,2.795),(1.32,2.795),(1.32,2.625),(1.15,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.965),(1.15,3.135),(1.32,3.135),(1.32,2.965),(1.15,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.305),(1.15,3.475),(1.32,3.475),(1.32,3.305),(1.15,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.645),(1.15,3.815),(1.32,3.815),(1.32,3.645),(1.15,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.985),(1.15,4.155),(1.32,4.155),(1.32,3.985),(1.15,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.225),(0.605,5.395),(0.775,5.395),(0.775,5.225),(0.605,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.565),(0.605,5.735),(0.775,5.735),(0.775,5.565),(0.605,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.905),(0.605,6.075),(0.775,6.075),(0.775,5.905),(0.605,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.245),(0.605,6.415),(0.775,6.415),(0.775,6.245),(0.605,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.585),(0.605,6.755),(0.775,6.755),(0.775,6.585),(0.605,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.925),(0.605,7.095),(0.775,7.095),(0.775,6.925),(0.605,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.265),(0.605,7.435),(0.775,7.435),(0.775,7.265),(0.605,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.605),(0.605,7.775),(0.775,7.775),(0.775,7.605),(0.605,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.945),(0.605,8.115),(0.775,8.115),(0.775,7.945),(0.605,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.285),(0.605,8.455),(0.775,8.455),(0.775,8.285),(0.605,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,5.055),(0.605,5.055),(0.605,8.63),(1.32,8.63),(1.32,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,4.885),(0.98,4.885),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)

    cell = new_cells['nand3_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.41,1.91),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(0.98,1.91),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(1.41,9.09),(1.41,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.84,1.91),(1.84,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,7.09),(1.41,9.09),(1.84,9.09),(1.84,7.09),(1.41,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.285),(1.63,7.455),(1.8,7.455),(1.8,7.285),(1.63,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.625),(1.63,7.795),(1.8,7.795),(1.8,7.625),(1.63,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.965),(1.63,8.135),(1.8,8.135),(1.8,7.965),(1.63,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,8.305),(1.63,8.475),(1.8,8.475),(1.8,8.305),(1.63,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.535),(1.63,1.705),(1.8,1.705),(1.8,1.535),(1.63,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((1.63,1.37),(1.63,7.205),(0.605,7.205),(0.605,8.63),(1.8,8.63),(1.8,1.37),(1.63,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,7.035),(0.98,7.035),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.37),(1.29,7.035),(1.46,7.035),(1.46,1.37),(1.29,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['nand3_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(0.98,4.445),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,4.445),(1.41,4.445),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(1.41,9.09),(1.41,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.41,4.995),(1.41,9.09),(1.84,9.09),(1.84,4.995),(1.41,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,4.445),(1.84,4.445),(1.84,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.225),(1.63,5.395),(1.8,5.395),(1.8,5.225),(1.63,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.565),(1.63,5.735),(1.8,5.735),(1.8,5.565),(1.63,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.905),(1.63,6.075),(1.8,6.075),(1.8,5.905),(1.63,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.245),(1.63,6.415),(1.8,6.415),(1.8,6.245),(1.63,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.585),(1.63,6.755),(1.8,6.755),(1.8,6.585),(1.63,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.925),(1.63,7.095),(1.8,7.095),(1.8,6.925),(1.63,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.265),(1.63,7.435),(1.8,7.435),(1.8,7.265),(1.63,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.605),(1.63,7.775),(1.8,7.775),(1.8,7.605),(1.63,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.945),(1.63,8.115),(1.8,8.115),(1.8,7.945),(1.63,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,8.285),(1.63,8.455),(1.8,8.455),(1.8,8.285),(1.63,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.605),(1.63,1.775),(1.8,1.775),(1.8,1.605),(1.63,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.945),(1.63,2.115),(1.8,2.115),(1.8,1.945),(1.63,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.285),(1.63,2.455),(1.8,2.455),(1.8,2.285),(1.63,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.625),(1.63,2.795),(1.8,2.795),(1.8,2.625),(1.63,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.965),(1.63,3.135),(1.8,3.135),(1.8,2.965),(1.63,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.305),(1.63,3.475),(1.8,3.475),(1.8,3.305),(1.63,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.645),(1.63,3.815),(1.8,3.815),(1.8,3.645),(1.63,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.985),(1.63,4.155),(1.8,4.155),(1.8,3.985),(1.63,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.225),(0.605,5.395),(0.775,5.395),(0.775,5.225),(0.605,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.565),(0.605,5.735),(0.775,5.735),(0.775,5.565),(0.605,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.905),(0.605,6.075),(0.775,6.075),(0.775,5.905),(0.605,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.245),(0.605,6.415),(0.775,6.415),(0.775,6.245),(0.605,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.585),(0.605,6.755),(0.775,6.755),(0.775,6.585),(0.605,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.925),(0.605,7.095),(0.775,7.095),(0.775,6.925),(0.605,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.265),(0.605,7.435),(0.775,7.435),(0.775,7.265),(0.605,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.605),(0.605,7.775),(0.775,7.775),(0.775,7.605),(0.605,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.945),(0.605,8.115),(0.775,8.115),(0.775,7.945),(0.605,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.285),(0.605,8.455),(0.775,8.455),(0.775,8.285),(0.605,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((1.63,1.37),(1.63,5.055),(0.605,5.055),(0.605,8.63),(1.8,8.63),(1.8,1.37),(1.63,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,4.885),(0.98,4.885),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,4.445),(1.26,4.445),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.37),(1.29,4.885),(1.46,4.885),(1.46,1.37),(1.29,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['nand4_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'i3': Net.create(cell, 'i3'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,0.91),(1.72,1.91),(1.87,1.91),(1.87,0.91),(1.72,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(0.98,1.91),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.41,1.91),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,7.09),(1.72,9.09),(2.32,9.09),(2.32,7.09),(1.72,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(1.41,9.09),(1.41,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,8.8),(2.11,8.97),(2.28,8.97),(2.28,8.8),(2.11,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.41,7.09),(1.41,9.09),(1.72,9.09),(1.72,7.09),(1.41,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.87,0.91),(1.87,1.91),(2.32,1.91),(2.32,0.91),(1.87,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.535),(2.11,1.705),(2.28,1.705),(2.28,1.535),(2.11,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.285),(1.465,7.455),(1.635,7.455),(1.635,7.285),(1.465,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.625),(1.465,7.795),(1.635,7.795),(1.635,7.625),(1.465,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.965),(1.465,8.135),(1.635,8.135),(1.635,7.965),(1.465,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,8.305),(1.465,8.475),(1.635,8.475),(1.635,8.305),(1.465,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((2.11,1.37),(2.11,7.205),(0.605,7.205),(0.605,8.63),(2.28,8.63),(2.28,1.37),(2.11,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,7.035),(0.98,7.035),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.72,1.91),(1.72,0.91),(1.41,0.91)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.37),(1.29,7.035),(1.46,7.035),(1.46,1.37),(1.29,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i3']
        createRL(
            tech, net, 'poly',
            ((1.72,0.78),(1.72,9.22),(1.87,9.22),(1.87,4.885),(1.99,4.885),(1.99,4.555),(1.87,4.555),(1.87,0.78),(1.72,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.77,1.37),(1.77,7.035),(1.94,7.035),(1.94,1.37),(1.77,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.855), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.855), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)
        nets['i3'].setDirection(Net.Direction.IN)

    cell = new_cells['nand4_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'i3': Net.create(cell, 'i3'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(0.98,4.445),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,4.445),(1.41,4.445),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,0.91),(1.72,4.445),(1.87,4.445),(1.87,0.91),(1.72,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(1.41,9.09),(1.41,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,4.995),(1.72,9.09),(2.32,9.09),(2.32,4.995),(1.72,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,8.8),(2.11,8.97),(2.28,8.97),(2.28,8.8),(2.11,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,4.995),(1.41,9.09),(1.72,9.09),(1.72,4.995),(1.41,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.87,0.91),(1.87,4.445),(2.32,4.445),(2.32,0.91),(1.87,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,5.225),(1.465,5.395),(1.635,5.395),(1.635,5.225),(1.465,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,5.565),(1.465,5.735),(1.635,5.735),(1.635,5.565),(1.465,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,5.905),(1.465,6.075),(1.635,6.075),(1.635,5.905),(1.465,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,6.245),(1.465,6.415),(1.635,6.415),(1.635,6.245),(1.465,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,6.585),(1.465,6.755),(1.635,6.755),(1.635,6.585),(1.465,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,6.925),(1.465,7.095),(1.635,7.095),(1.635,6.925),(1.465,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.265),(1.465,7.435),(1.635,7.435),(1.635,7.265),(1.465,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.605),(1.465,7.775),(1.635,7.775),(1.635,7.605),(1.465,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.945),(1.465,8.115),(1.635,8.115),(1.635,7.945),(1.465,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,8.285),(1.465,8.455),(1.635,8.455),(1.635,8.285),(1.465,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.605),(2.11,1.775),(2.28,1.775),(2.28,1.605),(2.11,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.945),(2.11,2.115),(2.28,2.115),(2.28,1.945),(2.11,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.285),(2.11,2.455),(2.28,2.455),(2.28,2.285),(2.11,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.625),(2.11,2.795),(2.28,2.795),(2.28,2.625),(2.11,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.965),(2.11,3.135),(2.28,3.135),(2.28,2.965),(2.11,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.305),(2.11,3.475),(2.28,3.475),(2.28,3.305),(2.11,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.645),(2.11,3.815),(2.28,3.815),(2.28,3.645),(2.11,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.985),(2.11,4.155),(2.28,4.155),(2.28,3.985),(2.11,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.225),(0.605,5.395),(0.775,5.395),(0.775,5.225),(0.605,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.565),(0.605,5.735),(0.775,5.735),(0.775,5.565),(0.605,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.905),(0.605,6.075),(0.775,6.075),(0.775,5.905),(0.605,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.245),(0.605,6.415),(0.775,6.415),(0.775,6.245),(0.605,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.585),(0.605,6.755),(0.775,6.755),(0.775,6.585),(0.605,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.925),(0.605,7.095),(0.775,7.095),(0.775,6.925),(0.605,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.265),(0.605,7.435),(0.775,7.435),(0.775,7.265),(0.605,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.605),(0.605,7.775),(0.775,7.775),(0.775,7.605),(0.605,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.945),(0.605,8.115),(0.775,8.115),(0.775,7.945),(0.605,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.285),(0.605,8.455),(0.775,8.455),(0.775,8.285),(0.605,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((2.11,1.37),(2.11,5.055),(0.605,5.055),(0.605,8.63),(2.28,8.63),(2.28,1.37),(2.11,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,4.885),(0.98,4.885),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,4.445),(1.26,4.445),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,4.445),(1.72,4.445),(1.72,0.91),(1.41,0.91)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.37),(1.29,4.885),(1.46,4.885),(1.46,1.37),(1.29,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i3']
        createRL(
            tech, net, 'poly',
            ((1.72,0.78),(1.72,9.22),(1.87,9.22),(1.87,4.885),(1.99,4.885),(1.99,4.555),(1.87,4.555),(1.87,0.78),(1.72,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.77,1.37),(1.77,4.885),(1.94,4.885),(1.94,1.37),(1.77,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.855), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.855), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)
        nets['i3'].setDirection(Net.Direction.IN)

    cell = new_cells['and2_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'nq': Net.create(cell, 'nq'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,1.785),(1.29,1.785),(1.29,7.205),(0.605,7.205),(0.605,8.63),(1.375,8.63),(1.375,7.535),(1.46,7.535),(1.46,1.455),(1.375,1.455),(1.375,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.32,0.78),(1.32,4.555),(1.24,4.555),(1.24,4.885),(1.32,4.885),(1.32,9.22),(1.47,9.22),(1.47,4.885),(1.51,4.885),(1.51,4.555),(1.47,4.555),(1.47,0.78),(1.32,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.055,4.995),(1.055,7.09),(0.83,7.09),(0.83,9.09),(1.47,9.09),(1.47,4.995),(1.055,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.095,8.8),(1.095,8.97),(1.265,8.97),(1.265,8.8),(1.095,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.055,1.91),(1.055,4.445),(1.47,4.445),(1.47,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.55,1.91),(0.55,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.095,1.03),(1.095,1.2),(1.265,1.2),(1.265,1.03),(1.095,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.955),(0.175,8.63),(0.345,8.63),(0.345,1.955),(0.175,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,7.035),(0.98,7.035),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.47,4.995),(1.47,9.09),(1.84,9.09),(1.84,4.995),(1.47,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.47,0.91),(1.47,4.445),(1.84,4.445),(1.84,0.91),(1.47,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.225),(1.63,5.395),(1.8,5.395),(1.8,5.225),(1.63,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.565),(1.63,5.735),(1.8,5.735),(1.8,5.565),(1.63,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.905),(1.63,6.075),(1.8,6.075),(1.8,5.905),(1.63,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.245),(1.63,6.415),(1.8,6.415),(1.8,6.245),(1.63,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.585),(1.63,6.755),(1.8,6.755),(1.8,6.585),(1.63,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.925),(1.63,7.095),(1.8,7.095),(1.8,6.925),(1.63,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.265),(1.63,7.435),(1.8,7.435),(1.8,7.265),(1.63,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.605),(1.63,7.775),(1.8,7.775),(1.8,7.605),(1.63,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.945),(1.63,8.115),(1.8,8.115),(1.8,7.945),(1.63,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,8.285),(1.63,8.455),(1.8,8.455),(1.8,8.285),(1.63,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.605),(1.63,1.775),(1.8,1.775),(1.8,1.605),(1.63,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.945),(1.63,2.115),(1.8,2.115),(1.8,1.945),(1.63,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.285),(1.63,2.455),(1.8,2.455),(1.8,2.285),(1.63,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.625),(1.63,2.795),(1.8,2.795),(1.8,2.625),(1.63,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.965),(1.63,3.135),(1.8,3.135),(1.8,2.965),(1.63,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.305),(1.63,3.475),(1.8,3.475),(1.8,3.305),(1.63,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.645),(1.63,3.815),(1.8,3.815),(1.8,3.645),(1.63,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.985),(1.63,4.155),(1.8,4.155),(1.8,3.985),(1.63,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((1.63,1.37),(1.63,8.63),(1.8,8.63),(1.8,1.37),(1.63,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)

    cell = new_cells['and3_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.285),(1.035,7.455),(1.205,7.455),(1.205,7.285),(1.035,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.625),(1.035,7.795),(1.205,7.795),(1.205,7.625),(1.035,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.965),(1.035,8.135),(1.205,8.135),(1.205,7.965),(1.035,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.305),(1.035,8.475),(1.205,8.475),(1.205,8.305),(1.035,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,1.785),(1.77,1.785),(1.77,7.205),(0.175,7.205),(0.175,8.63),(1.855,8.63),(1.855,7.535),(1.94,7.535),(1.94,1.455),(1.855,1.455),(1.855,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.75,0.78),(1.75,4.555),(1.72,4.555),(1.72,4.885),(1.75,4.885),(1.75,9.22),(1.9,9.22),(1.9,4.885),(1.99,4.885),(1.99,4.555),(1.9,4.555),(1.9,0.78),(1.75,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.485,4.995),(1.485,7.09),(1.26,7.09),(1.26,9.09),(1.9,9.09),(1.9,4.995),(1.485,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.98,9.09),(0.98,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,8.8),(1.525,8.97),(1.695,8.97),(1.695,8.8),(1.525,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.485,1.91),(1.485,4.445),(1.9,4.445),(1.9,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.55,1.91),(0.55,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(0.98,1.91),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,1.03),(1.525,1.2),(1.695,1.2),(1.695,1.03),(1.525,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.955),(0.175,7.035),(0.345,7.035),(0.345,1.955),(0.175,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,7.035),(0.98,7.035),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.955),(1.29,7.035),(1.46,7.035),(1.46,1.955),(1.29,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.9,4.995),(1.9,9.09),(2.32,9.09),(2.32,4.995),(1.9,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.9,0.91),(1.9,4.445),(2.32,4.445),(2.32,0.91),(1.9,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.225),(2.11,5.395),(2.28,5.395),(2.28,5.225),(2.11,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.565),(2.11,5.735),(2.28,5.735),(2.28,5.565),(2.11,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.905),(2.11,6.075),(2.28,6.075),(2.28,5.905),(2.11,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.245),(2.11,6.415),(2.28,6.415),(2.28,6.245),(2.11,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.585),(2.11,6.755),(2.28,6.755),(2.28,6.585),(2.11,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.925),(2.11,7.095),(2.28,7.095),(2.28,6.925),(2.11,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.265),(2.11,7.435),(2.28,7.435),(2.28,7.265),(2.11,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.605),(2.11,7.775),(2.28,7.775),(2.28,7.605),(2.11,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.945),(2.11,8.115),(2.28,8.115),(2.28,7.945),(2.11,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,8.285),(2.11,8.455),(2.28,8.455),(2.28,8.285),(2.11,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.605),(2.11,1.775),(2.28,1.775),(2.28,1.605),(2.11,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.945),(2.11,2.115),(2.28,2.115),(2.28,1.945),(2.11,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.285),(2.11,2.455),(2.28,2.455),(2.28,2.285),(2.11,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.625),(2.11,2.795),(2.28,2.795),(2.28,2.625),(2.11,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.965),(2.11,3.135),(2.28,3.135),(2.28,2.965),(2.11,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.305),(2.11,3.475),(2.28,3.475),(2.28,3.305),(2.11,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.645),(2.11,3.815),(2.28,3.815),(2.28,3.645),(2.11,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.985),(2.11,4.155),(2.28,4.155),(2.28,3.985),(2.11,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((2.11,1.37),(2.11,8.63),(2.28,8.63),(2.28,1.37),(2.11,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['and4_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'i3': Net.create(cell, 'i3'),
            'nq': Net.create(cell, 'nq'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,7.09),(1.41,9.09),(1.72,9.09),(1.72,7.09),(1.41,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.25,4.635),(2.25,4.805),(2.42,4.805),(2.42,4.635),(2.25,4.635)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.285),(1.465,7.455),(1.635,7.455),(1.635,7.285),(1.465,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.625),(1.465,7.795),(1.635,7.795),(1.635,7.625),(1.465,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,7.965),(1.465,8.135),(1.635,8.135),(1.635,7.965),(1.465,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,8.305),(1.465,8.475),(1.635,8.475),(1.635,8.305),(1.465,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,1.785),(2.25,1.785),(2.25,7.205),(0.605,7.205),(0.605,8.63),(2.335,8.63),(2.335,7.535),(2.42,7.535),(2.42,1.455),(2.335,1.455),(2.335,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((2.21,0.78),(2.21,4.555),(2.2,4.555),(2.2,4.885),(2.21,4.885),(2.21,9.22),(2.36,9.22),(2.36,4.885),(2.47,4.885),(2.47,4.555),(2.36,4.555),(2.36,0.78),(2.21,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((1.945,4.995),(1.945,7.09),(1.72,7.09),(1.72,9.09),(2.36,9.09),(2.36,4.995),(1.945,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(1.41,9.09),(1.41,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.985,8.8),(1.985,8.97),(2.155,8.97),(2.155,8.8),(1.985,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(0.98,1.91),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.41,1.91),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,0.91),(1.72,1.91),(1.945,1.91),(1.945,4.445),(2.36,4.445),(2.36,0.91),(1.72,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.55,1.91),(0.55,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.985,1.03),(1.985,1.2),(2.155,1.2),(2.155,1.03),(1.985,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.955),(0.175,8.63),(0.345,8.63),(0.345,1.955),(0.175,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,7.035),(0.98,7.035),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.72,1.91),(1.72,0.91),(1.41,0.91)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.955),(1.29,7.035),(1.46,7.035),(1.46,1.955),(1.29,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i3']
        createRL(
            tech, net, 'poly',
            ((1.72,0.78),(1.72,9.22),(1.87,9.22),(1.87,4.885),(1.99,4.885),(1.99,4.555),(1.87,4.555),(1.87,0.78),(1.72,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.77,1.955),(1.77,7.035),(1.94,7.035),(1.94,1.955),(1.77,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.855), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.855), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((2.36,4.995),(2.36,9.09),(2.8,9.09),(2.8,4.995),(2.36,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.36,0.91),(2.36,4.445),(2.8,4.445),(2.8,0.91),(2.36,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,1.605),(2.59,1.775),(2.76,1.775),(2.76,1.605),(2.59,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,1.945),(2.59,2.115),(2.76,2.115),(2.76,1.945),(2.59,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,2.285),(2.59,2.455),(2.76,2.455),(2.76,2.285),(2.59,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,2.625),(2.59,2.795),(2.76,2.795),(2.76,2.625),(2.59,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,2.965),(2.59,3.135),(2.76,3.135),(2.76,2.965),(2.59,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,3.305),(2.59,3.475),(2.76,3.475),(2.76,3.305),(2.59,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,3.645),(2.59,3.815),(2.76,3.815),(2.76,3.645),(2.59,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,3.985),(2.59,4.155),(2.76,4.155),(2.76,3.985),(2.59,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,5.225),(2.59,5.395),(2.76,5.395),(2.76,5.225),(2.59,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,5.565),(2.59,5.735),(2.76,5.735),(2.76,5.565),(2.59,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,5.905),(2.59,6.075),(2.76,6.075),(2.76,5.905),(2.59,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,6.245),(2.59,6.415),(2.76,6.415),(2.76,6.245),(2.59,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,6.585),(2.59,6.755),(2.76,6.755),(2.76,6.585),(2.59,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,6.925),(2.59,7.095),(2.76,7.095),(2.76,6.925),(2.59,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,7.265),(2.59,7.435),(2.76,7.435),(2.76,7.265),(2.59,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,7.605),(2.59,7.775),(2.76,7.775),(2.76,7.605),(2.59,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,7.945),(2.59,8.115),(2.76,8.115),(2.76,7.945),(2.59,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,8.285),(2.59,8.455),(2.76,8.455),(2.76,8.285),(2.59,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((2.59,1.37),(2.59,8.63),(2.76,8.63),(2.76,1.37),(2.59,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.675), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.675), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)
        nets['i3'].setDirection(Net.Direction.IN)

    cell = new_cells['nor2_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.36,1.91),(1.36,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.03),(1.15,1.2),(1.32,1.2),(1.32,1.03),(1.15,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(0.98,9.09),(0.98,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.36,9.09),(1.36,7.09),(0.98,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.285),(1.15,7.455),(1.32,7.455),(1.32,7.285),(1.15,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.625),(1.15,7.795),(1.32,7.795),(1.32,7.625),(1.15,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.965),(1.15,8.135),(1.32,8.135),(1.32,7.965),(1.15,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.305),(1.15,8.475),(1.32,8.475),(1.32,8.305),(1.15,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.535),(0.605,1.705),(0.775,1.705),(0.775,1.535),(0.605,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,1.785),(1.15,1.785),(1.15,8.63),(1.32,8.63),(1.32,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,8.63),(0.98,8.63),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)

    cell = new_cells['nor2_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(1.36,4.445),(1.36,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.03),(1.15,1.2),(1.32,1.2),(1.32,1.03),(1.15,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(0.98,9.09),(0.98,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.98,4.995),(0.98,9.09),(1.36,9.09),(1.36,4.995),(0.98,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.225),(1.15,5.395),(1.32,5.395),(1.32,5.225),(1.15,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.565),(1.15,5.735),(1.32,5.735),(1.32,5.565),(1.15,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.905),(1.15,6.075),(1.32,6.075),(1.32,5.905),(1.15,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.245),(1.15,6.415),(1.32,6.415),(1.32,6.245),(1.15,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.585),(1.15,6.755),(1.32,6.755),(1.32,6.585),(1.15,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.925),(1.15,7.095),(1.32,7.095),(1.32,6.925),(1.15,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.265),(1.15,7.435),(1.32,7.435),(1.32,7.265),(1.15,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.605),(1.15,7.775),(1.32,7.775),(1.32,7.605),(1.15,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.945),(1.15,8.115),(1.32,8.115),(1.32,7.945),(1.15,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.285),(1.15,8.455),(1.32,8.455),(1.32,8.285),(1.15,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.605),(0.605,1.775),(0.775,1.775),(0.775,1.605),(0.605,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.945),(0.605,2.115),(0.775,2.115),(0.775,1.945),(0.605,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.285),(0.605,2.455),(0.775,2.455),(0.775,2.285),(0.605,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.625),(0.605,2.795),(0.775,2.795),(0.775,2.625),(0.605,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.965),(0.605,3.135),(0.775,3.135),(0.775,2.965),(0.605,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.305),(0.605,3.475),(0.775,3.475),(0.775,3.305),(0.605,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.645),(0.605,3.815),(0.775,3.815),(0.775,3.645),(0.605,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.985),(0.605,4.155),(0.775,4.155),(0.775,3.985),(0.605,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,4.385),(1.15,4.385),(1.15,8.63),(1.32,8.63),(1.32,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.235), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,4.555),(0.81,8.63),(0.98,8.63),(0.98,4.555),(0.81,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)

    cell = new_cells['nor3_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.41,1.91),(1.41,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(0.98,9.09),(0.98,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,7.09),(1.26,9.09),(1.41,9.09),(1.41,7.09),(1.26,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.84,1.91),(1.84,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,7.09),(1.41,9.09),(1.84,9.09),(1.84,7.09),(1.41,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.535),(0.605,1.705),(0.775,1.705),(0.775,1.535),(0.605,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.285),(1.63,7.455),(1.8,7.455),(1.8,7.285),(1.63,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.625),(1.63,7.795),(1.8,7.795),(1.8,7.625),(1.63,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.965),(1.63,8.135),(1.8,8.135),(1.8,7.965),(1.63,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,8.305),(1.63,8.475),(1.8,8.475),(1.8,8.305),(1.63,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.535),(1.63,1.705),(1.8,1.705),(1.8,1.535),(1.63,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,1.785),(1.63,1.785),(1.63,8.63),(1.8,8.63),(1.8,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,8.63),(0.98,8.63),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.955),(1.29,8.63),(1.46,8.63),(1.46,1.955),(1.29,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['nor3_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(1.41,4.445),(1.41,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,4.995),(1.26,9.09),(1.41,9.09),(1.41,4.995),(1.26,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(0.98,9.09),(0.98,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.41,4.995),(1.41,9.09),(1.84,9.09),(1.84,4.995),(1.41,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,4.445),(1.84,4.445),(1.84,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.225),(1.63,5.395),(1.8,5.395),(1.8,5.225),(1.63,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.565),(1.63,5.735),(1.8,5.735),(1.8,5.565),(1.63,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.905),(1.63,6.075),(1.8,6.075),(1.8,5.905),(1.63,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.245),(1.63,6.415),(1.8,6.415),(1.8,6.245),(1.63,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.585),(1.63,6.755),(1.8,6.755),(1.8,6.585),(1.63,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.925),(1.63,7.095),(1.8,7.095),(1.8,6.925),(1.63,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.265),(1.63,7.435),(1.8,7.435),(1.8,7.265),(1.63,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.605),(1.63,7.775),(1.8,7.775),(1.8,7.605),(1.63,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.945),(1.63,8.115),(1.8,8.115),(1.8,7.945),(1.63,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,8.285),(1.63,8.455),(1.8,8.455),(1.8,8.285),(1.63,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.605),(1.63,1.775),(1.8,1.775),(1.8,1.605),(1.63,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.945),(1.63,2.115),(1.8,2.115),(1.8,1.945),(1.63,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.285),(1.63,2.455),(1.8,2.455),(1.8,2.285),(1.63,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.625),(1.63,2.795),(1.8,2.795),(1.8,2.625),(1.63,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.965),(1.63,3.135),(1.8,3.135),(1.8,2.965),(1.63,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.305),(1.63,3.475),(1.8,3.475),(1.8,3.305),(1.63,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.645),(1.63,3.815),(1.8,3.815),(1.8,3.645),(1.63,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.985),(1.63,4.155),(1.8,4.155),(1.8,3.985),(1.63,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.605),(0.605,1.775),(0.775,1.775),(0.775,1.605),(0.605,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.945),(0.605,2.115),(0.775,2.115),(0.775,1.945),(0.605,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.285),(0.605,2.455),(0.775,2.455),(0.775,2.285),(0.605,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.625),(0.605,2.795),(0.775,2.795),(0.775,2.625),(0.605,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.965),(0.605,3.135),(0.775,3.135),(0.775,2.965),(0.605,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.305),(0.605,3.475),(0.775,3.475),(0.775,3.305),(0.605,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.645),(0.605,3.815),(0.775,3.815),(0.775,3.645),(0.605,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.985),(0.605,4.155),(0.775,4.155),(0.775,3.985),(0.605,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,4.385),(1.63,4.385),(1.63,8.63),(1.8,8.63),(1.8,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,4.555),(0.81,8.63),(0.98,8.63),(0.98,4.555),(0.81,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,4.995),(0.98,9.09),(1.26,9.09),(1.26,4.995),(0.98,4.995)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,4.555),(1.29,8.63),(1.46,8.63),(1.46,4.555),(1.29,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['nor4_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'i3': Net.create(cell, 'i3'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((1.72,0.91),(1.72,1.91),(2.32,1.91),(2.32,0.91),(1.72,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.41,1.91),(1.41,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.03),(2.11,1.2),(2.28,1.2),(2.28,1.03),(2.11,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(0.98,9.09),(0.98,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,7.09),(1.26,9.09),(1.41,9.09),(1.41,7.09),(1.26,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,7.09),(1.72,9.09),(1.87,9.09),(1.87,7.09),(1.72,7.09)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.72,1.91),(1.72,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.87,7.09),(1.87,9.09),(2.32,9.09),(2.32,7.09),(1.87,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.285),(2.11,7.455),(2.28,7.455),(2.28,7.285),(2.11,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.625),(2.11,7.795),(2.28,7.795),(2.28,7.625),(2.11,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.965),(2.11,8.135),(2.28,8.135),(2.28,7.965),(2.11,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,8.305),(2.11,8.475),(2.28,8.475),(2.28,8.305),(2.11,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.535),(0.605,1.705),(0.775,1.705),(0.775,1.535),(0.605,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,1.535),(1.465,1.705),(1.635,1.705),(1.635,1.535),(1.465,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,1.785),(2.11,1.785),(2.11,8.63),(2.28,8.63),(2.28,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,8.63),(0.98,8.63),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.955),(1.29,8.63),(1.46,8.63),(1.46,1.955),(1.29,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.41,7.09),(1.41,9.09),(1.72,9.09),(1.72,7.09),(1.41,7.09)),
        )
        net = nets['i3']
        createRL(
            tech, net, 'poly',
            ((1.72,0.78),(1.72,9.22),(1.87,9.22),(1.87,4.885),(1.99,4.885),(1.99,4.555),(1.87,4.555),(1.87,0.78),(1.72,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.77,1.955),(1.77,8.63),(1.94,8.63),(1.94,1.955),(1.77,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.855), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.855), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)
        nets['i3'].setDirection(Net.Direction.IN)

    cell = new_cells['nor4_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'i3': Net.create(cell, 'i3'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,0.91),(1.72,4.445),(2.32,4.445),(2.32,0.91),(1.72,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(1.41,4.445),(1.41,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.03),(2.11,1.2),(2.28,1.2),(2.28,1.03),(2.11,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((1.26,4.995),(1.26,9.09),(1.41,9.09),(1.41,4.995),(1.26,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,4.995),(1.72,9.09),(1.87,9.09),(1.87,4.995),(1.72,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(0.98,9.09),(0.98,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,4.445),(1.72,4.445),(1.72,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.87,4.995),(1.87,9.09),(2.32,9.09),(2.32,4.995),(1.87,4.995)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,1.605),(1.465,1.775),(1.635,1.775),(1.635,1.605),(1.465,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,1.945),(1.465,2.115),(1.635,2.115),(1.635,1.945),(1.465,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,2.285),(1.465,2.455),(1.635,2.455),(1.635,2.285),(1.465,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,2.625),(1.465,2.795),(1.635,2.795),(1.635,2.625),(1.465,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,2.965),(1.465,3.135),(1.635,3.135),(1.635,2.965),(1.465,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,3.305),(1.465,3.475),(1.635,3.475),(1.635,3.305),(1.465,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,3.645),(1.465,3.815),(1.635,3.815),(1.635,3.645),(1.465,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,3.985),(1.465,4.155),(1.635,4.155),(1.635,3.985),(1.465,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.225),(2.11,5.395),(2.28,5.395),(2.28,5.225),(2.11,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.565),(2.11,5.735),(2.28,5.735),(2.28,5.565),(2.11,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.905),(2.11,6.075),(2.28,6.075),(2.28,5.905),(2.11,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.245),(2.11,6.415),(2.28,6.415),(2.28,6.245),(2.11,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.585),(2.11,6.755),(2.28,6.755),(2.28,6.585),(2.11,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.925),(2.11,7.095),(2.28,7.095),(2.28,6.925),(2.11,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.265),(2.11,7.435),(2.28,7.435),(2.28,7.265),(2.11,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.605),(2.11,7.775),(2.28,7.775),(2.28,7.605),(2.11,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.945),(2.11,8.115),(2.28,8.115),(2.28,7.945),(2.11,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,8.285),(2.11,8.455),(2.28,8.455),(2.28,8.285),(2.11,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.605),(0.605,1.775),(0.775,1.775),(0.775,1.605),(0.605,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.945),(0.605,2.115),(0.775,2.115),(0.775,1.945),(0.605,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.285),(0.605,2.455),(0.775,2.455),(0.775,2.285),(0.605,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.625),(0.605,2.795),(0.775,2.795),(0.775,2.625),(0.605,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,2.965),(0.605,3.135),(0.775,3.135),(0.775,2.965),(0.605,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.305),(0.605,3.475),(0.775,3.475),(0.775,3.305),(0.605,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.645),(0.605,3.815),(0.775,3.815),(0.775,3.645),(0.605,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,3.985),(0.605,4.155),(0.775,4.155),(0.775,3.985),(0.605,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,4.385),(2.11,4.385),(2.11,8.63),(2.28,8.63),(2.28,1.37),(0.605,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,4.555),(0.81,8.63),(0.98,8.63),(0.98,4.555),(0.81,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,4.995),(0.98,9.09),(1.26,9.09),(1.26,4.995),(0.98,4.995)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,4.555),(1.29,8.63),(1.46,8.63),(1.46,4.555),(1.29,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.41,4.995),(1.41,9.09),(1.72,9.09),(1.72,4.995),(1.41,4.995)),
        )
        net = nets['i3']
        createRL(
            tech, net, 'poly',
            ((1.72,0.78),(1.72,9.22),(1.87,9.22),(1.87,4.885),(1.99,4.885),(1.99,4.555),(1.87,4.555),(1.87,0.78),(1.72,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.77,4.555),(1.77,8.63),(1.94,8.63),(1.94,4.555),(1.77,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.855), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.855), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)
        nets['i3'].setDirection(Net.Direction.IN)

    cell = new_cells['or2_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(2.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'nq': Net.create(cell, 'nq'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(1.865,0.385),(1.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.055,1.91),(1.055,4.445),(1.47,4.445),(1.47,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,0.175),(0.405,0.345),(0.575,0.345),(0.575,0.175),(0.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,0.175),(0.745,0.345),(0.915,0.345),(0.915,0.175),(0.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,0.175),(1.085,0.345),(1.255,0.345),(1.255,0.175),(1.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,0.175),(1.425,0.345),(1.595,0.345),(1.595,0.175),(1.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.095,1.03),(1.095,1.2),(1.265,1.2),(1.265,1.03),(1.095,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(2.0,1.2),(2.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(2.0,4.8),(2.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(2.0,10.0),(2.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(2.0,9.215),(2.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(2.0,0.51),(2.0,0.0),(0.0,0.0)),
        )
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.535),(0.605,1.705),(0.775,1.705),(0.775,1.535),(0.605,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,1.785),(1.29,1.785),(1.29,7.205),(0.175,7.205),(0.175,8.63),(1.375,8.63),(1.375,7.535),(1.46,7.535),(1.46,1.455),(1.375,1.455),(1.375,1.37),(0.605,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.32,0.78),(1.32,4.555),(1.24,4.555),(1.24,4.885),(1.32,4.885),(1.32,9.22),(1.47,9.22),(1.47,4.885),(1.51,4.885),(1.51,4.555),(1.47,4.555),(1.47,0.78),(1.32,0.78)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(2.18,10.18),(2.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.55,9.09),(0.55,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.055,4.995),(1.055,7.09),(0.83,7.09),(0.83,9.09),(1.47,9.09),(1.47,4.995),(1.055,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(1.865,9.865),(1.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((1.095,8.8),(1.095,8.97),(1.265,8.97),(1.265,8.8),(1.095,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.405,9.655),(0.405,9.825),(0.575,9.825),(0.575,9.655),(0.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.745,9.655),(0.745,9.825),(0.915,9.825),(0.915,9.655),(0.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.085,9.655),(1.085,9.825),(1.255,9.825),(1.255,9.655),(1.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.425,9.655),(1.425,9.825),(1.595,9.825),(1.595,9.655),(1.425,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(2.0,10.0),(2.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.0), u(2.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,7.035),(0.345,7.035),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,7.035),(0.98,7.035),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.47,4.995),(1.47,9.09),(1.84,9.09),(1.84,4.995),(1.47,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.47,0.91),(1.47,4.445),(1.84,4.445),(1.84,0.91),(1.47,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.225),(1.63,5.395),(1.8,5.395),(1.8,5.225),(1.63,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.565),(1.63,5.735),(1.8,5.735),(1.8,5.565),(1.63,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,5.905),(1.63,6.075),(1.8,6.075),(1.8,5.905),(1.63,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.245),(1.63,6.415),(1.8,6.415),(1.8,6.245),(1.63,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.585),(1.63,6.755),(1.8,6.755),(1.8,6.585),(1.63,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,6.925),(1.63,7.095),(1.8,7.095),(1.8,6.925),(1.63,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.265),(1.63,7.435),(1.8,7.435),(1.8,7.265),(1.63,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.605),(1.63,7.775),(1.8,7.775),(1.8,7.605),(1.63,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,7.945),(1.63,8.115),(1.8,8.115),(1.8,7.945),(1.63,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,8.285),(1.63,8.455),(1.8,8.455),(1.8,8.285),(1.63,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.605),(1.63,1.775),(1.8,1.775),(1.8,1.605),(1.63,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,1.945),(1.63,2.115),(1.8,2.115),(1.8,1.945),(1.63,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.285),(1.63,2.455),(1.8,2.455),(1.8,2.285),(1.63,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.625),(1.63,2.795),(1.8,2.795),(1.8,2.625),(1.63,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,2.965),(1.63,3.135),(1.8,3.135),(1.8,2.965),(1.63,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.305),(1.63,3.475),(1.8,3.475),(1.8,3.305),(1.63,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.645),(1.63,3.815),(1.8,3.815),(1.8,3.645),(1.63,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.63,3.985),(1.63,4.155),(1.8,4.155),(1.8,3.985),(1.63,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((1.63,1.37),(1.63,8.63),(1.8,8.63),(1.8,1.37),(1.63,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.715), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)

    cell = new_cells['or3_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.535),(1.035,1.705),(1.205,1.705),(1.205,1.535),(1.035,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,1.785),(1.77,1.785),(1.77,7.205),(0.175,7.205),(0.175,8.63),(1.855,8.63),(1.855,7.535),(1.94,7.535),(1.94,1.455),(1.855,1.455),(1.855,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.75,0.78),(1.75,4.555),(1.72,4.555),(1.72,4.885),(1.75,4.885),(1.75,9.22),(1.9,9.22),(1.9,4.885),(1.99,4.885),(1.99,4.555),(1.9,4.555),(1.9,0.78),(1.75,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(0.98,9.09),(0.98,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.485,4.995),(1.485,7.09),(1.26,7.09),(1.26,9.09),(1.9,9.09),(1.9,4.995),(1.485,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.55,9.09),(0.55,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,8.8),(1.525,8.97),(1.695,8.97),(1.695,8.8),(1.525,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.485,1.91),(1.485,4.445),(1.9,4.445),(1.9,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.98,1.91),(0.98,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,1.03),(1.525,1.2),(1.695,1.2),(1.695,1.03),(1.525,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.955),(0.175,7.035),(0.345,7.035),(0.345,1.955),(0.175,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,7.035),(0.98,7.035),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.955),(1.29,7.035),(1.46,7.035),(1.46,1.955),(1.29,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.9,4.995),(1.9,9.09),(2.32,9.09),(2.32,4.995),(1.9,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.9,0.91),(1.9,4.445),(2.32,4.445),(2.32,0.91),(1.9,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.225),(2.11,5.395),(2.28,5.395),(2.28,5.225),(2.11,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.565),(2.11,5.735),(2.28,5.735),(2.28,5.565),(2.11,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,5.905),(2.11,6.075),(2.28,6.075),(2.28,5.905),(2.11,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.245),(2.11,6.415),(2.28,6.415),(2.28,6.245),(2.11,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.585),(2.11,6.755),(2.28,6.755),(2.28,6.585),(2.11,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,6.925),(2.11,7.095),(2.28,7.095),(2.28,6.925),(2.11,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.265),(2.11,7.435),(2.28,7.435),(2.28,7.265),(2.11,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.605),(2.11,7.775),(2.28,7.775),(2.28,7.605),(2.11,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,7.945),(2.11,8.115),(2.28,8.115),(2.28,7.945),(2.11,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,8.285),(2.11,8.455),(2.28,8.455),(2.28,8.285),(2.11,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.605),(2.11,1.775),(2.28,1.775),(2.28,1.605),(2.11,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,1.945),(2.11,2.115),(2.28,2.115),(2.28,1.945),(2.11,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.285),(2.11,2.455),(2.28,2.455),(2.28,2.285),(2.11,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.625),(2.11,2.795),(2.28,2.795),(2.28,2.625),(2.11,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,2.965),(2.11,3.135),(2.28,3.135),(2.28,2.965),(2.11,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.305),(2.11,3.475),(2.28,3.475),(2.28,3.305),(2.11,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.645),(2.11,3.815),(2.28,3.815),(2.28,3.645),(2.11,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((2.11,3.985),(2.11,4.155),(2.28,4.155),(2.28,3.985),(2.11,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((2.11,1.37),(2.11,8.63),(2.28,8.63),(2.28,1.37),(2.11,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.195), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['or4_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'i3': Net.create(cell, 'i3'),
            'nq': Net.create(cell, 'nq'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.41,1.91),(1.41,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.72,0.91),(1.72,1.91),(1.945,1.91),(1.945,4.445),(2.36,4.445),(2.36,0.91),(1.72,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.985,1.03),(1.985,1.2),(2.155,1.2),(2.155,1.03),(1.985,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.72,1.91),(1.72,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.535),(0.605,1.705),(0.775,1.705),(0.775,1.535),(0.605,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.25,4.635),(2.25,4.805),(2.42,4.805),(2.42,4.635),(2.25,4.635)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.465,1.535),(1.465,1.705),(1.635,1.705),(1.635,1.535),(1.465,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.605,1.37),(0.605,1.785),(2.25,1.785),(2.25,7.205),(0.175,7.205),(0.175,8.63),(2.335,8.63),(2.335,7.535),(2.42,7.535),(2.42,1.455),(2.335,1.455),(2.335,1.37),(0.605,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((2.21,0.78),(2.21,4.555),(2.2,4.555),(2.2,4.885),(2.21,4.885),(2.21,9.22),(2.36,9.22),(2.36,4.885),(2.47,4.885),(2.47,4.555),(2.36,4.555),(2.36,0.78),(2.21,0.78)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.945,4.995),(1.945,7.09),(1.72,7.09),(1.72,9.09),(2.36,9.09),(2.36,4.995),(1.945,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.55,9.09),(0.55,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(0.98,9.09),(0.98,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,7.09),(1.26,9.09),(1.41,9.09),(1.41,7.09),(1.26,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((1.985,8.8),(1.985,8.97),(2.155,8.97),(2.155,8.8),(1.985,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,7.035),(0.345,7.035),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,7.035),(0.98,7.035),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,4.555),(1.24,4.555),(1.24,4.885),(1.26,4.885),(1.26,9.22),(1.41,9.22),(1.41,4.885),(1.51,4.885),(1.51,4.555),(1.41,4.555),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.29,4.635),(1.29,4.805),(1.46,4.805),(1.46,4.635),(1.29,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.29,1.955),(1.29,7.035),(1.46,7.035),(1.46,1.955),(1.29,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.375), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.41,7.09),(1.41,9.09),(1.72,9.09),(1.72,7.09),(1.41,7.09)),
        )
        net = nets['i3']
        createRL(
            tech, net, 'poly',
            ((1.72,0.78),(1.72,9.22),(1.87,9.22),(1.87,4.885),(1.99,4.885),(1.99,4.555),(1.87,4.555),(1.87,0.78),(1.72,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.77,4.635),(1.77,4.805),(1.94,4.805),(1.94,4.635),(1.77,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.77,1.955),(1.77,7.035),(1.94,7.035),(1.94,1.955),(1.77,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.855), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.855), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((2.36,4.995),(2.36,9.09),(2.8,9.09),(2.8,4.995),(2.36,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.36,0.91),(2.36,4.445),(2.8,4.445),(2.8,0.91),(2.36,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,1.605),(2.59,1.775),(2.76,1.775),(2.76,1.605),(2.59,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,1.945),(2.59,2.115),(2.76,2.115),(2.76,1.945),(2.59,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,2.285),(2.59,2.455),(2.76,2.455),(2.76,2.285),(2.59,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,2.625),(2.59,2.795),(2.76,2.795),(2.76,2.625),(2.59,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,2.965),(2.59,3.135),(2.76,3.135),(2.76,2.965),(2.59,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,3.305),(2.59,3.475),(2.76,3.475),(2.76,3.305),(2.59,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,3.645),(2.59,3.815),(2.76,3.815),(2.76,3.645),(2.59,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,3.985),(2.59,4.155),(2.76,4.155),(2.76,3.985),(2.59,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,5.225),(2.59,5.395),(2.76,5.395),(2.76,5.225),(2.59,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,5.565),(2.59,5.735),(2.76,5.735),(2.76,5.565),(2.59,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,5.905),(2.59,6.075),(2.76,6.075),(2.76,5.905),(2.59,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,6.245),(2.59,6.415),(2.76,6.415),(2.76,6.245),(2.59,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,6.585),(2.59,6.755),(2.76,6.755),(2.76,6.585),(2.59,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,6.925),(2.59,7.095),(2.76,7.095),(2.76,6.925),(2.59,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,7.265),(2.59,7.435),(2.76,7.435),(2.76,7.265),(2.59,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,7.605),(2.59,7.775),(2.76,7.775),(2.76,7.605),(2.59,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,7.945),(2.59,8.115),(2.76,8.115),(2.76,7.945),(2.59,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((2.59,8.285),(2.59,8.455),(2.76,8.455),(2.76,8.285),(2.59,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((2.59,1.37),(2.59,8.63),(2.76,8.63),(2.76,1.37),(2.59,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.675), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.675), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)
        nets['i3'].setDirection(Net.Direction.IN)

    cell = new_cells['mux2_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            '_net3': Net.create(cell, '_net3'),
            '_q_n': Net.create(cell, '_q_n'),
            'cmd': Net.create(cell, 'cmd'),
            'cmd_n': Net.create(cell, 'cmd_n'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['cmd_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.335,4.095),(1.335,4.265),(1.505,4.265),(1.505,4.095),(1.335,4.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,5.175),(1.695,5.345),(1.865,5.345),(1.865,5.175),(1.695,5.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.785),(1.335,1.785),(1.335,5.425),(1.865,5.425),(1.865,5.095),(1.505,5.095),(1.505,1.455),(1.42,1.455),(1.42,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.285,0.78),(1.285,4.345),(1.555,4.345),(1.555,4.015),(1.435,4.015),(1.435,0.78),(1.285,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((1.645,5.095),(1.645,5.425),(1.9,5.425),(1.9,9.22),(2.05,9.22),(2.05,5.095),(1.645,5.095)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(4.0,4.8),(4.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(4.0,10.0),(4.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(4.0,0.51),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(4.0,9.215),(4.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.555,5.535),(2.555,7.09),(2.33,7.09),(2.33,9.09),(2.97,9.09),(2.97,5.535),(2.555,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(3.865,9.865),(3.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.285,7.09),(1.285,9.09),(1.435,9.09),(1.435,7.09),(1.285,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.98,9.09),(0.98,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.9,7.09),(1.9,9.09),(2.05,9.09),(2.05,7.09),(1.9,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((2.595,8.8),(2.595,8.97),(2.765,8.97),(2.765,8.8),(2.595,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,9.655),(0.385,9.825),(0.555,9.825),(0.555,9.655),(0.385,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,9.655),(0.725,9.825),(0.895,9.825),(0.895,9.655),(0.725,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,9.655),(1.065,9.825),(1.235,9.825),(1.235,9.655),(1.065,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,9.655),(1.405,9.825),(1.575,9.825),(1.575,9.655),(1.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,9.655),(1.745,9.825),(1.915,9.825),(1.915,9.655),(1.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,9.655),(2.085,9.825),(2.255,9.825),(2.255,9.655),(2.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,9.655),(2.425,9.825),(2.595,9.825),(2.595,9.655),(2.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,9.655),(2.765,9.825),(2.935,9.825),(2.935,9.655),(2.765,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,9.655),(3.105,9.825),(3.275,9.825),(3.275,9.655),(3.105,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,9.655),(3.445,9.825),(3.615,9.825),(3.615,9.655),(3.445,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((2.33,0.91),(2.33,1.91),(2.555,1.91),(2.555,3.905),(2.97,3.905),(2.97,0.91),(2.33,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(3.865,0.385),(3.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.285,0.91),(1.285,1.91),(1.435,1.91),(1.435,0.91),(1.285,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.9,0.91),(1.9,1.91),(2.05,1.91),(2.05,0.91),(1.9,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.98,1.91),(0.98,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,0.175),(0.385,0.345),(0.555,0.345),(0.555,0.175),(0.385,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,0.175),(0.725,0.345),(0.895,0.345),(0.895,0.175),(0.725,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,0.175),(1.065,0.345),(1.235,0.345),(1.235,0.175),(1.065,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,0.175),(1.405,0.345),(1.575,0.345),(1.575,0.175),(1.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,0.175),(1.745,0.345),(1.915,0.345),(1.915,0.175),(1.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,0.175),(2.085,0.345),(2.255,0.345),(2.255,0.175),(2.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,0.175),(2.425,0.345),(2.595,0.345),(2.595,0.175),(2.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,0.175),(2.765,0.345),(2.935,0.345),(2.935,0.175),(2.765,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,0.175),(3.105,0.345),(3.275,0.345),(3.275,0.175),(3.105,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,0.175),(3.445,0.345),(3.615,0.345),(3.615,0.175),(3.445,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.595,1.03),(2.595,1.2),(2.765,1.2),(2.765,1.03),(2.595,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['cmd']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,9.22),(0.55,9.22),(0.55,4.885),(1.285,4.885),(1.285,9.22),(1.435,9.22),(1.435,4.885),(2.05,4.885),(2.05,0.78),(1.9,0.78),(1.9,4.555),(0.55,4.555),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,4.635),(0.515,4.805),(0.685,4.805),(0.685,4.635),(0.515,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.955),(0.515,8.63),(0.685,8.63),(0.685,1.955),(0.515,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.285,1.91),(1.285,0.91),(0.98,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.805,5.095),(0.805,5.425),(0.83,5.425),(0.83,9.22),(0.98,9.22),(0.98,5.425),(1.075,5.425),(1.075,5.095),(0.805,5.095)),
        )
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.015),(0.805,4.015),(0.805,4.345),(1.075,4.345),(1.075,4.015),(0.98,4.015),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.855,4.095),(0.855,4.265),(1.025,4.265),(1.025,4.095),(0.855,4.095)),
        )
        createRL(
            tech, net, 'licon',
            ((0.855,5.175),(0.855,5.345),(1.025,5.345),(1.025,5.175),(0.855,5.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.855,1.955),(0.855,8.63),(1.025,8.63),(1.025,1.955),(0.855,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.94), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.94), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.285,9.09),(1.285,7.09),(0.98,7.09)),
        )
        net = nets['_q_n']
        createRL(
            tech, net, 'difftap',
            ((1.435,7.09),(1.435,9.09),(1.9,9.09),(1.9,7.09),(1.435,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.435,0.91),(1.435,1.91),(1.9,1.91),(1.9,0.91),(1.435,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.675,7.285),(1.675,7.455),(1.845,7.455),(1.845,7.285),(1.675,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.675,7.625),(1.675,7.795),(1.845,7.795),(1.845,7.625),(1.675,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.675,7.965),(1.675,8.135),(1.845,8.135),(1.845,7.965),(1.675,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.675,8.305),(1.675,8.475),(1.845,8.475),(1.845,8.305),(1.675,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.74,4.635),(2.74,4.805),(2.91,4.805),(2.91,4.635),(2.74,4.635)),
        )
        createRL(
            tech, net, 'licon',
            ((1.675,1.535),(1.675,1.705),(1.845,1.705),(1.845,1.535),(1.675,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((1.675,1.37),(1.675,1.785),(2.74,1.785),(2.74,7.205),(1.675,7.205),(1.675,8.63),(2.825,8.63),(2.825,7.535),(2.91,7.535),(2.91,1.455),(2.825,1.455),(2.825,1.37),(1.675,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((2.82,0.78),(2.82,4.555),(2.69,4.555),(2.69,4.885),(2.82,4.885),(2.82,9.22),(2.97,9.22),(2.97,0.78),(2.82,0.78)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((2.05,0.91),(2.05,1.91),(2.33,1.91),(2.33,0.91),(2.05,0.91)),
        )
        net = nets['_net3']
        createRL(
            tech, net, 'difftap',
            ((2.05,7.09),(2.05,9.09),(2.33,9.09),(2.33,7.09),(2.05,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((2.33,0.78),(2.33,4.015),(2.26,4.015),(2.26,4.345),(2.33,4.345),(2.33,9.22),(2.48,9.22),(2.48,4.345),(2.53,4.345),(2.53,4.015),(2.48,4.015),(2.48,0.78),(2.33,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((2.31,4.095),(2.31,4.265),(2.48,4.265),(2.48,4.095),(2.31,4.095)),
        )
        createRL(
            tech, net, 'li',
            ((2.31,1.955),(2.31,7.035),(2.48,7.035),(2.48,1.955),(2.31,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.395), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.395), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((2.97,5.535),(2.97,9.09),(3.29,9.09),(3.29,5.535),(2.97,5.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.97,0.91),(2.97,3.905),(3.29,3.905),(3.29,0.91),(2.97,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,5.835),(3.08,6.005),(3.25,6.005),(3.25,5.835),(3.08,5.835)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,6.175),(3.08,6.345),(3.25,6.345),(3.25,6.175),(3.08,6.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,6.515),(3.08,6.685),(3.25,6.685),(3.25,6.515),(3.08,6.515)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,6.855),(3.08,7.025),(3.25,7.025),(3.25,6.855),(3.08,6.855)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,7.195),(3.08,7.365),(3.25,7.365),(3.25,7.195),(3.08,7.195)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,7.535),(3.08,7.705),(3.25,7.705),(3.25,7.535),(3.08,7.535)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,7.875),(3.08,8.045),(3.25,8.045),(3.25,7.875),(3.08,7.875)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,8.215),(3.08,8.385),(3.25,8.385),(3.25,8.215),(3.08,8.215)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,1.505),(3.08,1.675),(3.25,1.675),(3.25,1.505),(3.08,1.505)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,1.845),(3.08,2.015),(3.25,2.015),(3.25,1.845),(3.08,1.845)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,2.185),(3.08,2.355),(3.25,2.355),(3.25,2.185),(3.08,2.185)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,2.525),(3.08,2.695),(3.25,2.695),(3.25,2.525),(3.08,2.525)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,2.865),(3.08,3.035),(3.25,3.035),(3.25,2.865),(3.08,2.865)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,3.205),(3.08,3.375),(3.25,3.375),(3.25,3.205),(3.08,3.205)),
        )
        createRL(
            tech, net, 'licon',
            ((3.08,3.545),(3.08,3.715),(3.25,3.715),(3.25,3.545),(3.08,3.545)),
        )
        createRL(
            tech, net, 'li',
            ((3.08,1.37),(3.08,8.63),(3.25,8.63),(3.25,1.37),(3.08,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(3.165), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(3.165), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['cmd'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)

    cell = new_cells['and21nor_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,0.91),(1.375,1.91),(2.04,1.91),(2.04,0.91),(1.375,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(0.98,1.91),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.55,1.91),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,1.03),(1.83,1.2),(2.0,1.2),(2.0,1.03),(1.83,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.375,9.09),(1.375,7.09),(0.98,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.285),(1.15,7.455),(1.32,7.455),(1.32,7.285),(1.15,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.625),(1.15,7.795),(1.32,7.795),(1.32,7.625),(1.15,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.965),(1.15,8.135),(1.32,8.135),(1.32,7.965),(1.15,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.305),(1.15,8.475),(1.32,8.475),(1.32,8.305),(1.15,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,7.205),(0.175,8.63),(1.32,8.63),(1.32,7.205),(0.175,7.205)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.98,9.09),(0.98,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,7.09),(1.375,9.09),(1.525,9.09),(1.525,7.09),(1.375,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,7.035),(0.345,7.035),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.525,7.09),(1.525,9.09),(2.04,9.09),(2.04,7.09),(1.525,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.375,1.91),(1.375,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.535),(1.15,1.705),(1.32,1.705),(1.32,1.535),(1.15,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,7.285),(1.83,7.455),(2.0,7.455),(2.0,7.285),(1.83,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,7.625),(1.83,7.795),(2.0,7.795),(2.0,7.625),(1.83,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,7.965),(1.83,8.135),(2.0,8.135),(2.0,7.965),(1.83,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,8.305),(1.83,8.475),(2.0,8.475),(2.0,8.305),(1.83,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,1.785),(1.83,1.785),(1.83,8.63),(2.0,8.63),(2.0,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,7.035),(0.98,7.035),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.375,0.78),(1.375,9.22),(1.525,9.22),(1.525,4.885),(1.71,4.885),(1.71,4.555),(1.525,4.555),(1.525,0.78),(1.375,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.49,4.635),(1.49,4.805),(1.66,4.805),(1.66,4.635),(1.49,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.49,1.955),(1.49,8.63),(1.66,8.63),(1.66,1.955),(1.49,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.575), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.575), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['and21nor_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((1.375,0.91),(1.375,4.445),(2.04,4.445),(2.04,0.91),(1.375,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.55,4.445),(0.55,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.445),(0.98,4.445),(0.98,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.03),(0.175,1.2),(0.345,1.2),(0.345,1.03),(0.175,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,1.03),(1.83,1.2),(2.0,1.2),(2.0,1.03),(1.83,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.98,4.995),(0.98,9.09),(1.375,9.09),(1.375,4.995),(0.98,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.4,9.09),(0.4,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.225),(0.175,5.395),(0.345,5.395),(0.345,5.225),(0.175,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.565),(0.175,5.735),(0.345,5.735),(0.345,5.565),(0.175,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,5.905),(0.175,6.075),(0.345,6.075),(0.345,5.905),(0.175,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.245),(0.175,6.415),(0.345,6.415),(0.345,6.245),(0.175,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.585),(0.175,6.755),(0.345,6.755),(0.345,6.585),(0.175,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,6.925),(0.175,7.095),(0.345,7.095),(0.345,6.925),(0.175,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.265),(0.175,7.435),(0.345,7.435),(0.345,7.265),(0.175,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.605),(0.175,7.775),(0.345,7.775),(0.345,7.605),(0.175,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.945),(0.175,8.115),(0.345,8.115),(0.345,7.945),(0.175,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.285),(0.175,8.455),(0.345,8.455),(0.345,8.285),(0.175,8.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.225),(1.15,5.395),(1.32,5.395),(1.32,5.225),(1.15,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.565),(1.15,5.735),(1.32,5.735),(1.32,5.565),(1.15,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.905),(1.15,6.075),(1.32,6.075),(1.32,5.905),(1.15,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.245),(1.15,6.415),(1.32,6.415),(1.32,6.245),(1.15,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.585),(1.15,6.755),(1.32,6.755),(1.32,6.585),(1.15,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.925),(1.15,7.095),(1.32,7.095),(1.32,6.925),(1.15,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.265),(1.15,7.435),(1.32,7.435),(1.32,7.265),(1.15,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.605),(1.15,7.775),(1.32,7.775),(1.32,7.605),(1.15,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.945),(1.15,8.115),(1.32,8.115),(1.32,7.945),(1.15,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.285),(1.15,8.455),(1.32,8.455),(1.32,8.285),(1.15,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,5.055),(0.175,8.63),(1.32,8.63),(1.32,5.055),(0.175,5.055)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,4.995),(0.4,9.09),(0.98,9.09),(0.98,4.995),(0.4,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,4.995),(1.375,9.09),(1.525,9.09),(1.525,4.995),(1.375,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.445),(0.83,4.445),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,4.885),(0.345,4.885),(0.345,1.37),(0.175,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.525,4.995),(1.525,9.09),(2.04,9.09),(2.04,4.995),(1.525,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,4.445),(1.375,4.445),(1.375,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.605),(1.15,1.775),(1.32,1.775),(1.32,1.605),(1.15,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.945),(1.15,2.115),(1.32,2.115),(1.32,1.945),(1.15,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.285),(1.15,2.455),(1.32,2.455),(1.32,2.285),(1.15,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.625),(1.15,2.795),(1.32,2.795),(1.32,2.625),(1.15,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.965),(1.15,3.135),(1.32,3.135),(1.32,2.965),(1.15,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.305),(1.15,3.475),(1.32,3.475),(1.32,3.305),(1.15,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.645),(1.15,3.815),(1.32,3.815),(1.32,3.645),(1.15,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.985),(1.15,4.155),(1.32,4.155),(1.32,3.985),(1.15,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,5.225),(1.83,5.395),(2.0,5.395),(2.0,5.225),(1.83,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,5.565),(1.83,5.735),(2.0,5.735),(2.0,5.565),(1.83,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,5.905),(1.83,6.075),(2.0,6.075),(2.0,5.905),(1.83,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,6.245),(1.83,6.415),(2.0,6.415),(2.0,6.245),(1.83,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,6.585),(1.83,6.755),(2.0,6.755),(2.0,6.585),(1.83,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,6.925),(1.83,7.095),(2.0,7.095),(2.0,6.925),(1.83,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,7.265),(1.83,7.435),(2.0,7.435),(2.0,7.265),(1.83,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,7.605),(1.83,7.775),(2.0,7.775),(2.0,7.605),(1.83,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,7.945),(1.83,8.115),(2.0,8.115),(2.0,7.945),(1.83,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,8.285),(1.83,8.455),(2.0,8.455),(2.0,8.285),(1.83,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,4.385),(1.83,4.385),(1.83,8.63),(2.0,8.63),(2.0,1.37),(1.15,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.37),(0.81,4.885),(0.98,4.885),(0.98,1.37),(0.81,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.375,0.78),(1.375,9.22),(1.525,9.22),(1.525,4.885),(1.71,4.885),(1.71,4.555),(1.525,4.555),(1.525,0.78),(1.375,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.49,4.635),(1.49,4.805),(1.66,4.805),(1.66,4.635),(1.49,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.49,4.555),(1.49,8.63),(1.66,8.63),(1.66,4.555),(1.49,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.575), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.575), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['or21nand_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.375,1.91),(1.375,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.535),(1.15,1.705),(1.32,1.705),(1.32,1.535),(1.15,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,1.785),(1.32,1.785),(1.32,1.37),(0.175,1.37)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((1.375,7.09),(1.375,9.09),(2.04,9.09),(2.04,7.09),(1.375,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(0.98,9.09),(0.98,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,8.8),(1.83,8.97),(2.0,8.97),(2.0,8.8),(1.83,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,0.91),(1.375,1.91),(1.525,1.91),(1.525,0.91),(1.375,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.98,1.91),(0.98,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.955),(0.175,8.63),(0.345,8.63),(0.345,1.955),(0.175,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,1.955),(0.81,8.63),(0.98,8.63),(0.98,1.955),(0.81,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.375,9.09),(1.375,7.09),(0.98,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.525,0.91),(1.525,1.91),(2.04,1.91),(2.04,0.91),(1.525,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.285),(1.15,7.455),(1.32,7.455),(1.32,7.285),(1.15,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.625),(1.15,7.795),(1.32,7.795),(1.32,7.625),(1.15,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.965),(1.15,8.135),(1.32,8.135),(1.32,7.965),(1.15,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.305),(1.15,8.475),(1.32,8.475),(1.32,8.305),(1.15,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,1.535),(1.83,1.705),(2.0,1.705),(2.0,1.535),(1.83,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((1.83,1.37),(1.83,7.205),(1.15,7.205),(1.15,8.63),(2.0,8.63),(2.0,1.37),(1.83,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.375,0.78),(1.375,9.22),(1.525,9.22),(1.525,4.885),(1.71,4.885),(1.71,4.555),(1.525,4.555),(1.525,0.78),(1.375,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.49,4.635),(1.49,4.805),(1.66,4.805),(1.66,4.635),(1.49,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.49,1.37),(1.49,7.035),(1.66,7.035),(1.66,1.37),(1.49,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.575), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.575), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['or21nand_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'i0': Net.create(cell, 'i0'),
            'i1': Net.create(cell, 'i1'),
            'i2': Net.create(cell, 'i2'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,4.445),(1.375,4.445),(1.375,0.91),(0.98,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.445),(0.4,4.445),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.605),(1.15,1.775),(1.32,1.775),(1.32,1.605),(1.15,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.945),(1.15,2.115),(1.32,2.115),(1.32,1.945),(1.15,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.285),(1.15,2.455),(1.32,2.455),(1.32,2.285),(1.15,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.625),(1.15,2.795),(1.32,2.795),(1.32,2.625),(1.15,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,2.965),(1.15,3.135),(1.32,3.135),(1.32,2.965),(1.15,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.305),(1.15,3.475),(1.32,3.475),(1.32,3.305),(1.15,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.645),(1.15,3.815),(1.32,3.815),(1.32,3.645),(1.15,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,3.985),(1.15,4.155),(1.32,4.155),(1.32,3.985),(1.15,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.605),(0.175,1.775),(0.345,1.775),(0.345,1.605),(0.175,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.945),(0.175,2.115),(0.345,2.115),(0.345,1.945),(0.175,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.285),(0.175,2.455),(0.345,2.455),(0.345,2.285),(0.175,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.625),(0.175,2.795),(0.345,2.795),(0.345,2.625),(0.175,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.965),(0.175,3.135),(0.345,3.135),(0.345,2.965),(0.175,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.305),(0.175,3.475),(0.345,3.475),(0.345,3.305),(0.175,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.645),(0.175,3.815),(0.345,3.815),(0.345,3.645),(0.175,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.985),(0.175,4.155),(0.345,4.155),(0.345,3.985),(0.175,3.985)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,4.385),(1.32,4.385),(1.32,1.37),(0.175,1.37)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((1.375,4.995),(1.375,9.09),(2.04,9.09),(2.04,4.995),(1.375,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,4.995),(0.135,9.09),(0.55,9.09),(0.55,4.995),(0.135,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,4.995),(0.83,9.09),(0.98,9.09),(0.98,4.995),(0.83,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,8.8),(1.83,8.97),(2.0,8.97),(2.0,8.8),(1.83,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,4.445),(0.98,4.445),(0.98,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.375,0.91),(1.375,4.445),(1.525,4.445),(1.525,0.91),(1.375,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.555),(0.125,4.555),(0.125,4.885),(0.4,4.885),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.635),(0.175,4.805),(0.345,4.805),(0.345,4.635),(0.175,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,4.555),(0.175,8.63),(0.345,8.63),(0.345,4.555),(0.175,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.55,4.995),(0.55,9.09),(0.83,9.09),(0.83,4.995),(0.55,4.995)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,4.555),(0.76,4.555),(0.76,4.885),(0.83,4.885),(0.83,9.22),(0.98,9.22),(0.98,4.885),(1.03,4.885),(1.03,4.555),(0.98,4.555),(0.98,0.78),(0.83,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.81,4.635),(0.81,4.805),(0.98,4.805),(0.98,4.635),(0.81,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((0.81,4.555),(0.81,8.63),(0.98,8.63),(0.98,4.555),(0.81,4.555)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.895), u(0.17), u(4.555), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((0.98,4.995),(0.98,9.09),(1.375,9.09),(1.375,4.995),(0.98,4.995)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.525,0.91),(1.525,4.445),(2.04,4.445),(2.04,0.91),(1.525,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,1.605),(1.83,1.775),(2.0,1.775),(2.0,1.605),(1.83,1.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,1.945),(1.83,2.115),(2.0,2.115),(2.0,1.945),(1.83,1.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,2.285),(1.83,2.455),(2.0,2.455),(2.0,2.285),(1.83,2.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,2.625),(1.83,2.795),(2.0,2.795),(2.0,2.625),(1.83,2.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,2.965),(1.83,3.135),(2.0,3.135),(2.0,2.965),(1.83,2.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,3.305),(1.83,3.475),(2.0,3.475),(2.0,3.305),(1.83,3.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,3.645),(1.83,3.815),(2.0,3.815),(2.0,3.645),(1.83,3.645)),
        )
        createRL(
            tech, net, 'licon',
            ((1.83,3.985),(1.83,4.155),(2.0,4.155),(2.0,3.985),(1.83,3.985)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.225),(1.15,5.395),(1.32,5.395),(1.32,5.225),(1.15,5.225)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.565),(1.15,5.735),(1.32,5.735),(1.32,5.565),(1.15,5.565)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,5.905),(1.15,6.075),(1.32,6.075),(1.32,5.905),(1.15,5.905)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.245),(1.15,6.415),(1.32,6.415),(1.32,6.245),(1.15,6.245)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.585),(1.15,6.755),(1.32,6.755),(1.32,6.585),(1.15,6.585)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,6.925),(1.15,7.095),(1.32,7.095),(1.32,6.925),(1.15,6.925)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.265),(1.15,7.435),(1.32,7.435),(1.32,7.265),(1.15,7.265)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.605),(1.15,7.775),(1.32,7.775),(1.32,7.605),(1.15,7.605)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.945),(1.15,8.115),(1.32,8.115),(1.32,7.945),(1.15,7.945)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.285),(1.15,8.455),(1.32,8.455),(1.32,8.285),(1.15,8.285)),
        )
        createRL(
            tech, net, 'li',
            ((1.83,1.37),(1.83,5.055),(1.15,5.055),(1.15,8.63),(2.0,8.63),(2.0,1.37),(1.83,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.915), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i2']
        createRL(
            tech, net, 'poly',
            ((1.375,0.78),(1.375,9.22),(1.525,9.22),(1.525,4.885),(1.71,4.885),(1.71,4.555),(1.525,4.555),(1.525,0.78),(1.375,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.49,4.635),(1.49,4.805),(1.66,4.805),(1.66,4.635),(1.49,4.635)),
        )
        createRL(
            tech, net, 'li',
            ((1.49,1.37),(1.49,4.885),(1.66,4.885),(1.66,1.37),(1.49,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.575), u(0.17), u(1.37), u(4.885),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.575), u(0.17), u(1.37), u(4.885),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['i2'].setDirection(Net.Direction.IN)

    cell = new_cells['xor2_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i0_n': Net.create(cell, 'i0_n'),
            'i1': Net.create(cell, 'i1'),
            'i1_n': Net.create(cell, 'i1_n'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['i0_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.365),(0.175,4.535),(0.345,4.535),(0.345,4.365),(0.175,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.81,0.78),(1.81,4.285),(0.125,4.285),(0.125,4.615),(1.81,4.615),(1.81,9.22),(1.96,9.22),(1.96,0.78),(1.81,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(4.0,4.8),(4.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(4.0,10.0),(4.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(4.0,0.51),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(4.0,9.215),(4.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,7.09),(1.26,9.09),(1.41,9.09),(1.41,7.09),(1.26,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(3.865,9.865),(3.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.98,9.09),(0.98,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.24,7.09),(2.24,9.09),(2.82,9.09),(2.82,7.09),(2.24,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.81,7.09),(1.81,9.09),(1.96,9.09),(1.96,7.09),(1.81,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.445,8.8),(2.445,8.97),(2.615,8.97),(2.615,8.8),(2.445,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,9.655),(0.385,9.825),(0.555,9.825),(0.555,9.655),(0.385,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,9.655),(0.725,9.825),(0.895,9.825),(0.895,9.655),(0.725,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,9.655),(1.065,9.825),(1.235,9.825),(1.235,9.655),(1.065,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,9.655),(1.405,9.825),(1.575,9.825),(1.575,9.655),(1.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,9.655),(1.745,9.825),(1.915,9.825),(1.915,9.655),(1.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,9.655),(2.085,9.825),(2.255,9.825),(2.255,9.655),(2.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,9.655),(2.425,9.825),(2.595,9.825),(2.595,9.655),(2.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,9.655),(2.765,9.825),(2.935,9.825),(2.935,9.655),(2.765,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,9.655),(3.105,9.825),(3.275,9.825),(3.275,9.655),(3.105,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,9.655),(3.445,9.825),(3.615,9.825),(3.615,9.655),(3.445,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((1.81,0.91),(1.81,1.91),(1.96,1.91),(1.96,0.91),(1.81,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(3.865,0.385),(3.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.41,1.91),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.24,0.91),(2.24,1.91),(2.82,1.91),(2.82,0.91),(2.24,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.98,1.91),(0.98,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,0.175),(0.385,0.345),(0.555,0.345),(0.555,0.175),(0.385,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,0.175),(0.725,0.345),(0.895,0.345),(0.895,0.175),(0.725,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,0.175),(1.065,0.345),(1.235,0.345),(1.235,0.175),(1.065,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,0.175),(1.405,0.345),(1.575,0.345),(1.575,0.175),(1.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,0.175),(1.745,0.345),(1.915,0.345),(1.915,0.175),(1.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,0.175),(2.085,0.345),(2.255,0.345),(2.255,0.175),(2.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,0.175),(2.425,0.345),(2.595,0.345),(2.595,0.175),(2.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,0.175),(2.765,0.345),(2.935,0.345),(2.935,0.175),(2.765,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,0.175),(3.105,0.345),(3.275,0.345),(3.275,0.175),(3.105,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,0.175),(3.445,0.345),(3.615,0.345),(3.615,0.175),(3.445,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.445,1.03),(2.445,1.2),(2.615,1.2),(2.615,1.03),(2.445,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,5.365),(0.4,9.22),(0.55,9.22),(0.55,5.695),(0.83,5.695),(0.83,9.22),(0.98,9.22),(0.98,5.365),(0.4,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.075),(0.98,4.075),(0.98,0.78),(0.83,0.78),(0.83,3.745),(0.55,3.745),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.445),(0.515,5.615),(0.685,5.615),(0.685,5.445),(0.515,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,3.825),(0.515,3.995),(0.685,3.995),(0.685,3.825),(0.515,3.825)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.96,7.09),(1.96,9.09),(2.24,9.09),(2.24,7.09),(1.96,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.285),(1.035,7.455),(1.205,7.455),(1.205,7.285),(1.035,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.625),(1.035,7.795),(1.205,7.795),(1.205,7.625),(1.035,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.965),(1.035,8.135),(1.205,8.135),(1.205,7.965),(1.035,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.305),(1.035,8.475),(1.205,8.475),(1.205,8.305),(1.035,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,7.285),(2.015,7.455),(2.185,7.455),(2.185,7.285),(2.015,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,7.625),(2.015,7.795),(2.185,7.795),(2.185,7.625),(2.015,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,7.965),(2.015,8.135),(2.185,8.135),(2.185,7.965),(2.015,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,8.305),(2.015,8.475),(2.185,8.475),(2.185,8.305),(2.015,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((1.035,7.205),(1.035,8.63),(2.185,8.63),(2.185,7.205),(1.035,7.205)),
        )
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((1.485,5.285),(1.485,7.09),(1.41,7.09),(1.41,9.09),(1.81,9.09),(1.81,7.09),(1.735,7.09),(1.735,5.285),(1.485,5.285)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.81,1.91),(1.81,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,5.405),(1.525,5.575),(1.695,5.575),(1.695,5.405),(1.525,5.405)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,1.535),(1.525,1.705),(1.695,1.705),(1.695,1.535),(1.525,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.855,1.37),(0.855,7.035),(1.025,7.035),(1.025,5.655),(1.695,5.655),(1.695,5.325),(1.025,5.325),(1.025,1.785),(1.695,1.785),(1.695,1.37),(0.855,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.94), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.94), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,3.745),(1.19,3.745),(1.19,4.075),(1.46,4.075),(1.46,3.745),(1.41,3.745),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.67,0.78),(2.67,3.745),(2.6,3.745),(2.6,4.075),(2.87,4.075),(2.87,3.745),(2.82,3.745),(2.82,0.78),(2.67,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.24,5.365),(2.24,9.22),(2.39,9.22),(2.39,5.695),(2.67,5.695),(2.67,9.22),(2.82,9.22),(2.82,5.695),(2.87,5.695),(2.87,5.365),(2.24,5.365)),
        )
        createRL(
            tech, net, 'licon',
            ((2.65,3.825),(2.65,3.995),(2.82,3.995),(2.82,3.825),(2.65,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((1.24,3.825),(1.24,3.995),(1.41,3.995),(1.41,3.825),(1.24,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((2.65,5.445),(2.65,5.615),(2.82,5.615),(2.82,5.445),(2.65,5.445)),
        )
        createRL(
            tech, net, 'li',
            ((2.65,1.37),(2.65,3.745),(1.24,3.745),(1.24,4.075),(2.65,4.075),(2.65,8.63),(2.82,8.63),(2.82,1.37),(2.65,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.735), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.735), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1_n']
        createRL(
            tech, net, 'poly',
            ((1.19,4.825),(1.19,5.155),(1.26,5.155),(1.26,9.22),(1.41,9.22),(1.41,5.155),(1.46,5.155),(1.46,4.825),(1.19,4.825)),
        )
        createRL(
            tech, net, 'poly',
            ((2.24,0.78),(2.24,4.285),(2.17,4.285),(2.17,4.615),(3.21,4.615),(3.21,4.285),(2.39,4.285),(2.39,0.78),(2.24,0.78)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.82,0.91),(2.82,1.91),(3.2,1.91),(3.2,0.91),(2.82,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.82,7.09),(2.82,9.09),(3.2,9.09),(3.2,7.09),(2.82,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,7.285),(2.99,7.455),(3.16,7.455),(3.16,7.285),(2.99,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,7.625),(2.99,7.795),(3.16,7.795),(3.16,7.625),(2.99,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,7.965),(2.99,8.135),(3.16,8.135),(3.16,7.965),(2.99,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,8.305),(2.99,8.475),(3.16,8.475),(3.16,8.305),(2.99,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,4.365),(2.99,4.535),(3.16,4.535),(3.16,4.365),(2.99,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((1.24,4.905),(1.24,5.075),(1.41,5.075),(1.41,4.905),(1.24,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.22,4.365),(2.22,4.535),(2.39,4.535),(2.39,4.365),(2.22,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,1.535),(2.99,1.705),(3.16,1.705),(3.16,1.535),(2.99,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((2.22,4.285),(2.22,4.825),(1.24,4.825),(1.24,5.155),(2.39,5.155),(2.39,4.285),(2.22,4.285)),
        )
        createRL(
            tech, net, 'li',
            ((2.99,1.37),(2.99,8.63),(3.16,8.63),(3.16,1.37),(2.99,1.37)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.96,0.91),(1.96,1.91),(2.24,1.91),(2.24,0.91),(1.96,0.91)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)

    cell = new_cells['nexor2_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(4.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            'i0': Net.create(cell, 'i0'),
            'i0_n': Net.create(cell, 'i0_n'),
            'i1': Net.create(cell, 'i1'),
            'i1_n': Net.create(cell, 'i1_n'),
            'nq': Net.create(cell, 'nq'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['i0_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.365),(0.175,4.535),(0.345,4.535),(0.345,4.365),(0.175,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.81,0.78),(1.81,4.285),(0.125,4.285),(0.125,4.615),(1.81,4.615),(1.81,9.22),(1.96,9.22),(1.96,0.78),(1.81,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(4.0,4.8),(4.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(4.0,10.0),(4.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(4.0,0.51),(4.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(4.0,9.215),(4.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(4.18,10.18),(4.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,7.09),(1.26,9.09),(1.41,9.09),(1.41,7.09),(1.26,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(3.865,9.865),(3.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(0.98,9.09),(0.98,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.24,7.09),(2.24,9.09),(2.82,9.09),(2.82,7.09),(2.24,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.81,7.09),(1.81,9.09),(1.96,9.09),(1.96,7.09),(1.81,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.445,8.8),(2.445,8.97),(2.615,8.97),(2.615,8.8),(2.445,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,9.655),(0.385,9.825),(0.555,9.825),(0.555,9.655),(0.385,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,9.655),(0.725,9.825),(0.895,9.825),(0.895,9.655),(0.725,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,9.655),(1.065,9.825),(1.235,9.825),(1.235,9.655),(1.065,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,9.655),(1.405,9.825),(1.575,9.825),(1.575,9.655),(1.405,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,9.655),(1.745,9.825),(1.915,9.825),(1.915,9.655),(1.745,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,9.655),(2.085,9.825),(2.255,9.825),(2.255,9.655),(2.085,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,9.655),(2.425,9.825),(2.595,9.825),(2.595,9.655),(2.425,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,9.655),(2.765,9.825),(2.935,9.825),(2.935,9.655),(2.765,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,9.655),(3.105,9.825),(3.275,9.825),(3.275,9.655),(3.105,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,9.655),(3.445,9.825),(3.615,9.825),(3.615,9.655),(3.445,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(4.0,10.0),(4.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((1.81,0.91),(1.81,1.91),(1.96,1.91),(1.96,0.91),(1.81,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(3.865,0.385),(3.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.26,0.91),(1.26,1.91),(1.41,1.91),(1.41,0.91),(1.26,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.24,0.91),(2.24,1.91),(2.82,1.91),(2.82,0.91),(2.24,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.98,1.91),(0.98,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.385,0.175),(0.385,0.345),(0.555,0.345),(0.555,0.175),(0.385,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.725,0.175),(0.725,0.345),(0.895,0.345),(0.895,0.175),(0.725,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.065,0.175),(1.065,0.345),(1.235,0.345),(1.235,0.175),(1.065,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.405,0.175),(1.405,0.345),(1.575,0.345),(1.575,0.175),(1.405,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.745,0.175),(1.745,0.345),(1.915,0.345),(1.915,0.175),(1.745,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.085,0.175),(2.085,0.345),(2.255,0.345),(2.255,0.175),(2.085,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.425,0.175),(2.425,0.345),(2.595,0.345),(2.595,0.175),(2.425,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.765,0.175),(2.765,0.345),(2.935,0.345),(2.935,0.175),(2.765,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.105,0.175),(3.105,0.345),(3.275,0.345),(3.275,0.175),(3.105,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.445,0.175),(3.445,0.345),(3.615,0.345),(3.615,0.175),(3.445,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.445,1.03),(2.445,1.2),(2.615,1.2),(2.615,1.03),(2.445,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(4.0,1.2),(4.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.0), u(4.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i0']
        createRL(
            tech, net, 'poly',
            ((0.4,5.365),(0.4,9.22),(0.55,9.22),(0.55,5.695),(0.83,5.695),(0.83,9.22),(0.98,9.22),(0.98,5.365),(0.4,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.075),(0.98,4.075),(0.98,0.78),(0.83,0.78),(0.83,3.745),(0.55,3.745),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.445),(0.515,5.615),(0.685,5.615),(0.685,5.445),(0.515,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,3.825),(0.515,3.995),(0.685,3.995),(0.685,3.825),(0.515,3.825)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.98,0.91),(0.98,1.91),(1.26,1.91),(1.26,0.91),(0.98,0.91)),
        )
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((0.98,7.09),(0.98,9.09),(1.26,9.09),(1.26,7.09),(0.98,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.96,7.09),(1.96,9.09),(2.24,9.09),(2.24,7.09),(1.96,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.285),(1.035,7.455),(1.205,7.455),(1.205,7.285),(1.035,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.625),(1.035,7.795),(1.205,7.795),(1.205,7.625),(1.035,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,7.965),(1.035,8.135),(1.205,8.135),(1.205,7.965),(1.035,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.305),(1.035,8.475),(1.205,8.475),(1.205,8.305),(1.035,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,7.285),(2.015,7.455),(2.185,7.455),(2.185,7.285),(2.015,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,7.625),(2.015,7.795),(2.185,7.795),(2.185,7.625),(2.015,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,7.965),(2.015,8.135),(2.185,8.135),(2.185,7.965),(2.015,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.015,8.305),(2.015,8.475),(2.185,8.475),(2.185,8.305),(2.015,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((1.035,7.205),(1.035,8.63),(2.185,8.63),(2.185,7.205),(1.035,7.205)),
        )
        net = nets['nq']
        createRL(
            tech, net, 'difftap',
            ((1.485,5.285),(1.485,7.09),(1.41,7.09),(1.41,9.09),(1.81,9.09),(1.81,7.09),(1.735,7.09),(1.735,5.285),(1.485,5.285)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.41,0.91),(1.41,1.91),(1.81,1.91),(1.81,0.91),(1.41,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,5.405),(1.525,5.575),(1.695,5.575),(1.695,5.405),(1.525,5.405)),
        )
        createRL(
            tech, net, 'licon',
            ((1.525,1.535),(1.525,1.705),(1.695,1.705),(1.695,1.535),(1.525,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((0.855,1.37),(0.855,7.035),(1.025,7.035),(1.025,5.655),(1.695,5.655),(1.695,5.325),(1.025,5.325),(1.025,1.785),(1.695,1.785),(1.695,1.37),(0.855,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.94), u(0.17), u(1.37), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.94), u(0.17), u(1.37), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['i1_n']
        createRL(
            tech, net, 'poly',
            ((1.26,0.78),(1.26,3.745),(1.19,3.745),(1.19,4.075),(1.46,4.075),(1.46,3.745),(1.41,3.745),(1.41,0.78),(1.26,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.17,4.285),(2.17,4.615),(2.24,4.615),(2.24,9.22),(2.39,9.22),(2.39,4.615),(3.21,4.615),(3.21,4.285),(2.17,4.285)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.82,0.91),(2.82,1.91),(3.2,1.91),(3.2,0.91),(2.82,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.82,7.09),(2.82,9.09),(3.2,9.09),(3.2,7.09),(2.82,7.09)),
        )
        createRL(
            tech, net, 'li',
            ((2.99,1.37),(2.99,8.63),(3.16,8.63),(3.16,1.37),(2.99,1.37)),
        )
        createRL(
            tech, net, 'li',
            ((1.24,3.745),(1.24,4.075),(2.22,4.075),(2.22,4.615),(2.39,4.615),(2.39,3.745),(1.24,3.745)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,7.285),(2.99,7.455),(3.16,7.455),(3.16,7.285),(2.99,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,7.625),(2.99,7.795),(3.16,7.795),(3.16,7.625),(2.99,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,7.965),(2.99,8.135),(3.16,8.135),(3.16,7.965),(2.99,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,8.305),(2.99,8.475),(3.16,8.475),(3.16,8.305),(2.99,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,4.365),(2.99,4.535),(3.16,4.535),(3.16,4.365),(2.99,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((1.24,3.825),(1.24,3.995),(1.41,3.995),(1.41,3.825),(1.24,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((2.22,4.365),(2.22,4.535),(2.39,4.535),(2.39,4.365),(2.22,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((2.99,1.535),(2.99,1.705),(3.16,1.705),(3.16,1.535),(2.99,1.535)),
        )
        net = nets['i1']
        createRL(
            tech, net, 'poly',
            ((2.6,5.365),(2.6,5.695),(2.67,5.695),(2.67,9.22),(2.82,9.22),(2.82,5.695),(2.87,5.695),(2.87,5.365),(2.6,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((1.19,4.825),(1.19,5.155),(1.26,5.155),(1.26,9.22),(1.41,9.22),(1.41,5.155),(1.46,5.155),(1.46,4.825),(1.19,4.825)),
        )
        createRL(
            tech, net, 'poly',
            ((2.24,0.78),(2.24,4.075),(2.87,4.075),(2.87,3.745),(2.82,3.745),(2.82,0.78),(2.67,0.78),(2.67,3.745),(2.39,3.745),(2.39,0.78),(2.24,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((2.65,3.825),(2.65,3.995),(2.82,3.995),(2.82,3.825),(2.65,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((1.24,4.905),(1.24,5.075),(1.41,5.075),(1.41,4.905),(1.24,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.65,5.445),(2.65,5.615),(2.82,5.615),(2.82,5.445),(2.65,5.445)),
        )
        createRL(
            tech, net, 'li',
            ((2.65,1.37),(2.65,4.825),(1.24,4.825),(1.24,5.155),(2.65,5.155),(2.65,8.63),(2.82,8.63),(2.82,1.37),(2.65,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.735), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.735), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((1.96,0.91),(1.96,1.91),(2.24,1.91),(2.24,0.91),(1.96,0.91)),
        )
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i0'].setDirection(Net.Direction.IN)
        nets['i1'].setDirection(Net.Direction.IN)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['nsnrlatch_x0']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'nq': Net.create(cell, 'nq'),
            'nrst': Net.create(cell, 'nrst'),
            'nset': Net.create(cell, 'nset'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((0.55,7.09),(0.55,9.09),(0.83,9.09),(0.83,7.09),(0.55,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.24,4.905),(1.24,5.075),(1.41,5.075),(1.41,4.905),(1.24,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.285),(0.605,7.455),(0.775,7.455),(0.775,7.285),(0.605,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.625),(0.605,7.795),(0.775,7.795),(0.775,7.625),(0.605,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.965),(0.605,8.135),(0.775,8.135),(0.775,7.965),(0.605,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.305),(0.605,8.475),(0.775,8.475),(0.775,8.305),(0.605,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,1.785),(0.515,1.785),(0.515,8.63),(0.775,8.63),(0.775,7.205),(0.685,7.205),(0.685,5.155),(1.41,5.155),(1.41,4.825),(0.685,4.825),(0.685,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.285,0.78),(1.285,4.825),(1.19,4.825),(1.19,5.155),(1.285,5.155),(1.285,9.22),(1.435,9.22),(1.435,5.155),(1.46,5.155),(1.46,4.825),(1.435,4.825),(1.435,0.78),(1.285,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,9.22),(0.98,9.22),(0.98,0.78),(0.83,0.78)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((1.805,7.09),(1.805,9.09),(2.22,9.09),(2.22,7.09),(1.805,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,7.09),(0.83,9.09),(1.435,9.09),(1.435,7.09),(0.83,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.55,9.09),(0.55,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,8.8),(2.01,8.97),(2.18,8.97),(2.18,8.8),(2.01,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(0.55,1.91),(0.55,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,1.91),(1.435,1.91),(1.435,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.805,0.91),(1.805,1.91),(1.955,1.91),(1.955,0.91),(1.805,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,1.91),(0.83,1.91),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['nset']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.825),(0.125,4.825),(0.125,5.155),(0.4,5.155),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((1.805,0.78),(1.805,9.22),(1.955,9.22),(1.955,4.615),(2.005,4.615),(2.005,4.285),(1.955,4.285),(1.955,0.78),(1.805,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.905),(0.175,5.075),(0.345,5.075),(0.345,4.905),(0.175,4.905)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.955),(0.175,8.63),(0.345,8.63),(0.345,1.955),(0.175,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'poly',
            ((0.805,4.285),(0.805,4.615),(1.075,4.615),(1.075,4.285),(0.805,4.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,1.535),(2.01,1.705),(2.18,1.705),(2.18,1.535),(2.01,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.855,4.365),(0.855,4.535),(1.025,4.535),(1.025,4.365),(0.855,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,7.285),(1.58,7.455),(1.75,7.455),(1.75,7.285),(1.58,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,7.625),(1.58,7.795),(1.75,7.795),(1.75,7.625),(1.58,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,7.965),(1.58,8.135),(1.75,8.135),(1.75,7.965),(1.58,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,8.305),(1.58,8.475),(1.75,8.475),(1.75,8.305),(1.58,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((1.58,1.37),(1.58,4.285),(0.855,4.285),(0.855,4.615),(1.58,4.615),(1.58,8.63),(1.75,8.63),(1.75,1.785),(2.18,1.785),(2.18,1.37),(1.58,1.37)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.435,7.09),(1.435,9.09),(1.805,9.09),(1.805,7.09),(1.435,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.955,0.91),(1.955,1.91),(2.22,1.91),(2.22,0.91),(1.955,0.91)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.665), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.665), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((1.435,0.91),(1.435,1.91),(1.805,1.91),(1.805,0.91),(1.435,0.91)),
        )
        net = nets['nrst']
        createRL(
            tech, net, 'poly',
            ((1.87,4.285),(1.87,4.615),(2.14,4.615),(2.14,4.285),(1.87,4.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.92,4.365),(1.92,4.535),(2.09,4.535),(2.09,4.365),(1.92,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((1.92,1.955),(1.92,8.63),(2.09,8.63),(2.09,1.955),(1.92,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.005), u(0.17), u(1.955), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.005), u(0.17), u(1.955), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nset'].setDirection(Net.Direction.IN)
        nets['nrst'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['nsnrlatch_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(3.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            'nq': Net.create(cell, 'nq'),
            'nrst': Net.create(cell, 'nrst'),
            'nset': Net.create(cell, 'nset'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['q']
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,4.175),(0.4,4.175),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.55,5.265),(0.55,9.09),(0.83,9.09),(0.83,5.265),(0.55,5.265)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.465),(0.175,1.635),(0.345,1.635),(0.345,1.465),(0.175,1.465)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.805),(0.175,1.975),(0.345,1.975),(0.345,1.805),(0.175,1.805)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.145),(0.175,2.315),(0.345,2.315),(0.345,2.145),(0.175,2.145)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.485),(0.175,2.655),(0.345,2.655),(0.345,2.485),(0.175,2.485)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,2.825),(0.175,2.995),(0.345,2.995),(0.345,2.825),(0.175,2.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.165),(0.175,3.335),(0.345,3.335),(0.345,3.165),(0.175,3.165)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.505),(0.175,3.675),(0.345,3.675),(0.345,3.505),(0.175,3.505)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,3.845),(0.175,4.015),(0.345,4.015),(0.345,3.845),(0.175,3.845)),
        )
        createRL(
            tech, net, 'licon',
            ((1.24,4.905),(1.24,5.075),(1.41,5.075),(1.41,4.905),(1.24,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.535),(0.605,5.705),(0.775,5.705),(0.775,5.535),(0.605,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,5.875),(0.605,6.045),(0.775,6.045),(0.775,5.875),(0.605,5.875)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.215),(0.605,6.385),(0.775,6.385),(0.775,6.215),(0.605,6.215)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.555),(0.605,6.725),(0.775,6.725),(0.775,6.555),(0.605,6.555)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,6.895),(0.605,7.065),(0.775,7.065),(0.775,6.895),(0.605,6.895)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.235),(0.605,7.405),(0.775,7.405),(0.775,7.235),(0.605,7.235)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.575),(0.605,7.745),(0.775,7.745),(0.775,7.575),(0.605,7.575)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,7.915),(0.605,8.085),(0.775,8.085),(0.775,7.915),(0.605,7.915)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.255),(0.605,8.425),(0.775,8.425),(0.775,8.255),(0.605,8.255)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,4.115),(0.515,4.115),(0.515,8.63),(0.775,8.63),(0.775,5.325),(0.685,5.325),(0.685,5.155),(1.41,5.155),(1.41,4.825),(0.685,4.825),(0.685,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((1.285,0.78),(1.285,4.825),(1.19,4.825),(1.19,5.155),(1.285,5.155),(1.285,9.22),(1.435,9.22),(1.435,5.155),(1.46,5.155),(1.46,4.825),(1.435,4.825),(1.435,0.78),(1.285,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.83,0.78),(0.83,9.22),(0.98,9.22),(0.98,0.78),(0.83,0.78)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(3.0,10.0),(3.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(3.0,4.8),(3.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(3.0,0.51),(3.0,0.0),(0.0,0.0)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(3.0,9.215),(3.0,4.8),(0.0,4.8)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'difftap',
            ((0.83,5.265),(0.83,9.09),(1.435,9.09),(1.435,5.265),(0.83,5.265)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.805,5.265),(1.805,9.09),(2.22,9.09),(2.22,5.265),(1.805,5.265)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(2.865,9.865),(2.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,5.265),(0.135,9.09),(0.55,9.09),(0.55,5.265),(0.135,5.265)),
        )
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(3.18,10.18),(3.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,8.8),(1.035,8.97),(1.205,8.97),(1.205,8.8),(1.035,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,8.8),(2.01,8.97),(2.18,8.97),(2.18,8.8),(2.01,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.8),(0.175,8.97),(0.345,8.97),(0.345,8.8),(0.175,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,9.655),(0.395,9.825),(0.565,9.825),(0.565,9.655),(0.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,9.655),(0.735,9.825),(0.905,9.825),(0.905,9.655),(0.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,9.655),(1.075,9.825),(1.245,9.825),(1.245,9.655),(1.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,9.655),(1.415,9.825),(1.585,9.825),(1.585,9.655),(1.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,9.655),(1.755,9.825),(1.925,9.825),(1.925,9.655),(1.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,9.655),(2.095,9.825),(2.265,9.825),(2.265,9.655),(2.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,9.655),(2.435,9.825),(2.605,9.825),(2.605,9.655),(2.435,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(3.0,10.0),(3.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((1.805,0.91),(1.805,4.175),(1.955,4.175),(1.955,0.91),(1.805,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(2.865,0.385),(2.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.83,0.91),(0.83,4.175),(1.435,4.175),(1.435,0.91),(0.83,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,4.175),(0.55,4.175),(0.55,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,1.03),(1.035,1.2),(1.205,1.2),(1.205,1.03),(1.035,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.395,0.175),(0.395,0.345),(0.565,0.345),(0.565,0.175),(0.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.735,0.175),(0.735,0.345),(0.905,0.345),(0.905,0.175),(0.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.075,0.175),(1.075,0.345),(1.245,0.345),(1.245,0.175),(1.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.415,0.175),(1.415,0.345),(1.585,0.345),(1.585,0.175),(1.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.755,0.175),(1.755,0.345),(1.925,0.345),(1.925,0.175),(1.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.095,0.175),(2.095,0.345),(2.265,0.345),(2.265,0.175),(2.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.435,0.175),(2.435,0.345),(2.605,0.345),(2.605,0.175),(2.435,0.175)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(3.0,1.2),(3.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.5), u(3.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((0.55,0.91),(0.55,4.175),(0.83,4.175),(0.83,0.91),(0.55,0.91)),
        )
        net = nets['nset']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.825),(0.125,4.825),(0.125,5.155),(0.4,5.155),(0.4,9.22),(0.55,9.22),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((1.805,0.78),(1.805,9.22),(1.955,9.22),(1.955,4.615),(2.005,4.615),(2.005,4.285),(1.955,4.285),(1.955,0.78),(1.805,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.905),(0.175,5.075),(0.345,5.075),(0.345,4.905),(0.175,4.905)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,4.285),(0.175,8.63),(0.345,8.63),(0.345,4.285),(0.175,4.285)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.26), u(0.17), u(4.285), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.26), u(0.17), u(4.285), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['nq']
        createRL(
            tech, net, 'poly',
            ((0.805,4.285),(0.805,4.615),(1.075,4.615),(1.075,4.285),(0.805,4.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,5.535),(1.58,5.705),(1.75,5.705),(1.75,5.535),(1.58,5.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,5.875),(1.58,6.045),(1.75,6.045),(1.75,5.875),(1.58,5.875)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,6.215),(1.58,6.385),(1.75,6.385),(1.75,6.215),(1.58,6.215)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,6.555),(1.58,6.725),(1.75,6.725),(1.75,6.555),(1.58,6.555)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,6.895),(1.58,7.065),(1.75,7.065),(1.75,6.895),(1.58,6.895)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,7.235),(1.58,7.405),(1.75,7.405),(1.75,7.235),(1.58,7.235)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,7.575),(1.58,7.745),(1.75,7.745),(1.75,7.575),(1.58,7.575)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,7.915),(1.58,8.085),(1.75,8.085),(1.75,7.915),(1.58,7.915)),
        )
        createRL(
            tech, net, 'licon',
            ((1.58,8.255),(1.58,8.425),(1.75,8.425),(1.75,8.255),(1.58,8.255)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,1.465),(2.01,1.635),(2.18,1.635),(2.18,1.465),(2.01,1.465)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,1.805),(2.01,1.975),(2.18,1.975),(2.18,1.805),(2.01,1.805)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,2.145),(2.01,2.315),(2.18,2.315),(2.18,2.145),(2.01,2.145)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,2.485),(2.01,2.655),(2.18,2.655),(2.18,2.485),(2.01,2.485)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,2.825),(2.01,2.995),(2.18,2.995),(2.18,2.825),(2.01,2.825)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,3.165),(2.01,3.335),(2.18,3.335),(2.18,3.165),(2.01,3.165)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,3.505),(2.01,3.675),(2.18,3.675),(2.18,3.505),(2.01,3.505)),
        )
        createRL(
            tech, net, 'licon',
            ((2.01,3.845),(2.01,4.015),(2.18,4.015),(2.18,3.845),(2.01,3.845)),
        )
        createRL(
            tech, net, 'licon',
            ((0.855,4.365),(0.855,4.535),(1.025,4.535),(1.025,4.365),(0.855,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((1.58,1.37),(1.58,4.285),(0.855,4.285),(0.855,4.615),(1.58,4.615),(1.58,8.63),(1.75,8.63),(1.75,4.115),(2.18,4.115),(2.18,1.37),(1.58,1.37)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.955,0.91),(1.955,4.175),(2.22,4.175),(2.22,0.91),(1.955,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.435,5.265),(1.435,9.09),(1.805,9.09),(1.805,5.265),(1.435,5.265)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.665), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.665), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((1.435,0.91),(1.435,4.175),(1.805,4.175),(1.805,0.91),(1.435,0.91)),
        )
        net = nets['nrst']
        createRL(
            tech, net, 'poly',
            ((1.87,4.285),(1.87,4.615),(2.14,4.615),(2.14,4.285),(1.87,4.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.92,4.365),(1.92,4.535),(2.09,4.535),(2.09,4.365),(1.92,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((1.92,4.285),(1.92,8.63),(2.09,8.63),(2.09,4.285),(1.92,4.285)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(2.005), u(0.17), u(4.285), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(2.005), u(0.17), u(4.285), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['nset'].setDirection(Net.Direction.IN)
        nets['nrst'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['nq'].setDirection(Net.Direction.OUT)

    cell = new_cells['dff_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(7.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_clk_buf': Net.create(cell, '_clk_buf'),
            '_clk_n': Net.create(cell, '_clk_n'),
            '_dff_m': Net.create(cell, '_dff_m'),
            '_dff_s': Net.create(cell, '_dff_s'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            '_net3': Net.create(cell, '_net3'),
            '_net4': Net.create(cell, '_net4'),
            '_net5': Net.create(cell, '_net5'),
            '_u': Net.create(cell, '_u'),
            '_y': Net.create(cell, '_y'),
            'clk': Net.create(cell, 'clk'),
            'i': Net.create(cell, 'i'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_clk_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((5.305,4.905),(5.305,5.075),(5.475,5.075),(5.475,4.905),(5.305,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.905),(0.175,5.075),(0.345,5.075),(0.345,4.905),(0.175,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.785,3.825),(2.785,3.995),(2.955,3.995),(2.955,3.825),(2.785,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((5.305,3.825),(5.305,3.995),(5.475,3.995),(5.475,3.825),(5.305,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.785,4.905),(2.785,5.075),(2.955,5.075),(2.955,4.905),(2.785,4.905)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'li',
            ((2.785,3.745),(2.785,5.155),(2.955,5.155),(2.955,3.745),(2.785,3.745)),
        )
        createRL(
            tech, net, 'li',
            ((5.305,3.745),(5.305,5.155),(5.475,5.155),(5.475,3.745),(5.305,3.745)),
        )
        createRL(
            tech, net, 'poly',
            ((0.945,0.78),(0.945,4.825),(0.125,4.825),(0.125,5.155),(0.945,5.155),(0.945,9.22),(1.095,9.22),(1.095,5.155),(3.215,5.155),(3.215,9.22),(3.365,9.22),(3.365,5.155),(4.85,5.155),(4.85,9.22),(5.0,9.22),(5.0,5.155),(5.525,5.155),(5.525,4.825),(1.095,4.825),(1.095,0.78),(0.945,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.755,0.78),(2.755,3.745),(2.735,3.745),(2.735,4.075),(3.005,4.075),(3.005,3.745),(2.905,3.745),(2.905,0.78),(2.755,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((5.28,0.78),(5.28,3.745),(5.255,3.745),(5.255,4.075),(5.525,4.075),(5.525,3.745),(5.43,3.745),(5.43,0.78),(5.28,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(7.0,4.8),(7.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(7.0,10.0),(7.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(7.0,9.215),(7.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(7.0,0.51),(7.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(7.18,10.18),(7.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(1.095,9.09),(1.095,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.85,7.09),(4.85,9.09),(5.0,9.09),(5.0,7.09),(4.85,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(6.865,9.865),(6.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.28,7.09),(5.28,9.09),(5.43,9.09),(5.43,7.09),(5.28,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.215,7.09),(3.215,9.09),(3.365,9.09),(3.365,7.09),(3.215,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.895,7.09),(1.895,9.09),(2.475,9.09),(2.475,7.09),(1.895,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.755,7.09),(2.755,9.09),(2.905,9.09),(2.905,7.09),(2.755,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.96,5.805),(5.96,7.09),(5.735,7.09),(5.735,9.09),(6.565,9.09),(6.565,5.805),(5.96,5.805)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.645,7.09),(3.645,9.09),(4.385,9.09),(4.385,7.09),(3.645,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((3.85,8.8),(3.85,8.97),(4.02,8.97),(4.02,8.8),(3.85,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.1,8.8),(2.1,8.97),(2.27,8.97),(2.27,8.8),(2.1,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((6.0,8.8),(6.0,8.97),(6.17,8.97),(6.17,8.8),(6.0,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.355,9.655),(0.355,9.825),(0.525,9.825),(0.525,9.655),(0.355,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.695,9.655),(0.695,9.825),(0.865,9.825),(0.865,9.655),(0.695,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,9.655),(1.035,9.825),(1.205,9.825),(1.205,9.655),(1.035,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.375,9.655),(1.375,9.825),(1.545,9.825),(1.545,9.655),(1.375,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.715,9.655),(1.715,9.825),(1.885,9.825),(1.885,9.655),(1.715,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.055,9.655),(2.055,9.825),(2.225,9.825),(2.225,9.655),(2.055,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.395,9.655),(2.395,9.825),(2.565,9.825),(2.565,9.655),(2.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.735,9.655),(2.735,9.825),(2.905,9.825),(2.905,9.655),(2.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.075,9.655),(3.075,9.825),(3.245,9.825),(3.245,9.655),(3.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.415,9.655),(3.415,9.825),(3.585,9.825),(3.585,9.655),(3.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.755,9.655),(3.755,9.825),(3.925,9.825),(3.925,9.655),(3.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((4.095,9.655),(4.095,9.825),(4.265,9.825),(4.265,9.655),(4.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((4.435,9.655),(4.435,9.825),(4.605,9.825),(4.605,9.655),(4.435,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((4.775,9.655),(4.775,9.825),(4.945,9.825),(4.945,9.655),(4.775,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((5.115,9.655),(5.115,9.825),(5.285,9.825),(5.285,9.655),(5.115,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((5.455,9.655),(5.455,9.825),(5.625,9.825),(5.625,9.655),(5.455,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((5.795,9.655),(5.795,9.825),(5.965,9.825),(5.965,9.655),(5.795,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((6.135,9.655),(6.135,9.825),(6.305,9.825),(6.305,9.655),(6.135,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((6.475,9.655),(6.475,9.825),(6.645,9.825),(6.645,9.655),(6.475,9.655)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(7.0,10.0),(7.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(3.5), u(7.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(3.5), u(7.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(1.095,1.91),(1.095,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.645,0.91),(3.645,1.91),(4.385,1.91),(4.385,0.91),(3.645,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.735,0.91),(5.735,1.91),(5.96,1.91),(5.96,3.635),(6.565,3.635),(6.565,0.91),(5.735,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.28,0.91),(5.28,1.91),(5.43,1.91),(5.43,0.91),(5.28,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(6.865,0.385),(6.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.895,0.91),(1.895,1.91),(2.475,1.91),(2.475,0.91),(1.895,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.85,0.91),(4.85,1.91),(5.0,1.91),(5.0,0.91),(4.85,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.215,0.91),(3.215,1.91),(3.365,1.91),(3.365,0.91),(3.215,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.755,0.91),(2.755,1.91),(2.905,1.91),(2.905,0.91),(2.755,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.355,0.175),(0.355,0.345),(0.525,0.345),(0.525,0.175),(0.355,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.695,0.175),(0.695,0.345),(0.865,0.345),(0.865,0.175),(0.695,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.035,0.175),(1.035,0.345),(1.205,0.345),(1.205,0.175),(1.035,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.375,0.175),(1.375,0.345),(1.545,0.345),(1.545,0.175),(1.375,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.715,0.175),(1.715,0.345),(1.885,0.345),(1.885,0.175),(1.715,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.055,0.175),(2.055,0.345),(2.225,0.345),(2.225,0.175),(2.055,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.395,0.175),(2.395,0.345),(2.565,0.345),(2.565,0.175),(2.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.735,0.175),(2.735,0.345),(2.905,0.345),(2.905,0.175),(2.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.075,0.175),(3.075,0.345),(3.245,0.345),(3.245,0.175),(3.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.415,0.175),(3.415,0.345),(3.585,0.345),(3.585,0.175),(3.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.755,0.175),(3.755,0.345),(3.925,0.345),(3.925,0.175),(3.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((4.095,0.175),(4.095,0.345),(4.265,0.345),(4.265,0.175),(4.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((4.435,0.175),(4.435,0.345),(4.605,0.345),(4.605,0.175),(4.435,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((4.775,0.175),(4.775,0.345),(4.945,0.345),(4.945,0.175),(4.775,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((5.115,0.175),(5.115,0.345),(5.285,0.345),(5.285,0.175),(5.115,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((5.455,0.175),(5.455,0.345),(5.625,0.345),(5.625,0.175),(5.455,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((5.795,0.175),(5.795,0.345),(5.965,0.345),(5.965,0.175),(5.795,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((6.135,0.175),(6.135,0.345),(6.305,0.345),(6.305,0.175),(6.135,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((6.475,0.175),(6.475,0.345),(6.645,0.345),(6.645,0.175),(6.475,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.85,1.03),(3.85,1.2),(4.02,1.2),(4.02,1.03),(3.85,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((2.1,1.03),(2.1,1.2),(2.27,1.2),(2.27,1.03),(2.1,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((6.0,1.03),(6.0,1.2),(6.17,1.2),(6.17,1.03),(6.0,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(7.0,1.2),(7.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(3.5), u(7.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(3.5), u(7.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['clk']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.615),(0.735,4.615),(0.735,4.285),(0.55,4.285),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,5.365),(0.4,9.22),(0.55,9.22),(0.55,5.695),(0.735,5.695),(0.735,5.365),(0.4,5.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.445),(0.515,5.615),(0.685,5.615),(0.685,5.445),(0.515,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,4.365),(0.515,4.535),(0.685,4.535),(0.685,4.365),(0.515,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_clk_buf']
        createRL(
            tech, net, 'difftap',
            ((1.095,7.09),(1.095,9.09),(1.36,9.09),(1.36,7.09),(1.095,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.095,0.91),(1.095,1.91),(1.36,1.91),(1.36,0.91),(1.095,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((5.26,5.445),(5.26,5.615),(5.43,5.615),(5.43,5.445),(5.26,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((3.125,4.365),(3.125,4.535),(3.295,4.535),(3.295,4.365),(3.125,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((4.965,4.365),(4.965,4.535),(5.135,4.535),(5.135,4.365),(4.965,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((2.785,5.445),(2.785,5.615),(2.955,5.615),(2.955,5.445),(2.785,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.535),(1.15,1.705),(1.32,1.705),(1.32,1.535),(1.15,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.285),(1.15,7.455),(1.32,7.455),(1.32,7.285),(1.15,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.625),(1.15,7.795),(1.32,7.795),(1.32,7.625),(1.15,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.965),(1.15,8.135),(1.32,8.135),(1.32,7.965),(1.15,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.305),(1.15,8.475),(1.32,8.475),(1.32,8.305),(1.15,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((1.355,4.365),(1.355,4.535),(1.525,4.535),(1.525,4.365),(1.355,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,8.63),(1.32,8.63),(1.32,4.615),(1.525,4.615),(1.525,4.285),(1.32,4.285),(1.32,1.37),(1.15,1.37)),
        )
        createRL(
            tech, net, 'li',
            ((4.965,4.285),(4.965,5.695),(5.43,5.695),(5.43,5.365),(5.135,5.365),(5.135,4.285),(4.965,4.285)),
        )
        createRL(
            tech, net, 'li',
            ((3.125,4.285),(3.125,5.365),(2.785,5.365),(2.785,5.695),(3.295,5.695),(3.295,4.285),(3.125,4.285)),
        )
        createRL(
            tech, net, 'poly',
            ((2.735,5.365),(2.735,5.695),(2.755,5.695),(2.755,9.22),(2.905,9.22),(2.905,5.695),(3.005,5.695),(3.005,5.365),(2.735,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((3.215,0.78),(3.215,4.285),(1.305,4.285),(1.305,4.615),(5.185,4.615),(5.185,4.285),(5.0,4.285),(5.0,0.78),(4.85,0.78),(4.85,4.285),(3.365,4.285),(3.365,0.78),(3.215,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((5.21,5.365),(5.21,5.695),(5.28,5.695),(5.28,9.22),(5.43,9.22),(5.43,5.695),(5.48,5.695),(5.48,5.365),(5.21,5.365)),
        )
        net = nets['_u']
        createRL(
            tech, net, 'difftap',
            ((1.63,7.09),(1.63,9.09),(1.895,9.09),(1.895,7.09),(1.63,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.63,0.91),(1.63,1.91),(1.895,1.91),(1.895,0.91),(1.63,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((2.305,5.445),(2.305,5.615),(2.475,5.615),(2.475,5.445),(2.305,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,1.535),(1.67,1.705),(1.84,1.705),(1.84,1.535),(1.67,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,7.285),(1.67,7.455),(1.84,7.455),(1.84,7.285),(1.67,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,7.625),(1.67,7.795),(1.84,7.795),(1.84,7.625),(1.67,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,7.965),(1.67,8.135),(1.84,8.135),(1.84,7.965),(1.67,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,8.305),(1.67,8.475),(1.84,8.475),(1.84,8.305),(1.67,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.305,3.825),(2.305,3.995),(2.475,3.995),(2.475,3.825),(2.305,3.825)),
        )
        createRL(
            tech, net, 'li',
            ((1.67,1.37),(1.67,1.785),(2.305,1.785),(2.305,7.205),(1.67,7.205),(1.67,8.63),(2.39,8.63),(2.39,7.535),(2.475,7.535),(2.475,1.455),(2.39,1.455),(2.39,1.37),(1.67,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((2.325,0.78),(2.325,3.745),(2.255,3.745),(2.255,4.075),(2.525,4.075),(2.525,3.745),(2.475,3.745),(2.475,0.78),(2.325,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.255,5.365),(2.255,5.695),(2.325,5.695),(2.325,9.22),(2.475,9.22),(2.475,5.695),(2.525,5.695),(2.525,5.365),(2.255,5.365)),
        )
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((1.645,5.365),(1.645,5.695),(1.895,5.695),(1.895,9.22),(2.045,9.22),(2.045,5.365),(1.645,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((1.895,0.78),(1.895,3.745),(1.645,3.745),(1.645,4.075),(2.045,4.075),(2.045,0.78),(1.895,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,5.445),(1.695,5.615),(1.865,5.615),(1.865,5.445),(1.695,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,3.825),(1.695,3.995),(1.865,3.995),(1.865,3.825),(1.695,3.825)),
        )
        createRL(
            tech, net, 'li',
            ((1.695,1.955),(1.695,7.035),(1.865,7.035),(1.865,1.955),(1.695,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.78), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.78), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((2.475,0.91),(2.475,1.91),(2.755,1.91),(2.755,0.91),(2.475,0.91)),
        )
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((2.475,7.09),(2.475,9.09),(2.755,9.09),(2.755,7.09),(2.475,7.09)),
        )
        net = nets['_dff_m']
        createRL(
            tech, net, 'difftap',
            ((2.905,7.09),(2.905,9.09),(3.215,9.09),(3.215,7.09),(2.905,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.905,0.91),(2.905,1.91),(3.215,1.91),(3.215,0.91),(2.905,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((4.285,3.825),(4.285,3.995),(4.455,3.995),(4.455,3.825),(4.285,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,1.535),(2.96,1.705),(3.13,1.705),(3.13,1.535),(2.96,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,7.285),(2.96,7.455),(3.13,7.455),(3.13,7.285),(2.96,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,7.625),(2.96,7.795),(3.13,7.795),(3.13,7.625),(2.96,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,7.965),(2.96,8.135),(3.13,8.135),(3.13,7.965),(2.96,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,8.305),(2.96,8.475),(3.13,8.475),(3.13,8.305),(2.96,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((4.285,5.445),(4.285,5.615),(4.455,5.615),(4.455,5.445),(4.285,5.445)),
        )
        createRL(
            tech, net, 'li',
            ((2.96,1.37),(2.96,1.785),(3.465,1.785),(3.465,7.205),(2.96,7.205),(2.96,8.63),(4.37,8.63),(4.37,7.535),(4.455,7.535),(4.455,3.745),(4.285,3.745),(4.285,7.205),(3.635,7.205),(3.635,1.455),(3.55,1.455),(3.55,1.37),(2.96,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((4.235,0.78),(4.235,4.075),(4.505,4.075),(4.505,3.745),(4.385,3.745),(4.385,0.78),(4.235,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((4.235,5.365),(4.235,9.22),(4.385,9.22),(4.385,5.695),(4.505,5.695),(4.505,5.365),(4.235,5.365)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((3.365,0.91),(3.365,1.91),(3.645,1.91),(3.645,0.91),(3.365,0.91)),
        )
        net = nets['_net3']
        createRL(
            tech, net, 'difftap',
            ((3.365,7.09),(3.365,9.09),(3.645,9.09),(3.645,7.09),(3.365,7.09)),
        )
        net = nets['_y']
        createRL(
            tech, net, 'poly',
            ((3.645,5.365),(3.645,9.22),(3.795,9.22),(3.795,5.695),(4.025,5.695),(4.025,5.365),(3.645,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((3.645,0.78),(3.645,4.075),(4.025,4.075),(4.025,3.745),(3.795,3.745),(3.795,0.78),(3.645,0.78)),
        )
        createRL(
            tech, net, 'li',
            ((3.89,1.37),(3.89,1.455),(3.805,1.455),(3.805,5.695),(3.975,5.695),(3.975,1.785),(4.625,1.785),(4.625,8.63),(4.795,8.63),(4.795,1.37),(3.89,1.37)),
        )
        createRL(
            tech, net, 'licon',
            ((3.805,3.825),(3.805,3.995),(3.975,3.995),(3.975,3.825),(3.805,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((3.805,5.445),(3.805,5.615),(3.975,5.615),(3.975,5.445),(3.805,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,7.285),(4.625,7.455),(4.795,7.455),(4.795,7.285),(4.625,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,7.625),(4.625,7.795),(4.795,7.795),(4.795,7.625),(4.625,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,7.965),(4.625,8.135),(4.795,8.135),(4.795,7.965),(4.625,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,8.305),(4.625,8.475),(4.795,8.475),(4.795,8.305),(4.625,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,1.535),(4.625,1.705),(4.795,1.705),(4.795,1.535),(4.625,1.535)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.385,7.09),(4.385,9.09),(4.85,9.09),(4.85,7.09),(4.385,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.385,0.91),(4.385,1.91),(4.85,1.91),(4.85,0.91),(4.385,0.91)),
        )
        net = nets['_dff_s']
        createRL(
            tech, net, 'difftap',
            ((5.0,0.91),(5.0,1.91),(5.28,1.91),(5.28,0.91),(5.0,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.0,7.09),(5.0,9.09),(5.28,9.09),(5.28,7.09),(5.0,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((5.645,4.365),(5.645,4.535),(5.815,4.535),(5.815,4.365),(5.645,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,1.535),(5.055,1.705),(5.225,1.705),(5.225,1.535),(5.055,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,7.285),(5.055,7.455),(5.225,7.455),(5.225,7.285),(5.055,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,7.625),(5.055,7.795),(5.225,7.795),(5.225,7.625),(5.055,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,7.965),(5.055,8.135),(5.225,8.135),(5.225,7.965),(5.055,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,8.305),(5.055,8.475),(5.225,8.475),(5.225,8.305),(5.055,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((5.055,1.37),(5.055,1.785),(5.645,1.785),(5.645,7.205),(5.055,7.205),(5.055,8.63),(5.73,8.63),(5.73,7.535),(5.815,7.535),(5.815,1.455),(5.73,1.455),(5.73,1.37),(5.055,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((6.415,0.78),(6.415,4.285),(5.595,4.285),(5.595,4.615),(6.415,4.615),(6.415,9.22),(6.565,9.22),(6.565,0.78),(6.415,0.78)),
        )
        net = nets['_net4']
        createRL(
            tech, net, 'difftap',
            ((5.43,0.91),(5.43,1.91),(5.735,1.91),(5.735,0.91),(5.43,0.91)),
        )
        net = nets['_net5']
        createRL(
            tech, net, 'difftap',
            ((5.43,7.09),(5.43,9.09),(5.735,9.09),(5.735,7.09),(5.43,7.09)),
        )
        net = nets['q']
        createRL(
            tech, net, 'li',
            ((5.985,1.37),(5.985,8.63),(6.79,8.63),(6.79,5.865),(6.155,5.865),(6.155,3.575),(6.79,3.575),(6.79,1.37),(5.985,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((5.735,4.825),(5.735,9.22),(5.885,9.22),(5.885,5.155),(6.205,5.155),(6.205,4.825),(5.735,4.825)),
        )
        createRL(
            tech, net, 'poly',
            ((5.735,0.78),(5.735,4.075),(6.205,4.075),(6.205,3.745),(5.885,3.745),(5.885,0.78),(5.735,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,5.975),(6.62,6.145),(6.79,6.145),(6.79,5.975),(6.62,5.975)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,6.315),(6.62,6.485),(6.79,6.485),(6.79,6.315),(6.62,6.315)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,6.655),(6.62,6.825),(6.79,6.825),(6.79,6.655),(6.62,6.655)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,6.995),(6.62,7.165),(6.79,7.165),(6.79,6.995),(6.62,6.995)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,7.335),(6.62,7.505),(6.79,7.505),(6.79,7.335),(6.62,7.335)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,7.675),(6.62,7.845),(6.79,7.845),(6.79,7.675),(6.62,7.675)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,8.015),(6.62,8.185),(6.79,8.185),(6.79,8.015),(6.62,8.015)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,8.355),(6.62,8.525),(6.79,8.525),(6.79,8.355),(6.62,8.355)),
        )
        createRL(
            tech, net, 'licon',
            ((5.985,4.905),(5.985,5.075),(6.155,5.075),(6.155,4.905),(5.985,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((5.985,3.825),(5.985,3.995),(6.155,3.995),(6.155,3.825),(5.985,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,1.535),(6.62,1.705),(6.79,1.705),(6.79,1.535),(6.62,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,1.875),(6.62,2.045),(6.79,2.045),(6.79,1.875),(6.62,1.875)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,2.215),(6.62,2.385),(6.79,2.385),(6.79,2.215),(6.62,2.215)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,2.555),(6.62,2.725),(6.79,2.725),(6.79,2.555),(6.62,2.555)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,2.895),(6.62,3.065),(6.79,3.065),(6.79,2.895),(6.62,2.895)),
        )
        createRL(
            tech, net, 'licon',
            ((6.62,3.235),(6.62,3.405),(6.79,3.405),(6.79,3.235),(6.62,3.235)),
        )
        createRL(
            tech, net, 'difftap',
            ((6.565,0.91),(6.565,3.635),(6.83,3.635),(6.83,0.91),(6.565,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((6.565,5.805),(6.565,9.09),(6.83,9.09),(6.83,5.805),(6.565,5.805)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(6.07), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(6.07), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['clk'].setType(Net.Type.CLOCK)
        nets['clk'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)

    cell = new_cells['dffnr_x1']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(0.0), u(9.0), u(10.0),
        ))
        nets = {
            '*': Net.create(cell, '*'),
            '_clk_buf': Net.create(cell, '_clk_buf'),
            '_clk_n': Net.create(cell, '_clk_n'),
            '_dff_m': Net.create(cell, '_dff_m'),
            '_dff_s': Net.create(cell, '_dff_s'),
            '_net0': Net.create(cell, '_net0'),
            '_net1': Net.create(cell, '_net1'),
            '_net2': Net.create(cell, '_net2'),
            '_net3': Net.create(cell, '_net3'),
            '_net4': Net.create(cell, '_net4'),
            '_net5': Net.create(cell, '_net5'),
            '_net6': Net.create(cell, '_net6'),
            '_net7': Net.create(cell, '_net7'),
            '_u': Net.create(cell, '_u'),
            '_y': Net.create(cell, '_y'),
            'clk': Net.create(cell, 'clk'),
            'i': Net.create(cell, 'i'),
            'nrst': Net.create(cell, 'nrst'),
            'q': Net.create(cell, 'q'),
            'vdd': Net.create(cell, 'vdd'),
            'vss': Net.create(cell, 'vss'),
        }
        net = nets['_clk_n']
        createRL(
            tech, net, 'difftap',
            ((0.135,7.09),(0.135,9.09),(0.4,9.09),(0.4,7.09),(0.135,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.91),(0.135,1.91),(0.4,1.91),(0.4,0.91),(0.135,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,4.905),(0.175,5.075),(0.345,5.075),(0.345,4.905),(0.175,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.785,3.825),(2.785,3.995),(2.955,3.995),(2.955,3.825),(2.785,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.285),(0.175,7.455),(0.345,7.455),(0.345,7.285),(0.175,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.625),(0.175,7.795),(0.345,7.795),(0.345,7.625),(0.175,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,7.965),(0.175,8.135),(0.345,8.135),(0.345,7.965),(0.175,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,8.305),(0.175,8.475),(0.345,8.475),(0.345,8.305),(0.175,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((0.175,1.535),(0.175,1.705),(0.345,1.705),(0.345,1.535),(0.175,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.785,4.905),(2.785,5.075),(2.955,5.075),(2.955,4.905),(2.785,4.905)),
        )
        createRL(
            tech, net, 'li',
            ((0.175,1.37),(0.175,8.63),(0.345,8.63),(0.345,1.37),(0.175,1.37)),
        )
        createRL(
            tech, net, 'li',
            ((2.785,3.745),(2.785,5.155),(2.955,5.155),(2.955,3.745),(2.785,3.745)),
        )
        createRL(
            tech, net, 'poly',
            ((0.945,0.78),(0.945,4.825),(0.125,4.825),(0.125,5.155),(0.945,5.155),(0.945,9.22),(1.095,9.22),(1.095,5.155),(3.215,5.155),(3.215,9.22),(3.365,9.22),(3.365,5.155),(6.45,5.155),(6.45,9.22),(6.6,9.22),(6.6,0.78),(6.45,0.78),(6.45,4.825),(1.095,4.825),(1.095,0.78),(0.945,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.755,0.78),(2.755,3.745),(2.735,3.745),(2.735,4.075),(3.005,4.075),(3.005,3.745),(2.905,3.745),(2.905,0.78),(2.755,0.78)),
        )
        net = nets['*']
        createRL(
            tech, net, 'nsdm',
            ((0.0,0.785),(0.0,4.8),(9.0,4.8),(9.0,0.785),(0.0,0.785)),
        )
        createRL(
            tech, net, 'nsdm',
            ((0.0,9.49),(0.0,10.0),(9.0,10.0),(9.0,9.49),(0.0,9.49)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,4.8),(0.0,9.215),(9.0,9.215),(9.0,4.8),(0.0,4.8)),
        )
        createRL(
            tech, net, 'psdm',
            ((0.0,0.0),(0.0,0.51),(9.0,0.51),(9.0,0.0),(0.0,0.0)),
        )
        net = nets['vdd']
        createRL(
            tech, net, 'nwm',
            ((-0.18,4.8),(-0.18,10.18),(9.18,10.18),(9.18,4.8),(-0.18,4.8)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,9.615),(0.135,9.865),(8.865,9.865),(8.865,9.615),(0.135,9.615)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.4,7.09),(0.4,9.09),(1.095,9.09),(1.095,7.09),(0.4,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.215,7.09),(3.215,9.09),(3.365,9.09),(3.365,7.09),(3.215,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((6.45,7.09),(6.45,9.09),(6.6,9.09),(6.6,7.09),(6.45,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.895,7.09),(1.895,9.09),(2.475,9.09),(2.475,7.09),(1.895,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.85,7.09),(4.85,9.09),(5.43,9.09),(5.43,7.09),(4.85,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((7.655,5.805),(7.655,7.09),(7.43,7.09),(7.43,9.09),(8.125,9.09),(8.125,5.805),(7.655,5.805)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.755,7.09),(2.755,9.09),(2.905,9.09),(2.905,7.09),(2.755,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.645,7.09),(3.645,9.09),(4.385,9.09),(4.385,7.09),(3.645,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((7.0,7.09),(7.0,9.09),(7.15,9.09),(7.15,7.09),(7.0,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((3.85,8.8),(3.85,8.97),(4.02,8.97),(4.02,8.8),(3.85,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((0.335,9.655),(0.335,9.825),(0.505,9.825),(0.505,9.655),(0.335,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.675,9.655),(0.675,9.825),(0.845,9.825),(0.845,9.655),(0.675,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.015,9.655),(1.015,9.825),(1.185,9.825),(1.185,9.655),(1.015,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.355,9.655),(1.355,9.825),(1.525,9.825),(1.525,9.655),(1.355,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,9.655),(1.695,9.825),(1.865,9.825),(1.865,9.655),(1.695,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.035,9.655),(2.035,9.825),(2.205,9.825),(2.205,9.655),(2.035,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.375,9.655),(2.375,9.825),(2.545,9.825),(2.545,9.655),(2.375,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((2.715,9.655),(2.715,9.825),(2.885,9.825),(2.885,9.655),(2.715,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.055,9.655),(3.055,9.825),(3.225,9.825),(3.225,9.655),(3.055,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.395,9.655),(3.395,9.825),(3.565,9.825),(3.565,9.655),(3.395,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((3.735,9.655),(3.735,9.825),(3.905,9.825),(3.905,9.655),(3.735,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((4.075,9.655),(4.075,9.825),(4.245,9.825),(4.245,9.655),(4.075,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((4.415,9.655),(4.415,9.825),(4.585,9.825),(4.585,9.655),(4.415,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((4.755,9.655),(4.755,9.825),(4.925,9.825),(4.925,9.655),(4.755,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((5.095,9.655),(5.095,9.825),(5.265,9.825),(5.265,9.655),(5.095,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((5.435,9.655),(5.435,9.825),(5.605,9.825),(5.605,9.655),(5.435,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((5.775,9.655),(5.775,9.825),(5.945,9.825),(5.945,9.655),(5.775,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((6.115,9.655),(6.115,9.825),(6.285,9.825),(6.285,9.655),(6.115,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((6.455,9.655),(6.455,9.825),(6.625,9.825),(6.625,9.655),(6.455,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((6.795,9.655),(6.795,9.825),(6.965,9.825),(6.965,9.655),(6.795,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((7.135,9.655),(7.135,9.825),(7.305,9.825),(7.305,9.655),(7.135,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((7.475,9.655),(7.475,9.825),(7.645,9.825),(7.645,9.655),(7.475,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((7.815,9.655),(7.815,9.825),(7.985,9.825),(7.985,9.655),(7.815,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((8.155,9.655),(8.155,9.825),(8.325,9.825),(8.325,9.655),(8.155,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((8.495,9.655),(8.495,9.825),(8.665,9.825),(8.665,9.655),(8.495,9.655)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,8.8),(0.605,8.97),(0.775,8.97),(0.775,8.8),(0.605,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((2.1,8.8),(2.1,8.97),(2.27,8.97),(2.27,8.8),(2.1,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,8.8),(5.055,8.97),(5.225,8.97),(5.225,8.8),(5.055,8.8)),
        )
        createRL(
            tech, net, 'licon',
            ((7.695,8.8),(7.695,8.97),(7.865,8.97),(7.865,8.8),(7.695,8.8)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,8.8),(0.0,10.0),(9.0,10.0),(9.0,8.8),(0.0,8.8)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(4.5), u(9.0), u(8.8), u(10.0),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(4.5), u(9.0), u(8.8), u(10.0),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['vss']
        createRL(
            tech, net, 'difftap',
            ((0.4,0.91),(0.4,1.91),(1.095,1.91),(1.095,0.91),(0.4,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.645,0.91),(3.645,1.91),(4.385,1.91),(4.385,0.91),(3.645,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.895,0.91),(1.895,1.91),(2.475,1.91),(2.475,0.91),(1.895,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.915,0.91),(5.915,1.91),(6.065,1.91),(6.065,0.91),(5.915,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((0.135,0.135),(0.135,0.385),(8.865,0.385),(8.865,0.135),(0.135,0.135)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.85,0.91),(4.85,1.91),(5.0,1.91),(5.0,0.91),(4.85,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((7.43,0.91),(7.43,1.91),(7.655,1.91),(7.655,3.635),(8.125,3.635),(8.125,0.91),(7.43,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((6.45,0.91),(6.45,1.91),(6.6,1.91),(6.6,0.91),(6.45,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((3.215,0.91),(3.215,1.91),(3.365,1.91),(3.365,0.91),(3.215,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((7.0,0.91),(7.0,1.91),(7.15,1.91),(7.15,0.91),(7.0,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.755,0.91),(2.755,1.91),(2.905,1.91),(2.905,0.91),(2.755,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((0.335,0.175),(0.335,0.345),(0.505,0.345),(0.505,0.175),(0.335,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((0.675,0.175),(0.675,0.345),(0.845,0.345),(0.845,0.175),(0.675,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.015,0.175),(1.015,0.345),(1.185,0.345),(1.185,0.175),(1.015,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.355,0.175),(1.355,0.345),(1.525,0.345),(1.525,0.175),(1.355,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,0.175),(1.695,0.345),(1.865,0.345),(1.865,0.175),(1.695,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.035,0.175),(2.035,0.345),(2.205,0.345),(2.205,0.175),(2.035,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.375,0.175),(2.375,0.345),(2.545,0.345),(2.545,0.175),(2.375,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((2.715,0.175),(2.715,0.345),(2.885,0.345),(2.885,0.175),(2.715,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.055,0.175),(3.055,0.345),(3.225,0.345),(3.225,0.175),(3.055,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.395,0.175),(3.395,0.345),(3.565,0.345),(3.565,0.175),(3.395,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((3.735,0.175),(3.735,0.345),(3.905,0.345),(3.905,0.175),(3.735,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((4.075,0.175),(4.075,0.345),(4.245,0.345),(4.245,0.175),(4.075,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((4.415,0.175),(4.415,0.345),(4.585,0.345),(4.585,0.175),(4.415,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((4.755,0.175),(4.755,0.345),(4.925,0.345),(4.925,0.175),(4.755,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((5.095,0.175),(5.095,0.345),(5.265,0.345),(5.265,0.175),(5.095,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((5.435,0.175),(5.435,0.345),(5.605,0.345),(5.605,0.175),(5.435,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((5.775,0.175),(5.775,0.345),(5.945,0.345),(5.945,0.175),(5.775,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((6.115,0.175),(6.115,0.345),(6.285,0.345),(6.285,0.175),(6.115,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((6.455,0.175),(6.455,0.345),(6.625,0.345),(6.625,0.175),(6.455,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((6.795,0.175),(6.795,0.345),(6.965,0.345),(6.965,0.175),(6.795,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((7.135,0.175),(7.135,0.345),(7.305,0.345),(7.305,0.175),(7.135,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((7.475,0.175),(7.475,0.345),(7.645,0.345),(7.645,0.175),(7.475,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((7.815,0.175),(7.815,0.345),(7.985,0.345),(7.985,0.175),(7.815,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((8.155,0.175),(8.155,0.345),(8.325,0.345),(8.325,0.175),(8.155,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((8.495,0.175),(8.495,0.345),(8.665,0.345),(8.665,0.175),(8.495,0.175)),
        )
        createRL(
            tech, net, 'licon',
            ((7.695,1.03),(7.695,1.2),(7.865,1.2),(7.865,1.03),(7.695,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((0.605,1.03),(0.605,1.2),(0.775,1.2),(0.775,1.03),(0.605,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((3.85,1.03),(3.85,1.2),(4.02,1.2),(4.02,1.03),(3.85,1.03)),
        )
        createRL(
            tech, net, 'licon',
            ((2.1,1.03),(2.1,1.2),(2.27,1.2),(2.27,1.03),(2.1,1.03)),
        )
        createRL(
            tech, net, 'li',
            ((0.0,0.0),(0.0,1.2),(9.0,1.2),(9.0,0.0),(0.0,0.0)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(4.5), u(9.0), u(0.0), u(1.2),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(4.5), u(9.0), u(0.0), u(1.2),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['clk']
        createRL(
            tech, net, 'poly',
            ((0.4,0.78),(0.4,4.615),(0.735,4.615),(0.735,4.285),(0.55,4.285),(0.55,0.78),(0.4,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((0.4,5.365),(0.4,9.22),(0.55,9.22),(0.55,5.695),(0.735,5.695),(0.735,5.365),(0.4,5.365)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,5.445),(0.515,5.615),(0.685,5.615),(0.685,5.445),(0.515,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((0.515,4.365),(0.515,4.535),(0.685,4.535),(0.685,4.365),(0.515,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((0.515,1.37),(0.515,8.63),(0.685,8.63),(0.685,1.37),(0.515,1.37)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(0.6), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_clk_buf']
        createRL(
            tech, net, 'difftap',
            ((1.095,7.09),(1.095,9.09),(1.36,9.09),(1.36,7.09),(1.095,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.095,0.91),(1.095,1.91),(1.36,1.91),(1.36,0.91),(1.095,0.91)),
        )
        createRL(
            tech, net, 'licon',
            ((3.125,4.365),(3.125,4.535),(3.295,4.535),(3.295,4.365),(3.125,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((6.86,4.905),(6.86,5.075),(7.03,5.075),(7.03,4.905),(6.86,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((2.785,5.445),(2.785,5.615),(2.955,5.615),(2.955,5.445),(2.785,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,1.535),(1.15,1.705),(1.32,1.705),(1.32,1.535),(1.15,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.285),(1.15,7.455),(1.32,7.455),(1.32,7.285),(1.15,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.625),(1.15,7.795),(1.32,7.795),(1.32,7.625),(1.15,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,7.965),(1.15,8.135),(1.32,8.135),(1.32,7.965),(1.15,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.15,8.305),(1.15,8.475),(1.32,8.475),(1.32,8.305),(1.15,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((5.305,4.365),(5.305,4.535),(5.475,4.535),(5.475,4.365),(5.305,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((1.355,4.365),(1.355,4.535),(1.525,4.535),(1.525,4.365),(1.355,4.365)),
        )
        createRL(
            tech, net, 'li',
            ((3.125,4.285),(3.125,5.365),(2.785,5.365),(2.785,5.695),(3.295,5.695),(3.295,4.285),(3.125,4.285)),
        )
        createRL(
            tech, net, 'li',
            ((1.15,1.37),(1.15,8.63),(1.32,8.63),(1.32,4.615),(1.525,4.615),(1.525,4.285),(1.32,4.285),(1.32,1.37),(1.15,1.37)),
        )
        createRL(
            tech, net, 'li',
            ((5.305,4.285),(5.305,5.155),(7.03,5.155),(7.03,4.825),(5.475,4.825),(5.475,4.285),(5.305,4.285)),
        )
        createRL(
            tech, net, 'poly',
            ((2.735,5.365),(2.735,5.695),(2.755,5.695),(2.755,9.22),(2.905,9.22),(2.905,5.695),(3.005,5.695),(3.005,5.365),(2.735,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((3.215,0.78),(3.215,4.285),(1.305,4.285),(1.305,4.615),(6.065,4.615),(6.065,0.78),(5.915,0.78),(5.915,4.285),(3.365,4.285),(3.365,0.78),(3.215,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((6.81,4.825),(6.81,5.155),(7.0,5.155),(7.0,9.22),(7.15,9.22),(7.15,4.825),(6.81,4.825)),
        )
        net = nets['_u']
        createRL(
            tech, net, 'difftap',
            ((1.63,0.91),(1.63,1.91),(1.895,1.91),(1.895,0.91),(1.63,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((1.63,7.09),(1.63,9.09),(1.895,9.09),(1.895,7.09),(1.63,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((2.305,5.445),(2.305,5.615),(2.475,5.615),(2.475,5.445),(2.305,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,1.535),(1.67,1.705),(1.84,1.705),(1.84,1.535),(1.67,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,7.285),(1.67,7.455),(1.84,7.455),(1.84,7.285),(1.67,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,7.625),(1.67,7.795),(1.84,7.795),(1.84,7.625),(1.67,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,7.965),(1.67,8.135),(1.84,8.135),(1.84,7.965),(1.67,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((1.67,8.305),(1.67,8.475),(1.84,8.475),(1.84,8.305),(1.67,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((2.305,3.825),(2.305,3.995),(2.475,3.995),(2.475,3.825),(2.305,3.825)),
        )
        createRL(
            tech, net, 'li',
            ((1.67,1.37),(1.67,1.785),(2.305,1.785),(2.305,7.205),(1.67,7.205),(1.67,8.63),(2.39,8.63),(2.39,7.535),(2.475,7.535),(2.475,1.455),(2.39,1.455),(2.39,1.37),(1.67,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((2.325,0.78),(2.325,3.745),(2.255,3.745),(2.255,4.075),(2.525,4.075),(2.525,3.745),(2.475,3.745),(2.475,0.78),(2.325,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((2.255,5.365),(2.255,5.695),(2.325,5.695),(2.325,9.22),(2.475,9.22),(2.475,5.695),(2.525,5.695),(2.525,5.365),(2.255,5.365)),
        )
        net = nets['i']
        createRL(
            tech, net, 'poly',
            ((1.645,5.365),(1.645,5.695),(1.895,5.695),(1.895,9.22),(2.045,9.22),(2.045,5.365),(1.645,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((1.895,0.78),(1.895,3.745),(1.645,3.745),(1.645,4.075),(2.045,4.075),(2.045,0.78),(1.895,0.78)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,5.445),(1.695,5.615),(1.865,5.615),(1.865,5.445),(1.695,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((1.695,3.825),(1.695,3.995),(1.865,3.995),(1.865,3.825),(1.695,3.825)),
        )
        createRL(
            tech, net, 'li',
            ((1.695,1.955),(1.695,7.035),(1.865,7.035),(1.865,1.955),(1.695,1.955)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(1.78), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(1.78), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net0']
        createRL(
            tech, net, 'difftap',
            ((2.475,0.91),(2.475,1.91),(2.755,1.91),(2.755,0.91),(2.475,0.91)),
        )
        net = nets['_net1']
        createRL(
            tech, net, 'difftap',
            ((2.475,7.09),(2.475,9.09),(2.755,9.09),(2.755,7.09),(2.475,7.09)),
        )
        net = nets['_dff_m']
        createRL(
            tech, net, 'difftap',
            ((2.905,0.91),(2.905,1.91),(3.215,1.91),(3.215,0.91),(2.905,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((2.905,7.09),(2.905,9.09),(3.215,9.09),(3.215,7.09),(2.905,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((4.285,3.825),(4.285,3.995),(4.455,3.995),(4.455,3.825),(4.285,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,1.535),(2.96,1.705),(3.13,1.705),(3.13,1.535),(2.96,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,7.285),(2.96,7.455),(3.13,7.455),(3.13,7.285),(2.96,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,7.625),(2.96,7.795),(3.13,7.795),(3.13,7.625),(2.96,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,7.965),(2.96,8.135),(3.13,8.135),(3.13,7.965),(2.96,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((2.96,8.305),(2.96,8.475),(3.13,8.475),(3.13,8.305),(2.96,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((4.285,5.445),(4.285,5.615),(4.455,5.615),(4.455,5.445),(4.285,5.445)),
        )
        createRL(
            tech, net, 'li',
            ((2.96,1.37),(2.96,1.785),(3.465,1.785),(3.465,7.205),(2.96,7.205),(2.96,8.63),(4.37,8.63),(4.37,7.535),(4.455,7.535),(4.455,3.745),(4.285,3.745),(4.285,7.205),(3.635,7.205),(3.635,1.455),(3.55,1.455),(3.55,1.37),(2.96,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((4.235,0.78),(4.235,4.075),(4.505,4.075),(4.505,3.745),(4.385,3.745),(4.385,0.78),(4.235,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((4.235,5.365),(4.235,9.22),(4.385,9.22),(4.385,5.695),(4.505,5.695),(4.505,5.365),(4.235,5.365)),
        )
        net = nets['_net2']
        createRL(
            tech, net, 'difftap',
            ((3.365,0.91),(3.365,1.91),(3.645,1.91),(3.645,0.91),(3.365,0.91)),
        )
        net = nets['_net3']
        createRL(
            tech, net, 'difftap',
            ((3.365,7.09),(3.365,9.09),(3.645,9.09),(3.645,7.09),(3.365,7.09)),
        )
        net = nets['_y']
        createRL(
            tech, net, 'poly',
            ((3.645,5.365),(3.645,9.22),(3.795,9.22),(3.795,5.695),(4.025,5.695),(4.025,5.365),(3.645,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((3.645,0.78),(3.645,4.075),(4.025,4.075),(4.025,3.745),(3.795,3.745),(3.795,0.78),(3.645,0.78)),
        )
        createRL(
            tech, net, 'li',
            ((3.89,1.37),(3.89,1.455),(3.805,1.455),(3.805,5.695),(3.975,5.695),(3.975,1.785),(4.625,1.785),(4.625,8.63),(5.39,8.63),(5.39,7.535),(5.475,7.535),(5.475,5.695),(6.335,5.695),(6.335,5.365),(5.305,5.365),(5.305,7.205),(4.795,7.205),(4.795,1.785),(5.225,1.785),(5.225,1.37),(3.89,1.37)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,7.285),(4.625,7.455),(4.795,7.455),(4.795,7.285),(4.625,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,7.625),(4.625,7.795),(4.795,7.795),(4.795,7.625),(4.625,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,7.965),(4.625,8.135),(4.795,8.135),(4.795,7.965),(4.625,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((4.625,8.305),(4.625,8.475),(4.795,8.475),(4.795,8.305),(4.625,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((5.055,1.535),(5.055,1.705),(5.225,1.705),(5.225,1.535),(5.055,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((3.805,3.825),(3.805,3.995),(3.975,3.995),(3.975,3.825),(3.805,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((6.165,5.445),(6.165,5.615),(6.335,5.615),(6.335,5.445),(6.165,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((3.805,5.445),(3.805,5.615),(3.975,5.615),(3.975,5.445),(3.805,5.445)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.0,0.91),(5.0,1.91),(5.915,1.91),(5.915,0.91),(5.0,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((4.385,7.09),(4.385,9.09),(4.85,9.09),(4.85,7.09),(4.385,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((6.125,5.325),(6.125,9.09),(6.45,9.09),(6.45,7.09),(6.375,7.09),(6.375,5.325),(6.125,5.325)),
        )
        net = nets['_net6']
        createRL(
            tech, net, 'difftap',
            ((4.385,0.91),(4.385,1.91),(4.85,1.91),(4.85,0.91),(4.385,0.91)),
        )
        net = nets['nrst']
        createRL(
            tech, net, 'poly',
            ((4.85,5.365),(4.85,9.22),(5.0,9.22),(5.0,5.695),(5.28,5.695),(5.28,9.22),(5.43,9.22),(5.43,5.365),(4.85,5.365)),
        )
        createRL(
            tech, net, 'poly',
            ((7.0,0.78),(7.0,3.745),(6.81,3.745),(6.81,4.075),(7.15,4.075),(7.15,0.78),(7.0,0.78)),
        )
        createRL(
            tech, net, 'poly',
            ((4.85,0.78),(4.85,4.075),(5.185,4.075),(5.185,3.745),(5.0,3.745),(5.0,0.78),(4.85,0.78)),
        )
        createRL(
            tech, net, 'li',
            ((4.965,1.955),(4.965,7.035),(5.135,7.035),(5.135,4.075),(7.03,4.075),(7.03,3.745),(5.135,3.745),(5.135,1.955),(4.965,1.955)),
        )
        createRL(
            tech, net, 'licon',
            ((6.86,3.825),(6.86,3.995),(7.03,3.995),(7.03,3.825),(6.86,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((4.965,3.825),(4.965,3.995),(5.135,3.995),(5.135,3.825),(4.965,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((4.965,5.445),(4.965,5.615),(5.135,5.615),(5.135,5.445),(4.965,5.445)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(5.05), u(0.17), u(1.955), u(7.035),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(5.05), u(0.17), u(1.955), u(7.035),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        net = nets['_net5']
        createRL(
            tech, net, 'difftap',
            ((7.15,7.09),(7.15,9.09),(7.43,9.09),(7.43,7.09),(7.15,7.09)),
        )
        createRL(
            tech, net, 'difftap',
            ((5.43,7.09),(5.43,9.09),(5.855,9.09),(5.855,7.09),(5.43,7.09)),
        )
        createRL(
            tech, net, 'licon',
            ((5.645,7.285),(5.645,7.455),(5.815,7.455),(5.815,7.285),(5.645,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((5.645,7.625),(5.645,7.795),(5.815,7.795),(5.815,7.625),(5.645,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((5.645,7.965),(5.645,8.135),(5.815,8.135),(5.815,7.965),(5.645,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((5.645,8.305),(5.645,8.475),(5.815,8.475),(5.815,8.305),(5.645,8.305)),
        )
        createRL(
            tech, net, 'licon',
            ((7.205,7.285),(7.205,7.455),(7.375,7.455),(7.375,7.285),(7.205,7.285)),
        )
        createRL(
            tech, net, 'licon',
            ((7.205,7.625),(7.205,7.795),(7.375,7.795),(7.375,7.625),(7.205,7.625)),
        )
        createRL(
            tech, net, 'licon',
            ((7.205,7.965),(7.205,8.135),(7.375,8.135),(7.375,7.965),(7.205,7.965)),
        )
        createRL(
            tech, net, 'licon',
            ((7.205,8.305),(7.205,8.475),(7.375,8.475),(7.375,8.305),(7.205,8.305)),
        )
        createRL(
            tech, net, 'li',
            ((5.645,7.205),(5.645,8.63),(7.375,8.63),(7.375,7.205),(5.645,7.205)),
        )
        net = nets['_dff_s']
        createRL(
            tech, net, 'difftap',
            ((6.065,0.91),(6.065,1.91),(6.45,1.91),(6.45,0.91),(6.065,0.91)),
        )
        createRL(
            tech, net, 'difftap',
            ((6.675,5.325),(6.675,7.09),(6.6,7.09),(6.6,9.09),(7.0,9.09),(7.0,7.09),(6.925,7.09),(6.925,5.325),(6.675,5.325)),
        )
        createRL(
            tech, net, 'licon',
            ((7.2,4.365),(7.2,4.535),(7.37,4.535),(7.37,4.365),(7.2,4.365)),
        )
        createRL(
            tech, net, 'licon',
            ((6.715,5.445),(6.715,5.615),(6.885,5.615),(6.885,5.445),(6.715,5.445)),
        )
        createRL(
            tech, net, 'licon',
            ((6.165,1.535),(6.165,1.705),(6.335,1.705),(6.335,1.535),(6.165,1.535)),
        )
        createRL(
            tech, net, 'li',
            ((6.165,1.37),(6.165,1.785),(7.2,1.785),(7.2,5.365),(6.715,5.365),(6.715,5.695),(7.37,5.695),(7.37,1.455),(7.285,1.455),(7.285,1.37),(6.165,1.37)),
        )
        createRL(
            tech, net, 'poly',
            ((7.975,0.78),(7.975,4.285),(7.15,4.285),(7.15,4.615),(7.975,4.615),(7.975,9.22),(8.125,9.22),(8.125,0.78),(7.975,0.78)),
        )
        net = nets['_net7']
        createRL(
            tech, net, 'difftap',
            ((6.6,0.91),(6.6,1.91),(7.0,1.91),(7.0,0.91),(6.6,0.91)),
        )
        net = nets['_net4']
        createRL(
            tech, net, 'difftap',
            ((7.15,0.91),(7.15,1.91),(7.43,1.91),(7.43,0.91),(7.15,0.91)),
        )
        net = nets['q']
        createRL(
            tech, net, 'poly',
            ((7.43,4.825),(7.43,9.22),(7.58,9.22),(7.58,5.155),(7.765,5.155),(7.765,4.825),(7.43,4.825)),
        )
        createRL(
            tech, net, 'poly',
            ((7.43,0.78),(7.43,4.075),(7.765,4.075),(7.765,3.745),(7.58,3.745),(7.58,0.78),(7.43,0.78)),
        )
        createRL(
            tech, net, 'li',
            ((7.545,1.37),(7.545,8.63),(8.35,8.63),(8.35,5.865),(7.715,5.865),(7.715,3.575),(8.35,3.575),(8.35,1.37),(7.545,1.37)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,1.535),(8.18,1.705),(8.35,1.705),(8.35,1.535),(8.18,1.535)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,1.875),(8.18,2.045),(8.35,2.045),(8.35,1.875),(8.18,1.875)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,2.215),(8.18,2.385),(8.35,2.385),(8.35,2.215),(8.18,2.215)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,2.555),(8.18,2.725),(8.35,2.725),(8.35,2.555),(8.18,2.555)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,2.895),(8.18,3.065),(8.35,3.065),(8.35,2.895),(8.18,2.895)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,3.235),(8.18,3.405),(8.35,3.405),(8.35,3.235),(8.18,3.235)),
        )
        createRL(
            tech, net, 'licon',
            ((7.545,3.825),(7.545,3.995),(7.715,3.995),(7.715,3.825),(7.545,3.825)),
        )
        createRL(
            tech, net, 'licon',
            ((7.545,4.905),(7.545,5.075),(7.715,5.075),(7.715,4.905),(7.545,4.905)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,5.975),(8.18,6.145),(8.35,6.145),(8.35,5.975),(8.18,5.975)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,6.315),(8.18,6.485),(8.35,6.485),(8.35,6.315),(8.18,6.315)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,6.655),(8.18,6.825),(8.35,6.825),(8.35,6.655),(8.18,6.655)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,6.995),(8.18,7.165),(8.35,7.165),(8.35,6.995),(8.18,6.995)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,7.335),(8.18,7.505),(8.35,7.505),(8.35,7.335),(8.18,7.335)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,7.675),(8.18,7.845),(8.35,7.845),(8.35,7.675),(8.18,7.675)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,8.015),(8.18,8.185),(8.35,8.185),(8.35,8.015),(8.18,8.015)),
        )
        createRL(
            tech, net, 'licon',
            ((8.18,8.355),(8.18,8.525),(8.35,8.525),(8.35,8.355),(8.18,8.355)),
        )
        createRL(
            tech, net, 'difftap',
            ((8.125,5.805),(8.125,9.09),(8.39,9.09),(8.39,5.805),(8.125,5.805)),
        )
        createRL(
            tech, net, 'difftap',
            ((8.125,0.91),(8.125,3.635),(8.39,3.635),(8.39,0.91),(8.125,0.91)),
        )
        Vertical.create(
            net, tech.getLayer('li.pin'),
            u(7.63), u(0.17), u(1.37), u(8.63),
        )
        pin = Vertical.create(
            net, tech.getLayer('li'),
            u(7.63), u(0.17), u(1.37), u(8.63),
        )
        net.setExternal(True)
        NetExternalComponents.setExternal(pin)
        nets['vdd'].setGlobal(True)
        nets['vss'].setGlobal(True)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['i'].setDirection(Net.Direction.IN)
        nets['clk'].setType(Net.Type.CLOCK)
        nets['clk'].setDirection(Net.Direction.IN)
        nets['q'].setDirection(Net.Direction.OUT)
        nets['nrst'].setDirection(Net.Direction.IN)

    cell = new_cells['Gallery']
    with UpdateSession():
        cell.setAbutmentBox(Box(
            u(0.0), u(-10.0), u(137.0), u(20.0),
        ))
        nets = {

        }
        nets['vss'].setGlobal(True)
        nets['vdd'].setGlobal(True)
        nets['vss'].setType(Net.Type.GROUND)
        nets['vss'].setDirection(Net.Direction.IN)
        nets['vdd'].setType(Net.Type.POWER)
        nets['vdd'].setDirection(Net.Direction.IN)
        try:
            subcell = new_cells['fill']
        except:
            subcell = af.getCell('fill', 0)
        trans = Transformation(
            u(0.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'fill[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['dffnr_x1']
        except:
            subcell = af.getCell('dffnr_x1', 0)
        trans = Transformation(
            u(0.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'dffnr_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['dffnr_x1']
        except:
            subcell = af.getCell('dffnr_x1', 0)
        trans = Transformation(
            u(0.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'dffnr_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie']
        except:
            subcell = af.getCell('tie', 0)
        trans = Transformation(
            u(1.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['dff_x1']
        except:
            subcell = af.getCell('dff_x1', 0)
        trans = Transformation(
            u(9.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'dff_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill']
        except:
            subcell = af.getCell('fill', 0)
        trans = Transformation(
            u(9.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'fill[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff']
        except:
            subcell = af.getCell('tie_diff', 0)
        trans = Transformation(
            u(2.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_diff[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nsnrlatch_x1']
        except:
            subcell = af.getCell('nsnrlatch_x1', 0)
        trans = Transformation(
            u(16.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nsnrlatch_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['dff_x1']
        except:
            subcell = af.getCell('dff_x1', 0)
        trans = Transformation(
            u(10.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'dff_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly']
        except:
            subcell = af.getCell('tie_poly', 0)
        trans = Transformation(
            u(3.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_poly[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nsnrlatch_x0']
        except:
            subcell = af.getCell('nsnrlatch_x0', 0)
        trans = Transformation(
            u(19.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nsnrlatch_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie']
        except:
            subcell = af.getCell('tie', 0)
        trans = Transformation(
            u(17.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill_w2']
        except:
            subcell = af.getCell('fill_w2', 0)
        trans = Transformation(
            u(4.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'fill_w2[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nexor2_x0']
        except:
            subcell = af.getCell('nexor2_x0', 0)
        trans = Transformation(
            u(22.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nexor2_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nsnrlatch_x1']
        except:
            subcell = af.getCell('nsnrlatch_x1', 0)
        trans = Transformation(
            u(18.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nsnrlatch_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_w2']
        except:
            subcell = af.getCell('tie_w2', 0)
        trans = Transformation(
            u(6.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_w2[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['xor2_x0']
        except:
            subcell = af.getCell('xor2_x0', 0)
        trans = Transformation(
            u(26.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'xor2_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff']
        except:
            subcell = af.getCell('tie_diff', 0)
        trans = Transformation(
            u(21.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_diff[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff_w2']
        except:
            subcell = af.getCell('tie_diff_w2', 0)
        trans = Transformation(
            u(8.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_diff_w2[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or21nand_x1']
        except:
            subcell = af.getCell('or21nand_x1', 0)
        trans = Transformation(
            u(30.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or21nand_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nsnrlatch_x0']
        except:
            subcell = af.getCell('nsnrlatch_x0', 0)
        trans = Transformation(
            u(22.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nsnrlatch_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly_w2']
        except:
            subcell = af.getCell('tie_poly_w2', 0)
        trans = Transformation(
            u(10.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_poly_w2[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or21nand_x0']
        except:
            subcell = af.getCell('or21nand_x0', 0)
        trans = Transformation(
            u(33.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or21nand_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly']
        except:
            subcell = af.getCell('tie_poly', 0)
        trans = Transformation(
            u(25.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_poly[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill_w4']
        except:
            subcell = af.getCell('fill_w4', 0)
        trans = Transformation(
            u(12.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'fill_w4[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and21nor_x1']
        except:
            subcell = af.getCell('and21nor_x1', 0)
        trans = Transformation(
            u(36.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and21nor_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nexor2_x0']
        except:
            subcell = af.getCell('nexor2_x0', 0)
        trans = Transformation(
            u(26.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nexor2_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_w4']
        except:
            subcell = af.getCell('tie_w4', 0)
        trans = Transformation(
            u(16.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_w4[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and21nor_x0']
        except:
            subcell = af.getCell('and21nor_x0', 0)
        trans = Transformation(
            u(39.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and21nor_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill_w2']
        except:
            subcell = af.getCell('fill_w2', 0)
        trans = Transformation(
            u(30.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'fill_w2[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff_w4']
        except:
            subcell = af.getCell('tie_diff_w4', 0)
        trans = Transformation(
            u(20.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_diff_w4[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['mux2_x1']
        except:
            subcell = af.getCell('mux2_x1', 0)
        trans = Transformation(
            u(42.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'mux2_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['xor2_x0']
        except:
            subcell = af.getCell('xor2_x0', 0)
        trans = Transformation(
            u(32.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'xor2_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly_w4']
        except:
            subcell = af.getCell('tie_poly_w4', 0)
        trans = Transformation(
            u(24.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'tie_poly_w4[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or4_x1']
        except:
            subcell = af.getCell('or4_x1', 0)
        trans = Transformation(
            u(46.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or4_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_w2']
        except:
            subcell = af.getCell('tie_w2', 0)
        trans = Transformation(
            u(36.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_w2[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['diode_w1']
        except:
            subcell = af.getCell('diode_w1', 0)
        trans = Transformation(
            u(28.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'diode_w1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or3_x1']
        except:
            subcell = af.getCell('or3_x1', 0)
        trans = Transformation(
            u(49.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or3_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or21nand_x1']
        except:
            subcell = af.getCell('or21nand_x1', 0)
        trans = Transformation(
            u(38.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or21nand_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['zero_x1']
        except:
            subcell = af.getCell('zero_x1', 0)
        trans = Transformation(
            u(29.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'zero_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or2_x1']
        except:
            subcell = af.getCell('or2_x1', 0)
        trans = Transformation(
            u(52.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or2_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff_w2']
        except:
            subcell = af.getCell('tie_diff_w2', 0)
        trans = Transformation(
            u(41.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_diff_w2[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['one_x1']
        except:
            subcell = af.getCell('one_x1', 0)
        trans = Transformation(
            u(30.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'one_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor4_x1']
        except:
            subcell = af.getCell('nor4_x1', 0)
        trans = Transformation(
            u(54.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor4_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or21nand_x0']
        except:
            subcell = af.getCell('or21nand_x0', 0)
        trans = Transformation(
            u(43.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or21nand_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['zeroone_x1']
        except:
            subcell = af.getCell('zeroone_x1', 0)
        trans = Transformation(
            u(31.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'zeroone_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor4_x0']
        except:
            subcell = af.getCell('nor4_x0', 0)
        trans = Transformation(
            u(57.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor4_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly_w2']
        except:
            subcell = af.getCell('tie_poly_w2', 0)
        trans = Transformation(
            u(46.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_poly_w2[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['decap_w0']
        except:
            subcell = af.getCell('decap_w0', 0)
        trans = Transformation(
            u(32.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'decap_w0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor3_x1']
        except:
            subcell = af.getCell('nor3_x1', 0)
        trans = Transformation(
            u(60.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor3_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and21nor_x1']
        except:
            subcell = af.getCell('and21nor_x1', 0)
        trans = Transformation(
            u(48.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and21nor_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x0']
        except:
            subcell = af.getCell('inv_x0', 0)
        trans = Transformation(
            u(33.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'inv_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor3_x0']
        except:
            subcell = af.getCell('nor3_x0', 0)
        trans = Transformation(
            u(62.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor3_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill_w4']
        except:
            subcell = af.getCell('fill_w4', 0)
        trans = Transformation(
            u(51.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'fill_w4[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x1']
        except:
            subcell = af.getCell('inv_x1', 0)
        trans = Transformation(
            u(34.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'inv_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor2_x1']
        except:
            subcell = af.getCell('nor2_x1', 0)
        trans = Transformation(
            u(64.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor2_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and21nor_x0']
        except:
            subcell = af.getCell('and21nor_x0', 0)
        trans = Transformation(
            u(55.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and21nor_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x2']
        except:
            subcell = af.getCell('inv_x2', 0)
        trans = Transformation(
            u(35.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'inv_x2[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor2_x0']
        except:
            subcell = af.getCell('nor2_x0', 0)
        trans = Transformation(
            u(66.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor2_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_w4']
        except:
            subcell = af.getCell('tie_w4', 0)
        trans = Transformation(
            u(58.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_w4[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x4']
        except:
            subcell = af.getCell('inv_x4', 0)
        trans = Transformation(
            u(37.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'inv_x4[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and4_x1']
        except:
            subcell = af.getCell('and4_x1', 0)
        trans = Transformation(
            u(68.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and4_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['mux2_x1']
        except:
            subcell = af.getCell('mux2_x1', 0)
        trans = Transformation(
            u(62.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'mux2_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x1']
        except:
            subcell = af.getCell('buf_x1', 0)
        trans = Transformation(
            u(40.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'buf_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and3_x1']
        except:
            subcell = af.getCell('and3_x1', 0)
        trans = Transformation(
            u(71.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and3_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff_w4']
        except:
            subcell = af.getCell('tie_diff_w4', 0)
        trans = Transformation(
            u(66.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_diff_w4[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x2']
        except:
            subcell = af.getCell('buf_x2', 0)
        trans = Transformation(
            u(42.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'buf_x2[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and2_x1']
        except:
            subcell = af.getCell('and2_x1', 0)
        trans = Transformation(
            u(74.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and2_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or4_x1']
        except:
            subcell = af.getCell('or4_x1', 0)
        trans = Transformation(
            u(70.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or4_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x4']
        except:
            subcell = af.getCell('buf_x4', 0)
        trans = Transformation(
            u(44.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'buf_x4[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand4_x1']
        except:
            subcell = af.getCell('nand4_x1', 0)
        trans = Transformation(
            u(76.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand4_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly_w4']
        except:
            subcell = af.getCell('tie_poly_w4', 0)
        trans = Transformation(
            u(73.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_poly_w4[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand2_x0']
        except:
            subcell = af.getCell('nand2_x0', 0)
        trans = Transformation(
            u(47.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nand2_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand4_x0']
        except:
            subcell = af.getCell('nand4_x0', 0)
        trans = Transformation(
            u(79.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand4_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or3_x1']
        except:
            subcell = af.getCell('or3_x1', 0)
        trans = Transformation(
            u(77.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or3_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand2_x1']
        except:
            subcell = af.getCell('nand2_x1', 0)
        trans = Transformation(
            u(49.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nand2_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand3_x1']
        except:
            subcell = af.getCell('nand3_x1', 0)
        trans = Transformation(
            u(82.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand3_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['diode_w1']
        except:
            subcell = af.getCell('diode_w1', 0)
        trans = Transformation(
            u(80.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'diode_w1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand3_x0']
        except:
            subcell = af.getCell('nand3_x0', 0)
        trans = Transformation(
            u(51.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nand3_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand3_x0']
        except:
            subcell = af.getCell('nand3_x0', 0)
        trans = Transformation(
            u(84.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand3_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or2_x1']
        except:
            subcell = af.getCell('or2_x1', 0)
        trans = Transformation(
            u(81.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'or2_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand3_x1']
        except:
            subcell = af.getCell('nand3_x1', 0)
        trans = Transformation(
            u(53.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nand3_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand2_x1']
        except:
            subcell = af.getCell('nand2_x1', 0)
        trans = Transformation(
            u(86.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand2_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['zero_x1']
        except:
            subcell = af.getCell('zero_x1', 0)
        trans = Transformation(
            u(83.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'zero_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand4_x0']
        except:
            subcell = af.getCell('nand4_x0', 0)
        trans = Transformation(
            u(55.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nand4_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand2_x0']
        except:
            subcell = af.getCell('nand2_x0', 0)
        trans = Transformation(
            u(88.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand2_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor4_x1']
        except:
            subcell = af.getCell('nor4_x1', 0)
        trans = Transformation(
            u(84.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor4_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand4_x1']
        except:
            subcell = af.getCell('nand4_x1', 0)
        trans = Transformation(
            u(58.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nand4_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x4']
        except:
            subcell = af.getCell('buf_x4', 0)
        trans = Transformation(
            u(90.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'buf_x4[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['one_x1']
        except:
            subcell = af.getCell('one_x1', 0)
        trans = Transformation(
            u(87.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'one_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and2_x1']
        except:
            subcell = af.getCell('and2_x1', 0)
        trans = Transformation(
            u(61.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'and2_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x2']
        except:
            subcell = af.getCell('buf_x2', 0)
        trans = Transformation(
            u(93.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'buf_x2[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor4_x0']
        except:
            subcell = af.getCell('nor4_x0', 0)
        trans = Transformation(
            u(88.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor4_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and3_x1']
        except:
            subcell = af.getCell('and3_x1', 0)
        trans = Transformation(
            u(63.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'and3_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x1']
        except:
            subcell = af.getCell('buf_x1', 0)
        trans = Transformation(
            u(95.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'buf_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['zeroone_x1']
        except:
            subcell = af.getCell('zeroone_x1', 0)
        trans = Transformation(
            u(91.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'zeroone_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and4_x1']
        except:
            subcell = af.getCell('and4_x1', 0)
        trans = Transformation(
            u(66.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'and4_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x4']
        except:
            subcell = af.getCell('inv_x4', 0)
        trans = Transformation(
            u(97.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x4[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor3_x1']
        except:
            subcell = af.getCell('nor3_x1', 0)
        trans = Transformation(
            u(92.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor3_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor2_x0']
        except:
            subcell = af.getCell('nor2_x0', 0)
        trans = Transformation(
            u(69.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nor2_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x2']
        except:
            subcell = af.getCell('inv_x2', 0)
        trans = Transformation(
            u(100.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x2[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['decap_w0']
        except:
            subcell = af.getCell('decap_w0', 0)
        trans = Transformation(
            u(94.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'decap_w0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor2_x1']
        except:
            subcell = af.getCell('nor2_x1', 0)
        trans = Transformation(
            u(71.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nor2_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x1']
        except:
            subcell = af.getCell('inv_x1', 0)
        trans = Transformation(
            u(102.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor3_x0']
        except:
            subcell = af.getCell('nor3_x0', 0)
        trans = Transformation(
            u(95.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor3_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor3_x0']
        except:
            subcell = af.getCell('nor3_x0', 0)
        trans = Transformation(
            u(73.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nor3_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x0']
        except:
            subcell = af.getCell('inv_x0', 0)
        trans = Transformation(
            u(103.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x0']
        except:
            subcell = af.getCell('inv_x0', 0)
        trans = Transformation(
            u(97.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor3_x1']
        except:
            subcell = af.getCell('nor3_x1', 0)
        trans = Transformation(
            u(75.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nor3_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['decap_w0']
        except:
            subcell = af.getCell('decap_w0', 0)
        trans = Transformation(
            u(104.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'decap_w0[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor2_x1']
        except:
            subcell = af.getCell('nor2_x1', 0)
        trans = Transformation(
            u(98.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor2_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor4_x0']
        except:
            subcell = af.getCell('nor4_x0', 0)
        trans = Transformation(
            u(77.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nor4_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['zeroone_x1']
        except:
            subcell = af.getCell('zeroone_x1', 0)
        trans = Transformation(
            u(105.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'zeroone_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x1']
        except:
            subcell = af.getCell('inv_x1', 0)
        trans = Transformation(
            u(100.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor4_x1']
        except:
            subcell = af.getCell('nor4_x1', 0)
        trans = Transformation(
            u(80.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nor4_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['one_x1']
        except:
            subcell = af.getCell('one_x1', 0)
        trans = Transformation(
            u(106.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'one_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nor2_x0']
        except:
            subcell = af.getCell('nor2_x0', 0)
        trans = Transformation(
            u(101.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nor2_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or2_x1']
        except:
            subcell = af.getCell('or2_x1', 0)
        trans = Transformation(
            u(83.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'or2_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['zero_x1']
        except:
            subcell = af.getCell('zero_x1', 0)
        trans = Transformation(
            u(107.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'zero_x1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x2']
        except:
            subcell = af.getCell('inv_x2', 0)
        trans = Transformation(
            u(103.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x2[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or3_x1']
        except:
            subcell = af.getCell('or3_x1', 0)
        trans = Transformation(
            u(85.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'or3_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['diode_w1']
        except:
            subcell = af.getCell('diode_w1', 0)
        trans = Transformation(
            u(108.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'diode_w1[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and4_x1']
        except:
            subcell = af.getCell('and4_x1', 0)
        trans = Transformation(
            u(105.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and4_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or4_x1']
        except:
            subcell = af.getCell('or4_x1', 0)
        trans = Transformation(
            u(88.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'or4_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly_w4']
        except:
            subcell = af.getCell('tie_poly_w4', 0)
        trans = Transformation(
            u(109.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_poly_w4[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['inv_x4']
        except:
            subcell = af.getCell('inv_x4', 0)
        trans = Transformation(
            u(108.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'inv_x4[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['mux2_x1']
        except:
            subcell = af.getCell('mux2_x1', 0)
        trans = Transformation(
            u(91.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'mux2_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff_w4']
        except:
            subcell = af.getCell('tie_diff_w4', 0)
        trans = Transformation(
            u(113.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_diff_w4[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and3_x1']
        except:
            subcell = af.getCell('and3_x1', 0)
        trans = Transformation(
            u(111.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and3_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and21nor_x0']
        except:
            subcell = af.getCell('and21nor_x0', 0)
        trans = Transformation(
            u(95.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'and21nor_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_w4']
        except:
            subcell = af.getCell('tie_w4', 0)
        trans = Transformation(
            u(117.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_w4[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x1']
        except:
            subcell = af.getCell('buf_x1', 0)
        trans = Transformation(
            u(114.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'buf_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and21nor_x1']
        except:
            subcell = af.getCell('and21nor_x1', 0)
        trans = Transformation(
            u(98.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'and21nor_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill_w4']
        except:
            subcell = af.getCell('fill_w4', 0)
        trans = Transformation(
            u(121.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'fill_w4[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['and2_x1']
        except:
            subcell = af.getCell('and2_x1', 0)
        trans = Transformation(
            u(116.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'and2_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or21nand_x0']
        except:
            subcell = af.getCell('or21nand_x0', 0)
        trans = Transformation(
            u(101.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'or21nand_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly_w2']
        except:
            subcell = af.getCell('tie_poly_w2', 0)
        trans = Transformation(
            u(125.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_poly_w2[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x2']
        except:
            subcell = af.getCell('buf_x2', 0)
        trans = Transformation(
            u(118.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'buf_x2[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['or21nand_x1']
        except:
            subcell = af.getCell('or21nand_x1', 0)
        trans = Transformation(
            u(104.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'or21nand_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff_w2']
        except:
            subcell = af.getCell('tie_diff_w2', 0)
        trans = Transformation(
            u(127.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_diff_w2[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand4_x1']
        except:
            subcell = af.getCell('nand4_x1', 0)
        trans = Transformation(
            u(120.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand4_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['xor2_x0']
        except:
            subcell = af.getCell('xor2_x0', 0)
        trans = Transformation(
            u(107.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'xor2_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_w2']
        except:
            subcell = af.getCell('tie_w2', 0)
        trans = Transformation(
            u(129.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_w2[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['buf_x4']
        except:
            subcell = af.getCell('buf_x4', 0)
        trans = Transformation(
            u(123.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'buf_x4[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nexor2_x0']
        except:
            subcell = af.getCell('nexor2_x0', 0)
        trans = Transformation(
            u(111.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nexor2_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill_w2']
        except:
            subcell = af.getCell('fill_w2', 0)
        trans = Transformation(
            u(131.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'fill_w2[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand4_x0']
        except:
            subcell = af.getCell('nand4_x0', 0)
        trans = Transformation(
            u(126.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand4_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nsnrlatch_x0']
        except:
            subcell = af.getCell('nsnrlatch_x0', 0)
        trans = Transformation(
            u(115.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nsnrlatch_x0[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_poly']
        except:
            subcell = af.getCell('tie_poly', 0)
        trans = Transformation(
            u(133.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_poly[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand2_x0']
        except:
            subcell = af.getCell('nand2_x0', 0)
        trans = Transformation(
            u(129.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand2_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nsnrlatch_x1']
        except:
            subcell = af.getCell('nsnrlatch_x1', 0)
        trans = Transformation(
            u(118.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'nsnrlatch_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie_diff']
        except:
            subcell = af.getCell('tie_diff', 0)
        trans = Transformation(
            u(134.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie_diff[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand3_x1']
        except:
            subcell = af.getCell('nand3_x1', 0)
        trans = Transformation(
            u(131.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand3_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['dff_x1']
        except:
            subcell = af.getCell('dff_x1', 0)
        trans = Transformation(
            u(121.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'dff_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['tie']
        except:
            subcell = af.getCell('tie', 0)
        trans = Transformation(
            u(135.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'tie[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand2_x1']
        except:
            subcell = af.getCell('nand2_x1', 0)
        trans = Transformation(
            u(133.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand2_x1[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['dffnr_x1']
        except:
            subcell = af.getCell('dffnr_x1', 0)
        trans = Transformation(
            u(128.0), u(0.0), Transformation.Orientation.ID,
        )
        Instance.create(
            cell, 'dffnr_x1[0]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['fill']
        except:
            subcell = af.getCell('fill', 0)
        trans = Transformation(
            u(136.0), u(0.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'fill[1]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )
        try:
            subcell = new_cells['nand3_x0']
        except:
            subcell = af.getCell('nand3_x0', 0)
        trans = Transformation(
            u(135.0), u(20.0), Transformation.Orientation.MX,
        )
        Instance.create(
            cell, 'nand3_x0[2]', subcell, trans,
            Instance.PlacementStatus.PLACED,
        )

    af.wrapLibrary(lib, 0)

    return lib

def setup():
    lib = _load()
    _routing()
    try:
        from .StdCellLib_fix import fix
    except:
        pass
    else:
        fix(lib)

    return lib
